@@ -3,10 +3,12 @@
 Contains various components useful for application development and tasks
 common to applications.
 """
+
 from .daemon import Daemon
 from .dropprivileges import DropPrivileges
 
-__all__ = ("Daemon", "DropPrivileges",)
+
+__all__ = ('Daemon', 'DropPrivileges')
 
 # flake8: noqa
 # pylama: skip=1
