@@ -1,12 +1,12 @@
-"""Daemon Component
+"""
+Daemon Component
 
 Component to daemonize a system into the background and detach it from its
 controlling PTY. Supports PID file writing, logging stdin, stdout and stderr
 and changing the current working directory.
 """
-from os import (
-    _exit, chdir, closerange, dup2, fork, getpid, remove, setsid, umask,
-)
+
+from os import _exit, chdir, closerange, dup2, fork, getpid, remove, setsid, umask
 from os.path import isabs
 from resource import RLIM_INFINITY, RLIMIT_NOFILE, getrlimit
 from sys import stderr, stdin, stdout
@@ -23,15 +23,16 @@ class daemonized(Event):
 
 
 class deletepid(Event):
-    """"deletepid Event"""
+    """deletepid Event"""
 
 
 class writepid(Event):
-    """"writepid Event"""
+    """writepid Event"""
 
 
 class Daemon(Component):
-    """Daemon Component
+    """
+    Daemon Component
 
     :param pidfile: .pid filename
     :type  pidfile: str or unicode
@@ -46,33 +47,25 @@ class Daemon(Component):
     :type  stderr:  str or unicode
     """
 
-    channel = "daemon"
+    channel = 'daemon'
 
-    def init(self, pidfile, path="/", stdin=None, stdout=None,
-             stderr=None, channel=channel):
-
-        assert isabs(path), "path must be absolute"
+    def init(self, pidfile, path='/', stdin=None, stdout=None, stderr=None, channel=channel):
+        assert isabs(path), 'path must be absolute'
 
         self.pidfile = pidfile
         self.path = path
 
-        self.stdin = (
-            stdin if stdin is not None and isabs(stdin) else "/dev/null"
-        )
+        self.stdin = stdin if stdin is not None and isabs(stdin) else '/dev/null'
 
-        self.stdout = (
-            stdout if stdout is not None and isabs(stdout) else "/dev/null"
-        )
+        self.stdout = stdout if stdout is not None and isabs(stdout) else '/dev/null'
 
-        self.stderr = (
-            stderr if stderr is not None and isabs(stderr) else "/dev/null"
-        )
+        self.stderr = stderr if stderr is not None and isabs(stderr) else '/dev/null'
 
     def deletepid(self):
         remove(self.pidfile)
 
     def writepid(self):
-        with open(self.pidfile, "w") as fd:
+        with open(self.pidfile, 'w') as fd:
             fd.write(str(getpid()))
 
     def daemonize(self):
@@ -82,11 +75,7 @@ class Daemon(Component):
                 # exit first parent
                 _exit(0)
         except OSError as e:
-            stderr.write(
-                "fork #1 failed: {:d} ({})\n".format(
-                    e.errno, e
-                )
-            )
+            stderr.write(f'fork #1 failed: {e.errno:d} ({e})\n')
 
             raise SystemExit(1)
 
@@ -102,11 +91,7 @@ class Daemon(Component):
                 # exit from second parent
                 _exit(0)
         except OSError as e:
-            stderr.write(
-                "fork #2 failed: {:d} ({})\n".format(
-                    e.errno, e
-                )
-            )
+            stderr.write(f'fork #2 failed: {e.errno:d} ({e})\n')
 
             raise SystemExit(1)
 
@@ -120,9 +105,9 @@ class Daemon(Component):
 
         closerange(0, maxfd)
 
-        si = open(self.stdin, "r")
-        so = open(self.stdout, "a+")
-        se = open(self.stderr, "a+")
+        si = open(self.stdin)
+        so = open(self.stdout, 'a+')
+        se = open(self.stderr, 'a+')
 
         dup2(si.fileno(), stdin.fileno())
         dup2(so.fileno(), stdout.fileno())
@@ -135,7 +120,7 @@ class Daemon(Component):
         if component == self and manager.root.running:
             self.fire(daemonize())
 
-    @handler("started", priority=100.0, channel="*")
+    @handler('started', priority=100.0, channel='*')
     def on_started(self, component):
         if component is not self:
             self.fire(daemonize())
