@@ -2,6 +2,7 @@
 
 This package contains the essential core parts of the circuits framework.
 """
+
 from .bridge import Bridge, ipc
 from .components import BaseComponent, Component
 from .debugger import Debugger
@@ -13,9 +14,20 @@ from .timers import Timer
 from .values import Value
 from .workers import Worker, task
 
+
 __all__ = (
-    "handler", "BaseComponent", "Component", "Event", "task",
-    "Worker", "ipc", "Bridge", "Debugger", "Timer", "Manager", "TimeoutError",
+    'handler',
+    'BaseComponent',
+    'Component',
+    'Event',
+    'task',
+    'Worker',
+    'ipc',
+    'Bridge',
+    'Debugger',
+    'Timer',
+    'Manager',
+    'TimeoutError',
 )
 
 # flake8: noqa
