@@ -1,4 +1,5 @@
-"""Bridge
+"""
+Bridge
 
 The Bridge Component is used for inter-process communications between
 processes. Bridge is used internally when a Component is started in
@@ -6,24 +7,22 @@ processes. Bridge is used internally when a Component is started in
 Pipe is used as the socket transport between two sides of a Bridge
 (*there must be a :class:`~Bridge` instance on both sides*).
 """
+
 import traceback
+from pickle import dumps, loads
 
 from .components import BaseComponent
 from .events import Event, exception
 from .handlers import handler
 from .values import Value
 
-try:
-    from cPickle import dumps, loads
-except ImportError:
-    from pickle import dumps, loads  # NOQA
-
 
 _sentinel = b'~~~'
 
 
 class ipc(Event):
-    """ipc Event
+    """
+    ipc Event
 
     Send an event to a child/parent process
     """
@@ -36,18 +35,16 @@ class ipc(Event):
         :param channel: IPC Channel (channel to use on child/parent).
         :type channel:  str
         """
-
-        super(ipc, self).__init__(event, channel=channel)
+        super().__init__(event, channel=channel)
 
 
 class Bridge(BaseComponent):
-
-    channel = "bridge"
+    channel = 'bridge'
 
     def init(self, socket, channel=channel):
-        self._buffer = b""
+        self._buffer = b''
         self._socket = socket
-        self._values = dict()
+        self._values = {}
 
         if self._socket is not None:
             self._socket.register(self)
@@ -55,7 +52,7 @@ class Bridge(BaseComponent):
     def _process_packet(self, eid, obj):
         if isinstance(obj, Event):
             obj.remote = True
-            obj.notify = "value_changed"
+            obj.notify = 'value_changed'
             obj.waitingHandlers = 0
             value = self.fire(obj)
             self._values[value] = eid
@@ -70,7 +67,7 @@ class Bridge(BaseComponent):
             event.remote = True
             self.fire(event, self.channel)
 
-    @handler("value_changed", channel="*")
+    @handler('value_changed', channel='*')
     def _on_value_changed(self, value):
         try:
             eid = self._values[value]
@@ -80,12 +77,12 @@ class Bridge(BaseComponent):
         except Exception:
             pass
 
-    @handler("read")
+    @handler('read')
     def _on_read(self, data):
         self._buffer += data
         items = self._buffer.split(_sentinel)
 
-        if items[-1] != "":
+        if items[-1] != '':
             self._buffer = items.pop()
 
         for item in filter(None, items):
@@ -103,9 +100,10 @@ class Bridge(BaseComponent):
     def __write(self, eid, data):
         self._socket.write(dumps((eid, data)) + _sentinel)
 
-    @handler("ipc")
+    @handler('ipc')
     def _on_ipc(self, event, ipc_event, channel=None):
-        """Send event to a child/parentprocess
+        """
+        Send event to a child/parentprocess
 
         Event handler to run an event on a child/parent process
         (the event definition is :class:`circuits.core.bridge.ipc`)
@@ -127,7 +125,6 @@ class Bridge(BaseComponent):
         result = yield self.fire(ipc(hello()))
         print(result.value)``
         """
-
         ipc_event.channels = (channel,) if channel is not None else event.channels
         event.value.value = ipc_event.value = Value(ipc_event, self)
 
