@@ -1,13 +1,9 @@
-"""
-This module defines the BaseComponent and its subclass Component.
-"""
+"""This module defines the BaseComponent and its subclass Component."""
+
+from collections.abc import Callable
 from inspect import getmembers
 from itertools import chain
 from types import MethodType
-try:
-    from collections import Callable
-except ImportError:
-    from collections.abc import Callable
 
 from .events import Event, registered, unregistered
 from .handlers import HandlerMetaClass, handler
@@ -15,7 +11,6 @@ from .manager import Manager
 
 
 class prepare_unregister(Event):
-
     """
     This event is fired when a component is about to be unregistered
     from the component tree. Unregistering a component actually
@@ -33,7 +28,7 @@ class prepare_unregister(Event):
     complete = True
 
     def __init__(self, *args, **kwargs):
-        super(prepare_unregister, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def in_subtree(self, component):
         """
@@ -49,7 +44,6 @@ class prepare_unregister(Event):
 
 
 class BaseComponent(Manager):
-
     """
     This is the base class for all components in a circuits based application.
     Components can (and should, except for root components) be registered
@@ -81,15 +75,12 @@ class BaseComponent(Manager):
         channels and received from all channels.
     """
 
-    channel = "*"
+    channel = '*'
 
     def __new__(cls, *args, **kwargs):
-        self = super(BaseComponent, cls).__new__(cls)
+        self = super().__new__(cls)
 
-        handlers = dict(
-            [(k, v) for k, v in list(cls.__dict__.items())
-                if getattr(v, "handler", False)]
-        )
+        handlers = {k: v for k, v in list(cls.__dict__.items()) if getattr(v, 'handler', False)}
 
         def overridden(x):
             return x in handlers and handlers[x].override
@@ -98,36 +89,35 @@ class BaseComponent(Manager):
             if issubclass(cls, base):
                 for k, v in list(base.__dict__.items()):
                     p1 = isinstance(v, Callable)
-                    p2 = getattr(v, "handler", False)
+                    p2 = getattr(v, 'handler', False)
                     p3 = overridden(k)
                     if p1 and p2 and not p3:
-                        name = "%s_%s" % (base.__name__, k)
+                        name = f'{base.__name__}_{k}'
                         method = MethodType(v, self)
                         setattr(self, name, method)
 
         return self
 
     def __init__(self, *args, **kwargs):
-        "initializes x; see x.__class__.__doc__ for signature"
+        """Initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args, **kwargs)
 
-        super(BaseComponent, self).__init__(*args, **kwargs)
+        self.channel = kwargs.get('channel', self.channel) or '*'
 
-        self.channel = kwargs.get("channel", self.channel) or "*"
-
-        for k, v in getmembers(self):
-            if getattr(v, "handler", False) is True:
+        for _k, v in getmembers(self):
+            if getattr(v, 'handler', False) is True:
                 self.addHandler(v)
             # TODO: Document this feature. See Issue #88
-            if v is not self and isinstance(v, BaseComponent) \
-                    and v not in ('parent', 'root'):
+            if v is not self and isinstance(v, BaseComponent) and v not in ('parent', 'root'):
                 v.register(self)
 
-        if hasattr(self, "init") and isinstance(self.init, Callable):
+        if hasattr(self, 'init') and isinstance(self.init, Callable):
             self.init(*args, **kwargs)
 
-        @handler("prepare_unregister_complete", channel=self)
+        @handler('prepare_unregister_complete', channel=self)
         def _on_prepare_unregister_complete(self, event, e, value):
             self._do_prepare_unregister_complete(event.parent, value)
+
         self.addHandler(_on_prepare_unregister_complete)
 
     def register(self, parent):
@@ -141,7 +131,6 @@ class BaseComponent(Manager):
         This method fires a :class:`~.events.Registered` event to inform
         other components in the tree about the new member.
         """
-
         self.parent = parent
         self.root = parent.root
 
@@ -171,7 +160,6 @@ class BaseComponent(Manager):
         the component is removed from the tree and an
         :class:`~.events.unregistered` event is fired.
         """
-
         if self.unregister_pending or self.parent is self:
             return self
 
@@ -188,11 +176,11 @@ class BaseComponent(Manager):
 
     @property
     def unregister_pending(self):
-        return getattr(self, "_unregister_pending", False)
+        return getattr(self, '_unregister_pending', False)
 
     def _do_prepare_unregister_complete(self, e, value):
         # Remove component from tree now
-        delattr(self, "_unregister_pending")
+        delattr(self, '_unregister_pending')
         self.fire(unregistered(self, self.parent))
 
         if self.parent is not self:
@@ -210,34 +198,22 @@ class BaseComponent(Manager):
     @classmethod
     def handlers(cls):
         """Returns a list of all event handlers for this Component"""
-
-        return list(set(
-            getattr(cls, k) for k in dir(cls)
-            if getattr(getattr(cls, k), "handler", False)
-        ))
+        return list({getattr(cls, k) for k in dir(cls) if getattr(getattr(cls, k), 'handler', False)})
 
     @classmethod
     def events(cls):
         """Returns a list of all events this Component listens to"""
+        handlers = (getattr(cls, k).names for k in dir(cls) if getattr(getattr(cls, k), 'handler', False))
 
-        handlers = (
-            getattr(cls, k).names for k in dir(cls)
-            if getattr(getattr(cls, k), "handler", False)
-        )
-
-        return list(set(
-            name for name in chain(*handlers)
-            if not name.startswith("_")
-        ))
+        return list({name for name in chain(*handlers) if not name.startswith('_')})
 
     @classmethod
     def handles(cls, *names):
         """Returns True if all names are event handlers of this Component"""
-
         return all(name in cls.events() for name in names)
 
 
-Component = HandlerMetaClass("Component", (BaseComponent,), {})
+Component = HandlerMetaClass('Component', (BaseComponent,), {})
 """
 If you use Component instead of BaseComponent as base class for your own
 component class, then all methods that are not marked as private
