@@ -1,14 +1,12 @@
-"""
-This module defines the basic event class and common events.
-"""
+"""This module defines the basic event class and common events."""
+
 from inspect import ismethod
 from traceback import format_tb
 
 
-class Event(object):
-
+class Event:
     channels = ()
-    "The channels this message is sent to."
+    'The channels this message is sent to.'
 
     parent = None
     notify = False
@@ -23,14 +21,13 @@ class Event(object):
         return type(cls)(_name, (cls,), {})(*args, **kwargs)
 
     def child(self, name, *args, **kwargs):
-        e = Event.create(
-            "{:s}_{:s}".format(self.name, name), *args, **kwargs
-        )
+        e = Event.create(f'{self.name:s}_{name:s}', *args, **kwargs)
         e.parent = self
         return e
 
     def __init__(self, *args, **kwargs):
-        """An event is a message send to one or more channels.
+        """
+        An event is a message send to one or more channels.
         It is eventually dispatched to all components
         that have handlers for one of the channels and the event type.
 
@@ -78,7 +75,6 @@ class Event(object):
             This may be overridden by specifying an alternative list of
             destinations using this attribute.
         """
-
         self.args = list(args)
         self.kwargs = kwargs
 
@@ -92,7 +88,7 @@ class Event(object):
 
     def __getstate__(self):
         odict = self.__dict__.copy()
-        del odict["handler"]
+        del odict['handler']
         return odict
 
     def __setstate__(self, dict):
@@ -105,24 +101,24 @@ class Event(object):
         return False
 
     def __repr__(self):
-        "x.__repr__() <==> repr(x)"
-
+        """x.__repr__() <==> repr(x)"""
         if len(self.channels) > 1:
             channels = repr(self.channels)
         elif len(self.channels) == 1:
             channels = str(self.channels[0])
         else:
-            channels = ""
+            channels = ''
 
-        data = "%s %s" % (
-            ", ".join(repr(arg) for arg in self.args),
-            ", ".join("%s=%s" % (k, repr(v)) for k, v in self.kwargs.items())
+        data = '%s %s' % (
+            ', '.join(repr(arg) for arg in self.args),
+            ', '.join(f'{k}={v!r}' for k, v in self.kwargs.items()),
         )
 
-        return "<%s[%s] (%s)>" % (self.name, channels, data)
+        return f'<{self.name}[{channels}] ({data})>'
 
     def __getitem__(self, x):
-        """x.__getitem__(y) <==> x[y]
+        """
+        x.__getitem__(y) <==> x[y]
 
         Get and return data from the event object requested by "x".
         If an int is passed to x, the requested argument from self.args
@@ -130,16 +126,15 @@ class Event(object):
         keyword argument from self.kwargs is returned keyed by x.
         Otherwise a TypeError is raised as nothing else is valid.
         """
-
         if isinstance(x, int):
             return self.args[x]
-        elif isinstance(x, str):
+        if isinstance(x, str):
             return self.kwargs[x]
-        else:
-            raise TypeError("Expected int or str, got %r" % type(x))
+        raise TypeError('Expected int or str, got %r' % type(x))
 
     def __setitem__(self, i, y):
-        """x.__setitem__(i, y) <==> x[i] = y
+        """
+        x.__setitem__(i, y) <==> x[i] = y
 
         Modify the data in the event object requested by "x".
         If i is an int, the ith requested argument from self.args
@@ -147,28 +142,25 @@ class Event(object):
         keyed by i from self.kwargs, shall by changed to y.
         Otherwise a TypeError is raised as nothing else is valid.
         """
-
         if isinstance(i, int):
             self.args[i] = y
         elif isinstance(i, str):
             self.kwargs[i] = y
         else:
-            raise TypeError("Expected int or str, got %r" % type(i))
+            raise TypeError('Expected int or str, got %r' % type(i))
 
     def cancel(self):
         """Cancel the event from being processed (if not already)"""
-
         self.cancelled = True
 
     def stop(self):
         """Stop further processing of this event"""
-
         self.stopped = True
 
 
 class exception(Event):
-
-    """exception Event
+    """
+    exception Event
 
     This event is sent for any exceptions that occur during the execution
     of an event Handler that is not SystemExit or KeyboardInterrupt.
@@ -190,17 +182,15 @@ class exception(Event):
     """
 
     def __init__(self, type, value, traceback, handler=None, fevent=None):
-        super(exception, self).__init__(type, value,
-                                        self.format_traceback(traceback),
-                                        handler=handler, fevent=fevent)
+        super().__init__(type, value, self.format_traceback(traceback), handler=handler, fevent=fevent)
 
     def format_traceback(self, traceback):
         return format_tb(traceback)
 
 
 class started(Event):
-
-    """started Event
+    """
+    started Event
 
     This Event is sent when a Component or Manager has started running.
 
@@ -209,12 +199,12 @@ class started(Event):
     """
 
     def __init__(self, manager):
-        super(started, self).__init__(manager)
+        super().__init__(manager)
 
 
 class stopped(Event):
-
-    """stopped Event
+    """
+    stopped Event
 
     This Event is sent when a Component or Manager has stopped running.
 
@@ -223,12 +213,12 @@ class stopped(Event):
     """
 
     def __init__(self, manager):
-        super(stopped, self).__init__(manager)
+        super().__init__(manager)
 
 
 class signal(Event):
-
-    """signal Event
+    """
+    signal Event
 
     This Event is sent when a Component receives a signal.
 
@@ -240,12 +230,12 @@ class signal(Event):
     """
 
     def __init__(self, signo, stack):
-        super(signal, self).__init__(signo, stack)
+        super().__init__(signo, stack)
 
 
 class registered(Event):
-
-    """registered Event
+    """
+    registered Event
 
     This Event is sent when a Component has registered with another Component
     or Manager. This Event is only sent if the Component or Manager being
@@ -259,12 +249,12 @@ class registered(Event):
     """
 
     def __init__(self, component, manager):
-        super(registered, self).__init__(component, manager)
+        super().__init__(component, manager)
 
 
 class unregistered(Event):
-
-    """unregistered Event
+    """
+    unregistered Event
 
     This Event is sent when a Component has been unregistered from its
     Component or Manager.
@@ -272,8 +262,8 @@ class unregistered(Event):
 
 
 class generate_events(Event):
-
-    """generate_events Event
+    """
+    generate_events Event
 
     This Event is sent by the circuits core. All components that generate
     timed events or events from external sources (e.g. data becoming
@@ -281,7 +271,7 @@ class generate_events(Event):
     handler.
 
     The handler must either call :meth:`~stop` (*preventing other handlers
-    from being called in the same iteration)
+    from being called in the same iteration*)
     or must invoke :meth:`~.reduce_time_left` with parameter 0.
 
     :param max_wait: maximum time available for generating events.
@@ -293,7 +283,7 @@ class generate_events(Event):
     """
 
     def __init__(self, lock, max_wait):
-        super(generate_events, self).__init__()
+        super().__init__()
 
         self._time_left = max_wait
         self._lock = lock
@@ -306,7 +296,6 @@ class generate_events(Event):
         one component in your system (usually a poller component) that
         spends up to "time left" until it generates an event.
         """
-
         return self._time_left
 
     def reduce_time_left(self, time_left):
@@ -324,18 +313,18 @@ class generate_events(Event):
         If the time left is reduced to 0 and the event is currently
         being handled, the handler's *resume* method is invoked.
         """
-
         with self._lock:
             if time_left >= 0 and (self._time_left < 0 or self._time_left > time_left):
                 self._time_left = time_left
                 if self._time_left == 0 and self.handler is not None:
                     m = getattr(
                         getattr(
-                            self.handler, "im_self", getattr(
-                                self.handler, "__self__"
-                            )
+                            self.handler,
+                            'im_self',
+                            self.handler.__self__,
                         ),
-                        "resume", None
+                        'resume',
+                        None,
                     )
                     if m is not None and ismethod(m):
                         m()
