@@ -1,6 +1,5 @@
-"""
-.. codeauthor: mnl
-"""
+""".. codeauthor: mnl"""
+
 from signal import SIGINT, SIGTERM
 from sys import stderr
 from threading import Event
@@ -13,12 +12,11 @@ from .handlers import handler
 
 
 class FallBackGenerator(BaseComponent):
-
     def __init__(self, *args, **kwargs):
-        super(FallBackGenerator, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._continue = Event()
 
-    @handler("generate_events", priority=-100)
+    @handler('generate_events', priority=-100)
     def _on_generate_events(self, event):
         """
         Fall back handler for the :class:`~.events.GenerateEvents` event.
@@ -30,7 +28,6 @@ class FallBackGenerator(BaseComponent):
         e.g: ``@handler("generate_events", priority=0)``
         and provide a different way to idle when the queue is empty.
         """
-
         with event.lock:
             if event.time_left == 0:
                 event.stop()
@@ -69,44 +66,36 @@ class FallBackGenerator(BaseComponent):
 
 
 class FallBackExceptionHandler(BaseComponent):
-
     """
     If there is no handler for error events in the component hierarchy, this
     component's handler is added automatically. It simply prints
     the error information on stderr.
     """
 
-    @handler("exception", channel="*")
-    def _on_exception(self, error_type, value, traceback,
-                      handler=None, fevent=None):
+    @handler('exception', channel='*')
+    def _on_exception(self, error_type, value, traceback, handler=None, fevent=None):
         s = []
 
-        if handler is None:
-            handler = ""
-        else:
-            handler = reprhandler(handler)
+        handler = '' if handler is None else reprhandler(handler)
 
-        msg = "ERROR {} ({!r}) ({!r}): {!r}\n".format(
-            handler, fevent, error_type, value
-        )
+        msg = f'ERROR {handler} ({fevent!r}) ({error_type!r}): {value!r}\n'
 
         s.append(msg)
         s.append('Traceback (most recent call last):\n')
         s.extend(traceback)
         s.extend(format_exception_only(error_type, value))
-        s.append("\n")
-        stderr.write("".join(s))
+        s.append('\n')
+        stderr.write(''.join(s))
 
 
 class FallBackSignalHandler(BaseComponent):
-
     """
     If there is no handler for signal events in the component hierarchy, this
     component's handler is added automatically. It simply terminates the
     system if the signal is SIGINT or SIGTERM.
     """
 
-    @handler("signal", channel="*")
+    @handler('signal', channel='*')
     def _on_signal(self, signo, stack):
         if signo in [SIGINT, SIGTERM]:
             raise SystemExit(0)
