@@ -1,7 +1,9 @@
-"""
-This module defines the Manager class.
-"""
+"""This module defines the Manager class."""
+
+import _thread
 import atexit
+import contextlib
+import types
 from collections import deque
 from heapq import heappop, heappush
 from inspect import isfunction
@@ -17,42 +19,34 @@ from traceback import format_exc
 from types import GeneratorType
 from uuid import uuid4 as uuid
 
-from ..six import Iterator, create_bound_method, next
-from ..tools import tryimport
 from .events import Event, exception, generate_events, signal, started, stopped
 from .handlers import handler
 from .values import Value
 
+
 try:
     from signal import SIGKILL
 except ImportError:
     SIGKILL = SIGTERM
 
 
-thread = tryimport(("thread", "_thread"))
-
-
 TIMEOUT = 0.1  # 100ms timeout when idle
 
 
 class UnregistrableError(Exception):
-
     """Raised if a component cannot be registered as child."""
 
 
 class TimeoutError(Exception):
-
     """Raised if wait event timeout occurred"""
 
 
-class CallValue(object):
-
+class CallValue:
     def __init__(self, value):
         self.value = value
 
 
-class ExceptionWrapper(object):
-
+class ExceptionWrapper:
     def __init__(self, exception):
         self.exception = exception
 
@@ -60,21 +54,20 @@ class ExceptionWrapper(object):
         return self.exception
 
 
-class Sleep(Iterator):
-
+class Sleep:
     def __init__(self, seconds):
         self._task = None
 
         try:
             self.expiry = time() + float(seconds)
         except ValueError:
-            raise TypeError("a float is required")
+            raise TypeError('a float is required')
 
     def __iter__(self):
         return self
 
     def __repr__(self):
-        return "sleep({!r})".format(self.expiry - time())
+        return f'sleep({self.expiry - time()!r})'
 
     def __next__(self):
         if time() >= self.expiry:
@@ -99,12 +92,10 @@ def sleep(seconds):
     Delay execution of a coroutine for a given number of seconds.
     The argument may be a floating point number for subsecond precision.
     """
-
     return Sleep(seconds)
 
 
-class Dummy(object):
-
+class Dummy:
     channel = None
 
 
@@ -112,9 +103,8 @@ _dummy = Dummy()
 del Dummy
 
 
-class _State(object):
-
-    __slots__ = ('task', 'run', 'flag', 'event', 'timeout', 'parent', 'task_event', 'tick_handler')
+class _State:
+    __slots__ = ('event', 'flag', 'parent', 'run', 'task', 'task_event', 'tick_handler', 'timeout')
 
     def __init__(self, timeout):
         self.task = None
@@ -127,8 +117,8 @@ class _State(object):
         self.tick_handler = None
 
 
-class _EventQueue(object):
-    __slots__ = ('_queue', '_priority_queue', '_counter', '_flush_batch')
+class _EventQueue:
+    __slots__ = ('_counter', '_flush_batch', '_priority_queue', '_queue')
 
     def __init__(self):
         self._queue = deque()
@@ -164,8 +154,7 @@ class _EventQueue(object):
             dispatcher(event, channels, self._flush_batch)
 
 
-class Manager(object):
-
+class Manager:
     """
     The manager class has two roles. As a base class for component
     implementation, it provides methods for event and handler management.
@@ -220,14 +209,13 @@ class Manager(object):
     """
 
     def __init__(self, *args, **kwargs):
-        "initializes x; see x.__class__.__doc__ for signature"
-
+        """Initializes x; see x.__class__.__doc__ for signature"""
         self._queue = _EventQueue()
 
         self._tasks = set()
-        self._cache = dict()
+        self._cache = {}
         self._globals = set()
-        self._handlers = dict()
+        self._handlers = {}
 
         self._flush_batch = 0
         self._cache_needs_refresh = False
@@ -243,51 +231,47 @@ class Manager(object):
         self.components = set()
 
     def __nonzero__(self):
-        "x.__nonzero__() <==> bool(x)"
-
+        """x.__nonzero__() <==> bool(x)"""
         return True
 
     __bool__ = __nonzero__
 
     def __repr__(self):
-        "x.__repr__() <==> repr(x)"
-
+        """x.__repr__() <==> repr(x)"""
         name = self.__class__.__name__
 
-        channel = "/{}".format(getattr(self, "channel", ""))
+        channel = '/{}'.format(getattr(self, 'channel', ''))
 
         q = len(self._queue)
-        state = "R" if self.running else "S"
+        state = 'R' if self.running else 'S'
 
         pid = current_process().pid
 
-        if pid:
-            id = "%s:%s" % (pid, current_thread().getName())
-        else:
-            id = current_thread().getName()
+        id = f'{pid}:{current_thread().name}' if pid else current_thread().name
 
-        format = "<%s%s %s (queued=%d) [%s]>"
+        format = '<%s%s %s (queued=%d) [%s]>'
         return format % (name, channel, id, q, state)
 
     def __contains__(self, y):
-        """x.__contains__(y) <==> y in x
+        """
+        x.__contains__(y) <==> y in x
 
         Return True if the Component y is registered.
         """
-
         components = self.components.copy()
         return y in components or y in [c.__class__ for c in components]
 
     def __len__(self):
-        """x.__len__() <==> len(x)
+        """
+        x.__len__() <==> len(x)
 
         Returns the number of events in the Event Queue.
         """
-
         return len(self._queue)
 
     def __add__(self, y):
-        """x.__add__(y) <==> x+y
+        """
+        x.__add__(y) <==> x+y
 
         (Optional) Convenience operator to register y with x
         Equivalent to: y.register(x)
@@ -295,12 +279,12 @@ class Manager(object):
         @return: x
         @rtype Component or Manager
         """
-
         y.register(self)
         return self
 
     def __iadd__(self, y):
-        """x.__iadd__(y) <==> x += y
+        """
+        x.__iadd__(y) <==> x += y
 
         (Optional) Convenience operator to register y with x
         Equivalent to: y.register(x)
@@ -308,12 +292,12 @@ class Manager(object):
         @return: x
         @rtype Component or Manager
         """
-
         y.register(self)
         return self
 
     def __sub__(self, y):
-        """x.__sub__(y) <==> x-y
+        """
+        x.__sub__(y) <==> x-y
 
         (Optional) Convenience operator to unregister y from x.parent
         Equivalent to: y.unregister()
@@ -321,13 +305,13 @@ class Manager(object):
         @return: x
         @rtype Component or Manager
         """
-
         if y.parent is not y:
             y.unregister()
         return self
 
     def __isub__(self, y):
-        """x.__sub__(y) <==> x -= y
+        """
+        x.__sub__(y) <==> x -= y
 
         (Optional) Convenience operator to unregister y from x
         Equivalent to: y.unregister()
@@ -335,7 +319,6 @@ class Manager(object):
         @return: x
         @rtype Component or Manager
         """
-
         if y.parent is not y:
             y.unregister()
         return self
@@ -343,19 +326,16 @@ class Manager(object):
     @property
     def name(self):
         """Return the name of this Component/Manager"""
-
         return self.__class__.__name__
 
     @property
     def running(self):
         """Return the running state of this Component/Manager"""
-
         return self._running
 
     @property
     def pid(self):
         """Return the process id of this Component/Manager"""
-
         return getpid() if self.__process is None else self.__process.pid
 
     def getHandlers(self, event, channel, **kwargs):
@@ -363,29 +343,25 @@ class Manager(object):
         handlers = set()
 
         _handlers = set()
-        _handlers.update(self._handlers.get("*", []))
+        _handlers.update(self._handlers.get('*', []))
         _handlers.update(self._handlers.get(name, []))
 
         for _handler in _handlers:
             handler_channel = _handler.channel
             if handler_channel is None:
-                # XXX: Why do we care about the event handler's channel?
+                # TODO: Why do we care about the event handler's channel?
                 #      This probably costs us performance for what?
                 #      I've not ever had to rely on this in practice...
                 handler_channel = getattr(
-                    getattr(
-                        _handler, "im_self", getattr(
-                            _handler, "__self__", _dummy
-                        )
-                    ),
-                    "channel", None
+                    getattr(_handler, 'im_self', getattr(_handler, '__self__', _dummy)),
+                    'channel',
+                    None,
                 )
 
-            if channel == "*" or handler_channel in ("*", channel,) \
-                    or channel is self:
+            if channel == '*' or handler_channel in ('*', channel) or channel is self:
                 handlers.add(_handler)
 
-        if not kwargs.get("exclude_globals", False):
+        if not kwargs.get('exclude_globals', False):
             handlers.update(self._globals)
 
         for c in self.components.copy():
@@ -394,14 +370,14 @@ class Manager(object):
         return handlers
 
     def addHandler(self, f):
-        method = create_bound_method(f, self) if isfunction(f) else f
+        method = types.MethodType(f, self) if isfunction(f) else f
 
         setattr(self, method.__name__, method)
 
-        if not method.names and method.channel == "*":
+        if not method.names and method.channel == '*':
             self._globals.add(method)
         elif not method.names:
-            self._handlers.setdefault("*", set()).add(method)
+            self._handlers.setdefault('*', set()).add(method)
         else:
             for name in method.names:
                 self._handlers.setdefault(name, set()).add(method)
@@ -411,10 +387,7 @@ class Manager(object):
         return method
 
     def removeHandler(self, method, event=None):
-        if event is None:
-            names = method.names
-        else:
-            names = [event]
+        names = method.names if event is None else [event]
 
         for name in names:
             self._handlers[name].remove(method)
@@ -444,11 +417,9 @@ class Manager(object):
 
     def _fire(self, event, channel, priority=0):
         # check if event is fired while handling an event
-        th = (self._executing_thread or self._flushing_thread)
-        if thread.get_ident() == (th.ident if th else None) and \
-                not isinstance(event, signal):
-            if self._currently_handling is not None and \
-                    getattr(self._currently_handling, "cause", None):
+        th = self._executing_thread or self._flushing_thread
+        if _thread.get_ident() == (th.ident if th else None) and not isinstance(event, signal):
+            if self._currently_handling is not None and getattr(self._currently_handling, 'cause', None):
                 # if the currently handled event wants to track the
                 # events generated by it, do the tracking now
                 event.cause = self._currently_handling
@@ -478,7 +449,8 @@ class Manager(object):
                     handling.reduce_time_left(0)
 
     def fireEvent(self, event, *channels, **kwargs):
-        """Fire an event into the system.
+        """
+        Fire an event into the system.
 
         :param event: The event that is to be fired.
         :param channels: The channels that this event is delivered on.
@@ -489,9 +461,8 @@ class Manager(object):
            when set neither, the event is delivered on all
            channels ("*").
         """
-
         if not channels:
-            channels = event.channels or (getattr(self, "channel", "*"),) or ("*",)
+            channels = event.channels or (getattr(self, 'channel', '*'),)
 
         event.channels = channels
 
@@ -510,7 +481,7 @@ class Manager(object):
             self.root._tasks.remove(g)
 
     def waitEvent(self, event, *channels, **kwargs):  # noqa
-        # XXX: C901: This has a high McCabe complexity score of 16.
+        # TODO: C901: This has a high McCabe complexity score of 16.
         # TODO: Refactor this method.
 
         if isinstance(event, Event):
@@ -521,12 +492,10 @@ class Manager(object):
             event_object = None
             event_name = event
 
-        state = _State(timeout=kwargs.get("timeout", -1))
+        state = _State(timeout=kwargs.get('timeout', -1))
 
         def _on_event(self, event, *args, **kwargs):
-            if not state.run and (
-                    event_object is None or event is event_object
-            ):
+            if not state.run and (event_object is None or event is event_object):
                 self.removeHandler(_on_event_handler, event_name)
                 event.alert_done = True
                 state.run = True
@@ -537,7 +506,7 @@ class Manager(object):
                 state.flag = True
                 self.registerTask((state.task_event, state.task, state.parent))
                 if state.timeout > 0:
-                    self.removeHandler(state.tick_handler, "generate_events")
+                    self.removeHandler(state.tick_handler, 'generate_events')
 
         def _on_tick(self):
             if state.timeout == 0:
@@ -545,11 +514,11 @@ class Manager(object):
                     (
                         state.task_event,
                         (e for e in (ExceptionWrapper(TimeoutError()),)),
-                        state.parent
-                    )
+                        state.parent,
+                    ),
                 )
-                self.removeHandler(_on_done_handler, "%s_done" % event_name)
-                self.removeHandler(_on_tick_handler, "generate_events")
+                self.removeHandler(_on_done_handler, '%s_done' % event_name)
+                self.removeHandler(_on_tick_handler, 'generate_events')
             elif state.timeout > 0:
                 state.timeout -= 1
 
@@ -557,17 +526,14 @@ class Manager(object):
             channels = (None,)
 
         for channel in channels:
-            _on_event_handler = self.addHandler(
-                handler(event_name, channel=channel)(_on_event))
-            _on_done_handler = self.addHandler(
-                handler("%s_done" % event_name, channel=channel)(_on_done))
+            _on_event_handler = self.addHandler(handler(event_name, channel=channel)(_on_event))
+            _on_done_handler = self.addHandler(handler('%s_done' % event_name, channel=channel)(_on_done))
             if state.timeout >= 0:
-                _on_tick_handler = state.tick_handler = self.addHandler(
-                    handler("generate_events", channel=channel)(_on_tick))
+                _on_tick_handler = state.tick_handler = self.addHandler(handler('generate_events', channel=channel)(_on_tick))
 
         yield state
 
-        self.removeHandler(_on_done_handler, "%s_done" % event_name)
+        self.removeHandler(_on_done_handler, '%s_done' % event_name)
 
         if state.event is not None:
             yield CallValue(state.event.value)
@@ -585,8 +551,7 @@ class Manager(object):
         been dispatched (see :func:`circuits.core.handlers.handler`).
         """
         value = self.fire(event, *channels)
-        for r in self.waitEvent(event, *event.channels, **kwargs):
-            yield r
+        yield from self.waitEvent(event, *event.channels, **kwargs)
         yield CallValue(value)
 
     call = callEvent
@@ -607,20 +572,19 @@ class Manager(object):
         that is not the root of an object hierarchy, the invocation
         is delegated to the root manager.
         """
-
         self.root._flush()
 
     flush = flushEvents
 
     def _dispatcher(self, event, channels, remaining):  # noqa
-        # XXX: C901: This has a high McCabe complexity score of 22.
+        # TODO: C901: This has a high McCabe complexity score of 22.
         # TODO: Refactor this method.
 
         if event.cancelled:
             return
 
         if event.complete:
-            if not getattr(event, "cause", None):
+            if not getattr(event, 'cause', None):
                 event.cause = event
             event.effects = 1  # event itself counts (must be done)
         eargs = event.args
@@ -638,18 +602,21 @@ class Manager(object):
 
             event_handlers = sorted(
                 chain(*h),
-                key=attrgetter("priority"),
-                reverse=True
+                key=attrgetter('priority'),
+                reverse=True,
             )
 
             if isinstance(event, generate_events):
                 from .helpers import FallBackGenerator
+
                 event_handlers.append(FallBackGenerator()._on_generate_events)
             elif isinstance(event, exception) and len(event_handlers) == 0:
                 from .helpers import FallBackExceptionHandler
+
                 event_handlers.append(FallBackExceptionHandler()._on_exception)
             elif isinstance(event, signal) and len(event_handlers) == 0:
                 from .helpers import FallBackSignalHandler
+
                 event_handlers.append(FallBackSignalHandler()._on_signal)
 
             self._cache[(event.name, channels)] = event_handlers
@@ -673,10 +640,7 @@ class Manager(object):
         for event_handler in event_handlers:
             event.handler = event_handler
             try:
-                if event_handler.event:
-                    value = event_handler(event, *eargs, **ekwargs)
-                else:
-                    value = event_handler(*eargs, **ekwargs)
+                value = event_handler(event, *eargs, **ekwargs) if event_handler.event else event_handler(*eargs, **ekwargs)
             except KeyboardInterrupt:
                 self.stop()
             except SystemExit as e:
@@ -686,10 +650,7 @@ class Manager(object):
                 event.value.errors = True
 
                 if event.failure:
-                    self.fire(
-                        event.child("failure", event, err),
-                        *event.channels
-                    )
+                    self.fire(event.child('failure', event, err), *event.channels)
 
                 self.fire(exception(*err, handler=event_handler, fevent=event))
 
@@ -721,17 +682,15 @@ class Manager(object):
         # interested in being notified about the last handler for
         # an event having been invoked.
         if event.alert_done:
-            self.fire(event.child("done", event.value.value), *event.channels)
+            self.fire(event.child('done', event.value.value), *event.channels)
 
         if err is None and event.success:
-            channels = getattr(event, "success_channels", event.channels)
-            self.fire(
-                event.child("success", event, event.value.value), *channels
-            )
+            channels = getattr(event, 'success_channels', event.channels)
+            self.fire(event.child('success', event, event.value.value), *channels)
 
         while True:
             # cause attributes indicates interest in completion event
-            cause = getattr(event, "cause", None)
+            cause = getattr(event, 'cause', None)
             if not cause:
                 break
             # event takes part in complete detection (as nested or root event)
@@ -740,13 +699,13 @@ class Manager(object):
                 break  # some nested events remain to be completed
             if event.complete:  # does this event want signaling?
                 self.fire(
-                    event.child("complete", event, event.value.value),
-                    *getattr(event, "complete_channels", event.channels)
+                    event.child('complete', event, event.value.value),
+                    *getattr(event, 'complete_channels', event.channels),
                 )
 
             # this event and nested events are done now
-            delattr(event, "cause")
-            delattr(event, "effects")
+            delattr(event, 'cause')
+            delattr(event, 'effects')
             # cause has one of its nested events done, decrement and check
             event = cause
 
@@ -759,12 +718,11 @@ class Manager(object):
         ``run()`` method. The invocation of this method returns
         immediately after the task or process has been started.
         """
-
         if process:
             # Parent<->Child Bridge
             if link is not None:
-                from circuits.net.sockets import Pipe
                 from circuits.core.bridge import Bridge
+                from circuits.net.sockets import Pipe
 
                 channels = (uuid(),) * 2
                 parent, child = Pipe(*channels)
@@ -775,19 +733,16 @@ class Manager(object):
                 args = ()
                 bridge = None
 
-            self.__process = Process(
-                target=self.run, args=args, name=self.name
-            )
+            self.__process = Process(target=self.run, args=args, name=self.name)
             self.__process.daemon = True
             self.__process.start()
 
             return self.__process, bridge
-        else:
-            self.__thread = Thread(target=self.run, name=self.name)
-            self.__thread.daemon = True
-            self.__thread.start()
+        self.__thread = Thread(target=self.run, name=self.name)
+        self.__thread.daemon = True
+        self.__thread.start()
 
-            return self.__thread, None
+        return self.__thread, None
 
     def join(self):
         if self.__thread is not None:
@@ -795,13 +750,13 @@ class Manager(object):
 
         if self.__process is not None:
             return self.__process.join()
+        return None
 
     def stop(self, code=None):
         """
         Stop this manager. Invoking this method causes
         an invocation of ``run()`` to return.
         """
-
         if self.__process not in (None, current_process()) and self.__process.is_alive():
             self.__process.terminate()
             self.__process.join(TIMEOUT)
@@ -824,7 +779,7 @@ class Manager(object):
             raise SystemExit(code)
 
     def processTask(self, event, task, parent=None):  # noqa
-        # XXX: C901: This has a high McCabe complexity score of 16.
+        # TODO: C901: This has a high McCabe complexity score of 16.
         # TODO: Refactor this method.
 
         value = None
@@ -862,7 +817,7 @@ class Manager(object):
                 # The below code is delegated to handlers
                 # in the waitEvent generator
                 # self.registerTask((event, value, task))
-                # XXX: ^^^ Why is this commented out anyway?
+                # TODO: ^^^ Why is this commented out anyway?
             elif isinstance(value, ExceptionWrapper):
                 self.unregisterTask((event, task, parent))
                 if parent:
@@ -885,8 +840,8 @@ class Manager(object):
 
             if parent:
                 self.registerTask((event, parent, None))
-            elif hasattr(task, "task"):
-                # XXX: The subtask is considered a "waiting handler"
+            elif hasattr(task, 'task'):
+                # TODO: The subtask is considered a "waiting handler"
                 event.waitingHandlers += 1
                 self.registerTask(task.task)
             elif event.waitingHandlers == 0:
@@ -906,7 +861,7 @@ class Manager(object):
             event.value.inform(True)
 
             if event.failure:
-                self.fire(event.child("failure", event, err), *event.channels)
+                self.fire(event.child('failure', event, err), *event.channels)
 
             self.fire(exception(*err, handler=None, fevent=event))
 
@@ -930,7 +885,7 @@ class Manager(object):
                 self.processTask(*task)
 
         if self._running:
-            self.fire(generate_events(self._lock, timeout), "*")
+            self.fire(generate_events(self._lock, timeout), '*')
 
         if len(self._queue):
             self.flush()
@@ -949,10 +904,9 @@ class Manager(object):
         fires the corresponding :class:`~.events.Signal`
         events and then calls :meth:`~.stop` for the manager.
         """
-
         atexit.register(self.stop)
 
-        if current_thread().getName() == "MainThread":
+        if current_thread().name == 'MainThread':
             try:
                 set_signal_handler(SIGINT, self._signal_handler)
                 set_signal_handler(SIGTERM, self._signal_handler)
@@ -967,6 +921,7 @@ class Manager(object):
 
         if socket is not None:
             from circuits.core.bridge import Bridge
+
             Bridge(socket, channel=socket.channel).register(self)
 
         self.fire(started(self))
@@ -978,13 +933,11 @@ class Manager(object):
             for _ in range(3):
                 self.tick()
         except Exception as exc:
-            stderr.write("Unhandled ERROR: {}\n".format(exc))
+            stderr.write(f'Unhandled ERROR: {exc}\n')
             stderr.write(format_exc())
         finally:
-            try:
+            with contextlib.suppress(Exception):
                 self.tick()
-            except Exception:
-                pass
 
         self.root._executing_thread = None
         self.__thread = None
