@@ -9,8 +9,8 @@ from .components import BaseComponent
 
 
 class Timer(BaseComponent):
-
-    """Timer Component
+    """
+    Timer Component
 
     A timer is a component that fires an event once after a certain
     delay or periodically at a regular interval.
@@ -35,18 +35,17 @@ class Timer(BaseComponent):
                          the timer is unregistered. **Default:** ``False``
         :type persist:   ``bool``
         """
-
-        super(Timer, self).__init__()
+        super().__init__()
 
         self.expiry = None
         self.interval = None
         self.event = event
         self.channels = channels
-        self.persist = kwargs.get("persist", False)
+        self.persist = kwargs.get('persist', False)
 
         self.reset(interval)
 
-    @handler("generate_events")
+    @handler('generate_events')
     def _on_generate_events(self, event):
         if self.expiry is None:
             return
@@ -71,7 +70,6 @@ class Timer(BaseComponent):
         Reset the timer, i.e. clear the amount of time already waited
         for.
         """
-
         if interval is not None and isinstance(interval, datetime):
             self.interval = mktime(interval.timetuple()) - time()
         elif interval is not None:
@@ -81,7 +79,7 @@ class Timer(BaseComponent):
 
     @property
     def expiry(self):
-        return getattr(self, "_expiry", None)
+        return getattr(self, '_expiry', None)
 
     @expiry.setter
     def expiry(self, seconds):
