@@ -1,9 +1,11 @@
-"""Utils
+"""
+Utils
 
 This module defines utilities used by circuits.
 """
+
 import sys
-from imp import reload
+from importlib import reload
 
 
 def flatten(root, visited=None):
@@ -13,30 +15,29 @@ def flatten(root, visited=None):
     for component in root.components.copy():
         if component not in visited:
             visited.add(component)
-            for child in flatten(component, visited):
-                yield child
+            yield from flatten(component, visited)
 
 
 def findchannel(root, channel, all=False):
-    components = [x for x in flatten(root)
-                  if x.channel == channel]
+    components = [x for x in flatten(root) if x.channel == channel]
 
     if all:
         return components
 
     if components:
         return components[0]
+    return None
 
 
 def findtype(root, component, all=False):
-    components = [x for x in flatten(root)
-                  if issubclass(type(x), component)]
+    components = [x for x in flatten(root) if issubclass(type(x), component)]
 
     if all:
         return components
 
     if components:
         return components[0]
+    return None
 
 
 findcmp = findtype
@@ -45,8 +46,7 @@ findcmp = findtype
 def findroot(component):
     if component.parent == component:
         return component
-    else:
-        return findroot(component.parent)
+    return findroot(component.parent)
 
 
 def safeimport(name):
@@ -54,8 +54,7 @@ def safeimport(name):
     try:
         if name in sys.modules:
             return reload(sys.modules[name])
-        else:
-            return __import__(name, globals(), locals(), [""])
+        return __import__(name, globals(), locals(), [''])
     except Exception:
         for name in sys.modules.copy():
             if name not in modules:
