@@ -1,14 +1,11 @@
-"""
-This defines the Value object used by components and events.
-"""
-from ..six import PY2, python_2_unicode_compatible, string_types, text_type
+"""This defines the Value object used by components and events."""
+
 from .events import Event
 
 
-@python_2_unicode_compatible
-class Value(object):
-
-    """Create a new future Value Object
+class Value:
+    """
+    Create a new future Value Object
 
     Creates a new future Value Object which is used by Event Objects and the
     Manager to store the result(s) of an Event Handler's exeuction of some
@@ -43,7 +40,7 @@ class Value(object):
 
     def __getstate__(self):
         odict = self.__dict__.copy()
-        del odict["manager"]
+        del odict['manager']
         return odict
 
     def __contains__(self, y):
@@ -54,40 +51,32 @@ class Value(object):
         v = self.value[y]
         if isinstance(v, Value):
             return v.value
-        else:
-            return v
+        return v
 
     def __iter__(self):
-        return iter(map(lambda v: v.value if isinstance(v, Value) else v,
-                        self.value))
+        return iter((v.value if isinstance(v, Value) else v for v in self.value))
 
     def __repr__(self):
-        "x.__repr__() <==> repr(x)"
-
-        value = ""
+        """x.__repr__() <==> repr(x)"""
+        value = ''
         if self.result:
             value = repr(self.value)
 
-        format = "<Value (%s) result=%r; errors=%r; for %r>"
+        format = '<Value (%s) result=%r; errors=%r; for %r>'
         return format % (value, self.result, self.errors, self.event)
 
     def __str__(self):
-        "x.__str__() <==> str(x)"
-        if PY2:
-            return text_type(self.value).encode('utf-8')
+        """x.__str__() <==> str(x)"""
         return str(self.value)
 
     def inform(self, force=False):
         if self.promise and not force:
             return
 
-        notify = getattr(self.event, "notify", False) or self.notify
+        notify = getattr(self.event, 'notify', False) or self.notify
 
         if self.manager is not None and notify:
-            if isinstance(notify, string_types):
-                e = Event.create(notify, self)
-            else:
-                e = self.event.child("value_changed", self)
+            e = Event.create(notify, self) if isinstance(notify, str) else self.event.child('value_changed', self)
 
             self.manager.fire(e, self.manager)
 
@@ -130,4 +119,4 @@ class Value(object):
 
         update(self, value)
 
-    value = property(getValue, setValue, None, "Value of this Value")
+    value = property(getValue, setValue, None, 'Value of this Value')
