@@ -1,24 +1,37 @@
-"""File Notification Support
+"""
+File Notification Support
 
 A Component wrapping the inotify API using the pyinotify library.
 """
+
 try:
-    from pyinotify import IN_UNMOUNT
-    from pyinotify import WatchManager, Notifier, ALL_EVENTS
-    from pyinotify import IN_ACCESS, IN_MODIFY, IN_ATTRIB, IN_CLOSE_WRITE
-    from pyinotify import IN_CREATE, IN_DELETE, IN_DELETE_SELF, IN_MOVE_SELF
-    from pyinotify import IN_CLOSE_NOWRITE, IN_OPEN, IN_MOVED_FROM, IN_MOVED_TO
+    from pyinotify import (
+        ALL_EVENTS,
+        IN_ACCESS,
+        IN_ATTRIB,
+        IN_CLOSE_NOWRITE,
+        IN_CLOSE_WRITE,
+        IN_CREATE,
+        IN_DELETE,
+        IN_DELETE_SELF,
+        IN_MODIFY,
+        IN_MOVE_SELF,
+        IN_MOVED_FROM,
+        IN_MOVED_TO,
+        IN_OPEN,
+        IN_UNMOUNT,
+        Notifier,
+        WatchManager,
+    )
 except ImportError:
-    raise ImportError("No pyinotify support available. Is pyinotify installed?")
+    raise ImportError('No pyinotify support available. Is pyinotify installed?')
 
 from circuits.core import BaseComponent, handler
 from circuits.core.pollers import BasePoller, Poller
 from circuits.core.utils import findcmp
 
-from .events import (
-    accessed, closed, created, deleted, modified, moved, opened, ready,
-    unmounted,
-)
+from .events import accessed, closed, created, deleted, modified, moved, opened, ready, unmounted
+
 
 MASK = ALL_EVENTS
 
@@ -40,11 +53,10 @@ EVENT_MAP = {
 
 
 class Notify(BaseComponent):
-
-    channel = "notify"
+    channel = 'notify'
 
     def __init__(self, channel=channel):
-        super(Notify, self).__init__(channel=channel)
+        super().__init__(channel=channel)
 
         self._poller = None
         self._wm = WatchManager()
@@ -70,11 +82,11 @@ class Notify(BaseComponent):
         if wd:
             self._wm.rm_watch(wd, rec=recursive)
 
-    @handler("ready")
+    @handler('ready')
     def _on_ready(self, component):
         self._poller.addReader(self, self._notifier._fd)
 
-    @handler("registered", channel="*")
+    @handler('registered', channel='*')
     def _on_registered(self, component, manager):
         if self._poller is None:
             if isinstance(component, BasePoller):
@@ -91,14 +103,14 @@ class Notify(BaseComponent):
                     self._poller = Poller().register(self)
                     self.fire(ready(self))
 
-    @handler("started", channel="*", priority=1)
+    @handler('started', channel='*', priority=1)
     def _on_started(self, event, component):
         if self._poller is None:
             self._poller = Poller().register(self)
             self.fire(ready(self))
             event.stop()
 
-    @handler("_read", priority=1)
+    @handler('_read', priority=1)
     def __on_read(self, fd):
         self._notifier.read_events()
         self._notifier.process_events()
