@@ -1,7 +1,9 @@
-"""Process
+"""
+Process
 
 This module implements a wrapper for basic ``subprocess.Popen`` functionality.
 """
+
 from io import BytesIO
 from subprocess import PIPE, Popen
 
@@ -13,7 +15,8 @@ from .file import File
 
 
 class terminated(Event):
-    """terminated Event
+    """
+    terminated Event
 
     This Event is sent when a process is completed
 
@@ -22,12 +25,11 @@ class terminated(Event):
     """
 
     def __init__(self, *args):
-        super(terminated, self).__init__(*args)
+        super().__init__(*args)
 
 
 class Process(BaseComponent):
-
-    channel = "process"
+    channel = 'process'
 
     def init(self, args, cwd=None, shell=False):
         self.args = args
@@ -61,7 +63,7 @@ class Process(BaseComponent):
             shell=self.shell,
             stdin=PIPE,
             stderr=PIPE,
-            stdout=PIPE
+            stdout=PIPE,
         )
 
         self.stderr = BytesIO()
@@ -71,41 +73,41 @@ class Process(BaseComponent):
 
         self._stdin = File(
             self.p.stdin,
-            channel="{0:d}.stdin".format(self.p.pid)
+            channel=f'{self.p.pid:d}.stdin',
         ).register(self)
 
         self._stderr = File(
             self.p.stderr,
-            channel="{0:d}.stderr".format(self.p.pid)
+            channel=f'{self.p.pid:d}.stderr',
         ).register(self)
 
         self._stdout = File(
             self.p.stdout,
-            channel="{0:d}.stdout".format(self.p.pid)
+            channel=f'{self.p.pid:d}.stdout',
         ).register(self)
 
         self._stderr_read_handler = self.addHandler(
-            handler("read", channel=self._stderr.channel)(
-                lambda self, data: self.stderr.write(data)
-            )
+            handler('read', channel=self._stderr.channel)(
+                lambda self, data: self.stderr.write(data),
+            ),
         )
 
         self._stdout_read_handler = self.addHandler(
-            handler("read", channel=self._stdout.channel)(
-                lambda self, data: self.stdout.write(data)
-            )
+            handler('read', channel=self._stdout.channel)(
+                lambda self, data: self.stdout.write(data),
+            ),
         )
 
         self._stderr_closed_handler = self.addHandler(
-            handler("closed", channel=self._stderr.channel)(
-                lambda self: setattr(self, '_stderr_closed', True)
-            )
+            handler('closed', channel=self._stderr.channel)(
+                lambda self: setattr(self, '_stderr_closed', True),
+            ),
         )
 
         self._stdout_closed_handler = self.addHandler(
-            handler("closed", channel=self._stdout.channel)(
-                lambda self: setattr(self, '_stdout_closed', True)
-            )
+            handler('closed', channel=self._stdout.channel)(
+                lambda self: setattr(self, '_stdout_closed', True),
+            ),
         )
 
         self.fire(started(self))
@@ -124,20 +126,20 @@ class Process(BaseComponent):
         return self.p.wait()
 
     def write(self, data):
-        self.fire(write(data), "{0:d}.stdin".format(self.p.pid))
+        self.fire(write(data), f'{self.p.pid:d}.stdin')
 
     @property
     def status(self):
-        if getattr(self, "p", None) is not None:
+        if getattr(self, 'p', None) is not None:
             return self.p.poll()
+        return None
 
-    @handler("generate_events")
+    @handler('generate_events')
     def _on_generate_events(self, event):
         if self.p is not None and self._status is None:
             self._status = self.p.poll()
 
-        if self._status is not None and self._stderr_closed \
-                and self._stdout_closed and not self._terminated:
+        if self._status is not None and self._stderr_closed and self._stdout_closed and not self._terminated:
             self._terminated = True
             self.removeHandler(self._stderr_read_handler)
             self.removeHandler(self._stdout_read_handler)
