@@ -1,4 +1,5 @@
-"""Networking Components
+"""
+Networking Components
 
 This package contains components that implement network sockets and
 protocols for implementing client and server network applications.
