@@ -1,13 +1,15 @@
-"""Networking Events
+"""
+Networking Events
 
 This module implements commonly used Networking events used by socket components.
 """
+
 from circuits.core import Event
 
 
 class connect(Event):
-
-    """connect Event
+    """
+    connect Event
 
     This Event is sent when a new client connection has arrived on a server.
     This event is also used for client's to initiate a new connection to
@@ -24,14 +26,13 @@ class connect(Event):
     """
 
     def __init__(self, *args, **kwargs):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(connect, self).__init__(*args, **kwargs)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args, **kwargs)
 
 
 class disconnect(Event):
-
-    """disconnect Event
+    """
+    disconnect Event
 
     This Event is sent when a client connection has closed on a server.
     This event is also used for client's to disconnect from a remote host.
@@ -44,14 +45,13 @@ class disconnect(Event):
     """
 
     def __init__(self, *args, **kwargs):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(disconnect, self).__init__(*args, **kwargs)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args, **kwargs)
 
 
 class connected(Event):
-
-    """connected Event
+    """
+    connected Event
 
     This Event is sent when a client has successfully connected.
 
@@ -66,14 +66,13 @@ class connected(Event):
     """
 
     def __init__(self, host, port):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(connected, self).__init__(host, port)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(host, port)
 
 
 class disconnected(Event):
-
-    """disconnected Event
+    """
+    disconnected Event
 
     This Event is sent when a client has disconnected
 
@@ -82,14 +81,13 @@ class disconnected(Event):
     """
 
     def __init__(self):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(disconnected, self).__init__()
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__()
 
 
 class read(Event):
-
-    """read Event
+    """
+    read Event
 
     This Event is sent when a client or server connection has read any data.
 
@@ -101,14 +99,13 @@ class read(Event):
     """
 
     def __init__(self, *args):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(read, self).__init__(*args)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args)
 
 
 class error(Event):
-
-    """error Event
+    """
+    error Event
 
     This Event is sent when a client or server connection has an error.
 
@@ -120,14 +117,13 @@ class error(Event):
     """
 
     def __init__(self, *args):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(error, self).__init__(*args)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args)
 
 
 class unreachable(Event):
-
-    """unreachable Event
+    """
+    unreachable Event
 
     This Event is sent when a server is unreachable for a client
 
@@ -139,14 +135,13 @@ class unreachable(Event):
     """
 
     def __init__(self, host, port, reason=None):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(unreachable, self).__init__(host, port, reason)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(host, port, reason)
 
 
 class broadcast(Event):
-
-    """broadcast Event
+    """
+    broadcast Event
 
     This Event is used by the UDPServer/UDPClient sockets to send a message on the ``<broadcast>``
     network.
@@ -160,14 +155,13 @@ class broadcast(Event):
     """
 
     def __init__(self, *args):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(broadcast, self).__init__(*args)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args)
 
 
 class write(Event):
-
-    """write Event
+    """
+    write Event
 
     This Event is used to notify a client, client connection or server that
     we have data to be written.
@@ -181,14 +175,13 @@ class write(Event):
     """
 
     def __init__(self, *args):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(write, self).__init__(*args)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args)
 
 
 class close(Event):
-
-    """close Event
+    """
+    close Event
 
     This Event is used to notify a client, client connection or server that
     we want to close.
@@ -202,14 +195,13 @@ class close(Event):
     """
 
     def __init__(self, *args):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(close, self).__init__(*args)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args)
 
 
 class ready(Event):
-
-    """ready Event
+    """
+    ready Event
 
     This Event is used to notify the rest of the system that the underlying
     Client or Server Component is ready to begin processing connections or
@@ -228,15 +220,14 @@ class ready(Event):
     """
 
     def __init__(self, component, bind=None):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
         args = (component, bind) if bind is not None else (component,)
-        super(ready, self).__init__(*args)
+        super().__init__(*args)
 
 
 class closed(Event):
-
-    """closed Event
+    """
+    closed Event
 
     This Event is sent when a server has closed its listening socket.
 
@@ -246,8 +237,8 @@ class closed(Event):
 
 
 class starttls(Event):
-
-    """starttls Event
+    """
+    starttls Event
 
     This event can be fired to upgrade the socket connection to a TLS
     secured connection.
@@ -260,4 +251,4 @@ class starttls(Event):
     """
 
     def __init__(self, sock):
-        super(starttls, self).__init__(sock)
+        super().__init__(sock)
