@@ -1,18 +1,48 @@
-"""Socket Components
+"""
+Socket Components
 
 This module contains various Socket Components for use with Networking.
 """
+
+import contextlib
 import os
 import select
 from collections import defaultdict, deque
 from errno import (
-    EAGAIN, EALREADY, EBADF, ECONNABORTED, EINPROGRESS, EINTR, EINVAL, EISCONN,
-    EMFILE, ENFILE, ENOBUFS, ENOMEM, ENOTCONN, EPERM, EPIPE, EWOULDBLOCK,
+    EAGAIN,
+    EALREADY,
+    EBADF,
+    ECONNABORTED,
+    EINPROGRESS,
+    EINTR,
+    EINVAL,
+    EISCONN,
+    EMFILE,
+    ENFILE,
+    ENOBUFS,
+    ENOMEM,
+    ENOTCONN,
+    EPERM,
+    EPIPE,
+    EWOULDBLOCK,
 )
 from socket import (
-    AF_INET, AF_INET6, IPPROTO_IP, IPPROTO_TCP, SO_BROADCAST, SO_REUSEADDR,
-    SOCK_DGRAM, SOCK_STREAM, SOL_SOCKET, TCP_NODELAY, error as SocketError,
-    gaierror, getaddrinfo, getfqdn, gethostbyname, gethostname, socket,
+    AF_INET,
+    AF_INET6,
+    IPPROTO_IP,
+    IPPROTO_TCP,
+    SO_BROADCAST,
+    SO_REUSEADDR,
+    SOCK_DGRAM,
+    SOCK_STREAM,
+    SOL_SOCKET,
+    TCP_NODELAY,
+    gaierror,
+    getaddrinfo,
+    getfqdn,
+    gethostbyname,
+    gethostname,
+    socket,
 )
 from time import time
 
@@ -21,39 +51,81 @@ from _socket import socket as SocketType
 from circuits.core import BaseComponent, handler
 from circuits.core.pollers import BasePoller, Poller
 from circuits.core.utils import findcmp
-from circuits.six import binary_type
 
-from .events import (
-    close, closed, connect, connected, disconnect, disconnected, error, read,
-    ready, unreachable, write,
-)
+from .events import close, closed, connect, connected, disconnect, disconnected, error, read, ready, unreachable, write
+
 
 try:
     from socket import AF_UNIX
 except ImportError:
     AF_UNIX = None
 
+try:
+    from socket import socketpair
+except ImportError:
+    socketpair = None
 
 try:
-    from ssl import wrap_socket as ssl_socket
-    from ssl import CERT_NONE, PROTOCOL_SSLv23
-    from ssl import SSLError, SSL_ERROR_WANT_WRITE, SSL_ERROR_WANT_READ
+    from ssl import (
+        CERT_NONE,
+        CERT_REQUIRED,
+        PROTOCOL_TLS,
+        SSL_ERROR_WANT_READ,
+        SSL_ERROR_WANT_WRITE,
+        Purpose,
+        SSLContext,
+        SSLError,
+        create_default_context,
+    )
 
     HAS_SSL = 1
 except ImportError:
     import warnings
-    warnings.warn("No SSL support available.")
+
+    warnings.warn('No SSL support available.')
     HAS_SSL = 0
     CERT_NONE = None
-    PROTOCOL_SSLv23 = None
+    PROTOCOL_TLS = None
 
 
 BUFSIZE = 4096  # 4KB Buffer
 BACKLOG = 5000  # 5K Concurrent Connections
 
 
+def wrap_socket(
+    sock,
+    keyfile=None,
+    certfile=None,
+    ca_certs=None,
+    purpose=Purpose.SERVER_AUTH,
+    verify_mode=None,
+    minimum_version=PROTOCOL_TLS,
+    check_hostname=None,
+    **kwargs,
+):
+    if minimum_version != PROTOCOL_TLS:
+        context = SSLContext(minimum_version)
+        if purpose == Purpose.SERVER_AUTH:
+            context.verify_mode = CERT_REQUIRED
+            context.check_hostname = True
+        if ca_certs:
+            context.load_verify_locations(cafile=ca_certs)
+    else:
+        context = create_default_context(purpose, cafile=ca_certs)
+    if check_hostname is not None:
+        context.check_hostname = check_hostname
+    if verify_mode:
+        if verify_mode == CERT_NONE:
+            context.check_hostname = False
+        context.verify_mode = verify_mode
+    if certfile:
+        context.load_cert_chain(certfile=certfile, keyfile=keyfile)
+    return context.wrap_socket(sock, **kwargs)
+
+
 def do_handshake(sock, on_done=None, on_error=None, extra_args=None):
-    """SSL Async Handshake
+    """
+    SSL Async Handshake
 
     :param on_done: Function called when handshake is complete
     :type on_done: :function:
@@ -61,7 +133,6 @@ def do_handshake(sock, on_done=None, on_error=None, extra_args=None):
     :param on_error: Function called when handshake errored
     :type on_error: :function:
     """
-
     extra_args = extra_args or ()
 
     while True:
@@ -83,8 +154,7 @@ def do_handshake(sock, on_done=None, on_error=None, extra_args=None):
 
 
 class Client(BaseComponent):
-
-    channel = "client"
+    channel = 'client'
 
     socket_family = AF_INET
     socket_type = SOCK_STREAM
@@ -92,7 +162,7 @@ class Client(BaseComponent):
     socket_options = []
 
     def __init__(self, bind=None, bufsize=BUFSIZE, channel=channel, **kwargs):
-        super(Client, self).__init__(channel=channel, **kwargs)
+        super().__init__(channel=channel, **kwargs)
 
         if isinstance(bind, SocketType):
             self._bind = bind.getsockname()
@@ -121,9 +191,9 @@ class Client(BaseComponent):
 
     @property
     def connected(self):
-        return getattr(self, "_connected", None)
+        return getattr(self, '_connected', None)
 
-    @handler("registered", "started", channel="*")
+    @handler('registered', 'started', channel='*')
     def _on_registered_or_started(self, component, manager=None):
         if self._poller is None:
             if isinstance(component, BasePoller):
@@ -140,16 +210,16 @@ class Client(BaseComponent):
                     self._poller = Poller().register(self)
                     self.fire(ready(self))
 
-    @handler("stopped", channel="*")
+    @handler('stopped', channel='*')
     def _on_stopped(self, component):
         self.fire(close())
 
-    @handler("read_value_changed")
+    @handler('read_value_changed')
     def _on_read_value_changed(self, value):
-        if isinstance(value, binary_type):
+        if isinstance(value, bytes):
             self.fire(write(value))
 
-    @handler("prepare_unregister", channel="*")
+    @handler('prepare_unregister', channel='*')
     def _on_prepare_unregister(self, event, c):
         if event.in_subtree(self):
             self._close()
@@ -164,18 +234,14 @@ class Client(BaseComponent):
         self._closeflag = False
         self._connected = False
 
-        try:
+        with contextlib.suppress(OSError):
             self._sock.shutdown(2)
-        except SocketError:
-            pass
-        try:
+        with contextlib.suppress(OSError):
             self._sock.close()
-        except SocketError:
-            pass
 
         self.fire(disconnected())
 
-    @handler("close")
+    @handler('close')
     def close(self):
         if not self._buffer:
             self._close()
@@ -185,10 +251,7 @@ class Client(BaseComponent):
     def _read(self):
         try:
             try:
-                if self.secure and self._ssock:
-                    data = self._ssock.read(self._bufsize)
-                else:
-                    data = self._sock.recv(self._bufsize)
+                data = self._ssock.read(self._bufsize) if self.secure and self._ssock else self._sock.recv(self._bufsize)
             except SSLError as exc:
                 if exc.errno in (SSL_ERROR_WANT_READ, SSL_ERROR_WANT_WRITE):
                     return
@@ -198,43 +261,39 @@ class Client(BaseComponent):
                 self.fire(read(data)).notify = True
             else:
                 self.close()
-        except SocketError as e:
+        except OSError as e:
             if e.args[0] == EWOULDBLOCK:
                 return
-            else:
-                self.fire(error(e))
-                self._close()
+            self.fire(error(e))
+            self._close()
 
     def _write(self, data):
         try:
-            if self.secure and self._ssock:
-                nbytes = self._ssock.write(data)
-            else:
-                nbytes = self._sock.send(data)
+            nbytes = self._ssock.write(data) if self.secure and self._ssock else self._sock.send(data)
 
             if nbytes < len(data):
                 self._buffer.appendleft(data[nbytes:])
-        except SocketError as e:
+        except OSError as e:
             if e.args[0] in (EPIPE, ENOTCONN):
                 self._close()
             else:
                 self.fire(error(e))
 
-    @handler("write")
+    @handler('write')
     def write(self, data):
         if not self._poller.isWriting(self._sock):
             self._poller.addWriter(self, self._sock)
         self._buffer.append(data)
 
-    @handler("_disconnect", priority=1)
+    @handler('_disconnect', priority=1)
     def __on_disconnect(self, sock):
         self._close()
 
-    @handler("_read", priority=1)
+    @handler('_read', priority=1)
     def __on_read(self, sock):
         self._read()
 
-    @handler("_write", priority=1)
+    @handler('_write', priority=1)
     def __on_write(self, sock):
         if self._buffer:
             data = self._buffer.popleft()
@@ -258,7 +317,6 @@ class Client(BaseComponent):
 
 
 class TCPClient(Client):
-
     socket_family = AF_INET
     socket_type = SOCK_STREAM
     socket_protocol = IPPROTO_TCP
@@ -269,9 +327,9 @@ class TCPClient(Client):
     def init(self, connect_timeout=5, *args, **kwargs):
         self.connect_timeout = connect_timeout
 
-    @handler("connect")  # noqa
+    @handler('connect')  # noqa
     def connect(self, host, port, secure=False, **kwargs):
-        # XXX: C901: This has a high McCacbe complexity score of 10.
+        # TODO: C901: This has a high McCacbe complexity score of 10.
         # TODO: Refactor this!
 
         self.host = host
@@ -279,14 +337,14 @@ class TCPClient(Client):
         self.secure = secure
 
         if self.secure:
-            self.certfile = kwargs.get("certfile", None)
-            self.keyfile = kwargs.get("keyfile", None)
-            self.ca_certs = kwargs.get("ca_certs", None)
+            self.certfile = kwargs.get('certfile', None)
+            self.keyfile = kwargs.get('keyfile', None)
+            self.ca_certs = kwargs.get('ca_certs', None)
 
         try:
             r = self._sock.connect((host, port))
-        except SocketError as e:
-            if e.args[0] in (EBADF, EINVAL,):
+        except OSError as e:
+            if e.args[0] in (EBADF, EINVAL):
                 self._sock = self._create_socket()
                 r = self._sock.connect_ex((host, port))
             else:
@@ -316,13 +374,19 @@ class TCPClient(Client):
             self.fire(connected(host, port))
 
         if self.secure:
+
             def on_error(sock, err):
                 self.fire(error(sock, err))
                 self._close()
 
-            self._sock = ssl_socket(
-                self._sock, self.keyfile, self.certfile, ca_certs=self.ca_certs,
-                do_handshake_on_connect=False
+            self._sock = wrap_socket(
+                self._sock,
+                self.keyfile,
+                self.certfile,
+                ca_certs=self.ca_certs,
+                purpose=Purpose.SERVER_AUTH,
+                server_hostname=self.host,
+                do_handshake_on_connect=False,
             )
             for _ in do_handshake(self._sock, on_done, on_error):
                 yield
@@ -331,7 +395,6 @@ class TCPClient(Client):
 
 
 class TCP6Client(TCPClient):
-
     socket_family = AF_INET6
 
     def parse_bind_parameter(self, bind_parameter):
@@ -339,32 +402,31 @@ class TCP6Client(TCPClient):
 
 
 class UNIXClient(Client):
-
     socket_family = AF_UNIX
     socket_type = SOCK_STREAM
     socket_options = []
 
-    @handler("ready")
+    @handler('ready')
     def ready(self, component):
         if self._poller is not None and self._connected:
             self._poller.addReader(self, self._sock)
 
-    @handler("connect")  # noqa
+    @handler('connect')  # noqa
     def connect(self, path, secure=False, **kwargs):
-        # XXX: C901: This has a high McCacbe complexity score of 10.
+        # TODO: C901: This has a high McCacbe complexity score of 10.
         # TODO: Refactor this!
 
         self.path = path
         self.secure = secure
 
         if self.secure:
-            self.certfile = kwargs.get("certfile", None)
-            self.keyfile = kwargs.get("keyfile", None)
-            self.ca_certs = kwargs.get("ca_certs", None)
+            self.certfile = kwargs.get('certfile', None)
+            self.keyfile = kwargs.get('keyfile', None)
+            self.ca_certs = kwargs.get('ca_certs', None)
 
         try:
             r = self._sock.connect_ex(path)
-        except SocketError as e:
+        except OSError as e:
             r = e.args[0]
 
         if r:
@@ -379,15 +441,21 @@ class UNIXClient(Client):
         self._poller.addReader(self, self._sock)
 
         if self.secure:
+
             def on_done(sock):
                 self.fire(connected(gethostname(), path))
 
             def on_error(sock, err):
                 self.fire(error(err))
 
-            self._ssock = ssl_socket(
-                self._sock, self.keyfile, self.certfile, ca_certs=self.ca_certs,
-                do_handshake_on_connect=False
+            self._ssock = wrap_socket(
+                self._sock,
+                self.keyfile,
+                self.certfile,
+                ca_certs=self.ca_certs,
+                purpose=Purpose.SERVER_AUTH,
+                server_hostname=self.host,
+                do_handshake_on_connect=False,
             )
             for _ in do_handshake(self._ssock, on_done, on_error):
                 yield
@@ -396,13 +464,11 @@ class UNIXClient(Client):
 
 
 class Server(BaseComponent):
-
-    channel = "server"
+    channel = 'server'
     socket_protocol = IPPROTO_IP
 
-    def __init__(self, bind, secure=False, backlog=BACKLOG,
-                 bufsize=BUFSIZE, channel=channel, **kwargs):
-        super(Server, self).__init__(channel=channel)
+    def __init__(self, bind, secure=False, backlog=BACKLOG, bufsize=BUFSIZE, channel=channel, **kwargs):
+        super().__init__(channel=channel)
 
         self.socket_options = self.socket_options[:] + kwargs.get('socket_options', [])
         self._bind = self.parse_bind_parameter(bind)
@@ -423,13 +489,13 @@ class Server(BaseComponent):
         self.__starttls = set()
 
         self.secure = secure
-        self.certfile = kwargs.get("certfile")
-        self.keyfile = kwargs.get("keyfile", None)
-        self.cert_reqs = kwargs.get("cert_reqs", CERT_NONE)
-        self.ssl_version = kwargs.get("ssl_version", PROTOCOL_SSLv23)
-        self.ca_certs = kwargs.get("ca_certs", None)
+        self.certfile = kwargs.get('certfile')
+        self.keyfile = kwargs.get('keyfile', None)
+        self.cert_reqs = kwargs.get('cert_reqs', CERT_NONE)
+        self.ssl_version = kwargs.get('ssl_version', PROTOCOL_TLS)
+        self.ca_certs = kwargs.get('ca_certs', None)
         if self.secure and not self.certfile:
-            raise RuntimeError("certfile must be specified for server-side operations")
+            raise RuntimeError('certfile must be specified for server-side operations')
 
     def parse_bind_parameter(self, bind_parameter):
         return parse_ipv4_parameter(bind_parameter)
@@ -440,27 +506,28 @@ class Server(BaseComponent):
 
     @property
     def host(self):
-        if getattr(self, "_sock", None) is not None:
+        if getattr(self, '_sock', None) is not None:
             try:
                 sockname = self._sock.getsockname()
                 if isinstance(sockname, tuple):
                     return sockname[0]
-                else:
-                    return sockname
-            except SocketError:
+                return sockname
+            except OSError:
                 return None
+        return None
 
     @property
     def port(self):
-        if getattr(self, "_sock", None) is not None:
+        if getattr(self, '_sock', None) is not None:
             try:
                 sockname = self._sock.getsockname()
                 if isinstance(sockname, tuple):
                     return sockname[1]
-            except SocketError:
+            except OSError:
                 return None
+        return None
 
-    @handler("registered", "started", channel="*")
+    @handler('registered', 'started', channel='*')
     def _on_registered_or_started(self, component, manager=None):
         if self._poller is None:
             if isinstance(component, BasePoller):
@@ -478,19 +545,19 @@ class Server(BaseComponent):
                 else:
                     try:
                         self._poller = Poller().register(self)
-                    except EnvironmentError as err:
+                    except OSError as err:
                         self.fire(error(err))
                     else:
                         self._poller.addReader(self, self._sock)
                         self.fire(ready(self, (self.host, self.port)))
 
-    @handler("stopped", channel="*")
+    @handler('stopped', channel='*')
     def _on_stopped(self, component):
         self.fire(close())
 
-    @handler("read_value_changed")
+    @handler('read_value_changed')
     def _on_read_value_changed(self, value):
-        if isinstance(value.value, binary_type):
+        if isinstance(value.value, bytes):
             sock = value.event.args[0]
             self.fire(write(sock, value.value))
 
@@ -514,18 +581,14 @@ class Server(BaseComponent):
         if sock in self.__starttls:
             self.__starttls.remove(sock)
 
-        try:
+        with contextlib.suppress(OSError):
             sock.shutdown(2)
-        except SocketError:
-            pass
-        try:
+        with contextlib.suppress(OSError):
             sock.close()
-        except SocketError:
-            pass
 
         self.fire(disconnect(sock))
 
-    @handler("close")
+    @handler('close')
     def close(self, sock=None):
         is_closed = sock is None
 
@@ -554,12 +617,11 @@ class Server(BaseComponent):
                 self.fire(read(sock, data)).notify = True
             else:
                 self.close(sock)
-        except SocketError as e:
+        except OSError as e:
             if e.args[0] == EWOULDBLOCK:
                 return
-            else:
-                self.fire(error(sock, e))
-                self._close(sock)
+            self.fire(error(sock, e))
+            self._close(sock)
 
     def _write(self, sock, data):
         if sock not in self._clients:
@@ -569,14 +631,14 @@ class Server(BaseComponent):
             nbytes = sock.send(data)
             if nbytes < len(data):
                 self._buffers[sock].appendleft(data[nbytes:])
-        except SocketError as e:
+        except OSError as e:
             if e.args[0] not in (EINTR, EWOULDBLOCK, ENOBUFS):
                 self.fire(error(sock, e))
                 self._close(sock)
             else:
                 self._buffers[sock].appendleft(data)
 
-    @handler("write")
+    @handler('write')
     def write(self, sock, data):
         if not self._poller.isWriting(sock):
             self._poller.addWriter(self, sock)
@@ -584,8 +646,8 @@ class Server(BaseComponent):
 
     def _accept(self):
         try:
-            newsock, host = self._sock.accept()
-        except SocketError as e:
+            newsock, _host = self._sock.accept()
+        except OSError as e:
             if e.args[0] in (EWOULDBLOCK, EAGAIN):
                 return
             elif e.args[0] == EPERM:
@@ -618,19 +680,19 @@ class Server(BaseComponent):
             self._on_accept_done(newsock)
 
     def _do_handshake(self, sock, fire_connect_event=True):
-        sslsock = ssl_socket(
+        sslsock = wrap_socket(
             sock,
-            server_side=True,
-            keyfile=self.keyfile,
+            self.keyfile,
+            self.certfile,
             ca_certs=self.ca_certs,
-            certfile=self.certfile,
-            cert_reqs=self.cert_reqs,
-            ssl_version=self.ssl_version,
-            do_handshake_on_connect=False
+            purpose=Purpose.CLIENT_AUTH,
+            verify_mode=self.cert_reqs,
+            minimum_version=self.ssl_version,
+            server_side=True,
+            do_handshake_on_connect=False,
         )
 
-        for _ in do_handshake(sslsock, self._on_accept_done, self._on_handshake_error, (fire_connect_event,)):
-            yield _
+        yield from do_handshake(sslsock, self._on_accept_done, self._on_handshake_error, (fire_connect_event,))
 
     def _on_accept_done(self, sock, fire_connect_event=True):
         sock.setblocking(False)
@@ -639,7 +701,7 @@ class Server(BaseComponent):
         if fire_connect_event:
             try:
                 self.fire(connect(sock, *sock.getpeername()))
-            except SocketError as exc:
+            except OSError as exc:
                 # errno 107 (ENOTCONN): the client already disconnected
                 self._on_handshake_error(sock, exc)
 
@@ -659,18 +721,18 @@ class Server(BaseComponent):
         for _ in self._do_handshake(sock, False):
             yield
 
-    @handler("_disconnect", priority=1)
+    @handler('_disconnect', priority=1)
     def _on_disconnect(self, sock):
         self._close(sock)
 
-    @handler("_read", priority=1)
+    @handler('_read', priority=1)
     def _on_read(self, sock):
         if sock == self._sock:
             return self._accept()
-        else:
-            self._read(sock)
+        self._read(sock)
+        return None
 
-    @handler("_write", priority=1)
+    @handler('_write', priority=1)
     def _on_write(self, sock):
         if self._buffers[sock]:
             data = self._buffers[sock].popleft()
@@ -695,7 +757,6 @@ class Server(BaseComponent):
 
 
 class TCPServer(Server):
-
     socket_family = AF_INET
     socket_type = SOCK_STREAM
     socket_options = [
@@ -704,7 +765,7 @@ class TCPServer(Server):
     ]
 
     def _create_socket(self):
-        sock = super(TCPServer, self)._create_socket()
+        sock = super()._create_socket()
         sock.listen(self._backlog)
 
         return sock
@@ -718,9 +779,9 @@ def parse_ipv4_parameter(bind_parameter):
         try:
             bind = (gethostbyname(gethostname()), bind_parameter)
         except gaierror:
-            bind = ("0.0.0.0", bind_parameter)
-    elif isinstance(bind_parameter, str) and ":" in bind_parameter:
-        host, port = bind_parameter.split(":")
+            bind = ('0.0.0.0', bind_parameter)
+    elif isinstance(bind_parameter, str) and ':' in bind_parameter:
+        host, port = bind_parameter.split(':')
         port = int(port)
         bind = (host, port)
     else:
@@ -732,10 +793,9 @@ def parse_ipv4_parameter(bind_parameter):
 def parse_ipv6_parameter(bind_parameter):
     if isinstance(bind_parameter, int):
         try:
-            _, _, _, _, bind \
-                = getaddrinfo(getfqdn(), bind_parameter, AF_INET6)[0]
+            _, _, _, _, bind = getaddrinfo(getfqdn(), bind_parameter, AF_INET6)[0]
         except (gaierror, IndexError):
-            bind = ("::", bind_parameter)
+            bind = ('::', bind_parameter)
     else:
         bind = bind_parameter
 
@@ -743,7 +803,6 @@ def parse_ipv6_parameter(bind_parameter):
 
 
 class TCP6Server(TCPServer):
-
     socket_family = AF_INET6
 
     def parse_bind_parameter(self, bind_parameter):
@@ -751,7 +810,6 @@ class TCP6Server(TCPServer):
 
 
 class UNIXServer(Server):
-
     socket_family = AF_UNIX
     socket_type = SOCK_STREAM
     socket_options = [
@@ -762,19 +820,18 @@ class UNIXServer(Server):
         if os.path.exists(self._bind):
             os.unlink(self._bind)
 
-        sock = super(UNIXServer, self)._create_socket()
+        sock = super()._create_socket()
         sock.listen(self._backlog)
 
         return sock
 
 
 class UDPServer(Server):
-
     socket_family = AF_INET
     socket_type = SOCK_DGRAM
     socket_options = [
         (SOL_SOCKET, SO_BROADCAST, 1),
-        (SOL_SOCKET, SO_REUSEADDR, 1)
+        (SOL_SOCKET, SO_REUSEADDR, 1),
     ]
 
     def _close(self, sock):
@@ -783,18 +840,14 @@ class UDPServer(Server):
         if sock in self._buffers:
             del self._buffers[sock]
 
-        try:
+        with contextlib.suppress(OSError):
             sock.shutdown(2)
-        except SocketError:
-            pass
-        try:
+        with contextlib.suppress(OSError):
             sock.close()
-        except SocketError:
-            pass
 
         self.fire(disconnect(sock))
 
-    @handler("close", override=True)
+    @handler('close', override=True)
     def close(self):
         self.fire(closed())
 
@@ -808,7 +861,7 @@ class UDPServer(Server):
             data, address = self._sock.recvfrom(self._bufsize)
             if data:
                 self.fire(read(address, data)).notify = True
-        except SocketError as e:
+        except OSError as e:
             if e.args[0] in (EWOULDBLOCK, EAGAIN):
                 return
             self.fire(error(self._sock, e))
@@ -819,31 +872,31 @@ class UDPServer(Server):
             bytes = self._sock.sendto(data, address)
             if bytes < len(data):
                 self._buffers[self._sock].appendleft(data[bytes:])
-        except SocketError as e:
+        except OSError as e:
             if e.args[0] in (EPIPE, ENOTCONN):
                 self._close(self._sock)
             else:
                 self.fire(error(self._sock, e))
 
-    @handler("write", override=True)
+    @handler('write', override=True)
     def write(self, address, data):
         if not self._poller.isWriting(self._sock):
             self._poller.addWriter(self, self._sock)
         self._buffers[self._sock].append((address, data))
 
-    @handler("broadcast", override=True)
+    @handler('broadcast', override=True)
     def broadcast(self, data, port):
-        self.write(("<broadcast>", port), data)
+        self.write(('<broadcast>', port), data)
 
-    @handler("_disconnect", priority=1, override=True)
+    @handler('_disconnect', priority=1, override=True)
     def _on_disconnect(self, sock):
         self._close(sock)
 
-    @handler("_read", priority=1, override=True)
+    @handler('_read', priority=1, override=True)
     def _on_read(self, sock):
         self._read()
 
-    @handler("_write", priority=1, override=True)
+    @handler('_write', priority=1, override=True)
     def _on_write(self, sock):
         if self._buffers[self._sock]:
             address, data = self._buffers[self._sock].popleft()
@@ -871,16 +924,17 @@ UDP6Client = UDP6Server
 
 
 def Pipe(*channels, **kwargs):
-    """Create a new full duplex Pipe
+    """
+    Create a new full duplex Pipe
 
     Returns a pair of UNIXClient instances connected on either side of
     the pipe.
     """
-
-    from socket import socketpair
+    if socketpair is None:
+        raise RuntimeError('No socketpair support available.')
 
     if not channels:
-        channels = ("a", "b")
+        channels = ('a', 'b')
 
     s1, s2 = socketpair()
     s1.setblocking(False)
