@@ -2,11 +2,9 @@ from circuits import Event
 
 
 class connected_to(Event):
-
     """Connected to a peer"""
 
-    def __init__(self, connection_name, hostname, port, client_channel,
-                 client_obj):
+    def __init__(self, connection_name, hostname, port, client_channel, client_obj):
         """
         :param connection_name:    Connection name.
         :type connection_name:     str
@@ -23,18 +21,14 @@ class connected_to(Event):
         :param client_obj:    Client object.
         :type client_obj:     :class:`circuits.net.sockets.Client`
         """
-        super(connected_to, self).__init__(
-            connection_name, hostname, port, client_channel, client_obj
-        )
+        super().__init__(connection_name, hostname, port, client_channel, client_obj)
 
 
 class disconnected_from(connected_to):
-
     """Disconnected from a peer"""
 
 
 class remote(Event):
-
     """send event to a peer"""
 
     def __init__(self, event, connection_name, channel=None):
@@ -48,4 +42,4 @@ class remote(Event):
         :param channel:    Remote channel (channel to use on peer).
         :type channel:     str
         """
-        super(remote, self).__init__(event, connection_name, channel=channel)
+        super().__init__(event, connection_name, channel=channel)
