@@ -1,3 +1,5 @@
+import contextlib
+
 from circuits import BaseComponent, handler
 from circuits.net.sockets import TCPServer
 
@@ -5,16 +7,16 @@ from .protocol import Protocol
 
 
 class Server(BaseComponent):
-
     """Node server."""
 
     channel = 'node'
     __protocols = {}
 
-    def __init__(self, port, server_ip='0.0.0.0', channel=channel,
-                 receive_event_firewall=None, send_event_firewall=None,
-                 **kwargs):
-        """Create server on node system.
+    def __init__(
+        self, port, server_ip='0.0.0.0', channel=channel, receive_event_firewall=None, send_event_firewall=None, **kwargs
+    ):
+        """
+        Create server on node system.
 
         :param port:    start server on this port.
         :type port:     int
@@ -42,7 +44,7 @@ class Server(BaseComponent):
         :type send_event_firewall:   function
         :type send_event_firewall:   method
         """
-        super(Server, self).__init__(channel=channel, **kwargs)
+        super().__init__(channel=channel, **kwargs)
 
         bind = (server_ip, port)
         self.server = TCPServer(bind, channel=self.channel, **kwargs)
@@ -51,7 +53,8 @@ class Server(BaseComponent):
         self.__send_event_firewall = send_event_firewall
 
     def send(self, event, sock, no_result=False):
-        """Send event to peer
+        """
+        Send event to peer
 
         :param event:    Event to execute remotely.
         :type event:     :class:`circuits.core.events.Event`
@@ -70,14 +73,13 @@ class Server(BaseComponent):
         iterator = self.__protocols[sock].send(event)
         if no_result:
             event.node_without_result = True
-            try:
+            with contextlib.suppress(StopIteration):
                 next(iterator)
-            except StopIteration:
-                pass
         return iterator
 
     def send_to(self, event, socks):
-        """Send event to multiple peer
+        """
+        Send event to multiple peer
 
         :param event:    Event to execute remotely.
         :type event:     :class:`circuits.core.events.Event`
@@ -89,7 +91,8 @@ class Server(BaseComponent):
             self.send(event, sock, no_result=True)
 
     def send_all(self, event):
-        """Send event to all peer
+        """
+        Send event to all peer
 
         :param event:    Event to execute remotely.
         :type event:     :class:`circuits.core.events.Event`
@@ -104,14 +107,17 @@ class Server(BaseComponent):
     def host(self):
         if hasattr(self, 'server'):
             return self.server.host
+        return None
 
     @property
     def port(self):
         if hasattr(self, 'server'):
             return self.server.port
+        return None
 
     def get_socks(self):
-        """Get clients sockets list
+        """
+        Get clients sockets list
 
         :return: The list of client socket
         :rtype: list of :class:`socket.socket`
@@ -125,7 +131,7 @@ class Server(BaseComponent):
             server=self.server,
             receive_event_firewall=self.__receive_event_firewall,
             send_event_firewall=self.__send_event_firewall,
-            channel=self.channel
+            channel=self.channel,
         ).register(self)
 
     @handler('disconnect')
