@@ -1,6 +1,8 @@
-"""Networking Protocols
+"""
+Networking Protocols
 
 This package contains components that implement various networking protocols.
 """
+
 from .irc import IRC  # noqa
 from .line import Line  # noqa
