@@ -1,6 +1,5 @@
 """Internet Relay Chat Protocol"""
 
-
 from re import compile as compile_regex
 
 from circuits import Component
@@ -11,12 +10,13 @@ from .commands import PONG
 from .events import response
 from .utils import parsemsg
 
-NUMERIC = compile_regex("[0-9]+")
+
+NUMERIC = compile_regex('[0-9]+')
 
 
 class IRC(Component):
-
-    """IRC Protocol Component
+    """
+    IRC Protocol Component
 
     Creates a new IRC Component instance that implements the IRC Protocol.
     Incoming messages are handled by the "read" Event Handler, parsed and
@@ -25,14 +25,15 @@ class IRC(Component):
     """
 
     def __init__(self, *args, **kwargs):
-        super(IRC, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
-        self.encoding = kwargs.get("encoding", "utf-8")
+        self.encoding = kwargs.get('encoding', 'utf-8')
 
         Line(**kwargs).register(self)
 
     def line(self, *args):
-        """line Event Handler
+        """
+        line Event Handler
 
         Process a line of text and generate the appropriate
         event. This must not be overridden by subclasses,
@@ -40,7 +41,6 @@ class IRC(Component):
         subclass. Other Components may however listen to
         this event and process custom IRC events.
         """
-
         if len(args) == 1:
             # Client read
             sock, line = None, args[0]
@@ -54,7 +54,7 @@ class IRC(Component):
 
         if NUMERIC.match(command):
             args.insert(0, int(command))
-            command = "numeric"
+            command = 'numeric'
 
         if sock is not None:
             self.fire(response.create(command, sock, prefix, *args))
@@ -62,7 +62,8 @@ class IRC(Component):
             self.fire(response.create(command, prefix, *args))
 
     def request(self, event, message):
-        """request Event Handler (Default)
+        """
+        request Event Handler (Default)
 
         This is a default event handler to respond to ``request`` events
         by converting the given message to bytes and firing a ``write``
@@ -71,13 +72,13 @@ class IRC(Component):
         ``request`` events by either explicitly calling this method
         or sending your own ``write`` events as the client socket.
         """
-
         event.stop()
         message.encoding = self.encoding
         self.fire(write(bytes(message)))
 
     def ping(self, event, *args):
-        """ping Event Handler (Default)
+        """
+        ping Event Handler (Default)
 
         This is a default event to respond to ``ping`` events
         by sending a ``PONG`` in response. Subclasses or
@@ -85,7 +86,6 @@ class IRC(Component):
         ``ping`` events by either explicitly calling this method
         or sending your own ``PONG`` response.
         """
-
         if len(args) == 2:
             # Client read
             self.fire(PONG(args[1]))
