@@ -1,37 +1,39 @@
-"""Line Protocol
+"""
+Line Protocol
 
 This module implements the basic Line protocol.
 
 This module can be used in both server and client implementations.
 """
+
 import re
 
 from circuits.core import BaseComponent, Event, handler
 
-LINESEP = re.compile(b"\r?\n")
+
+LINESEP = re.compile(b'\r?\n')
 
 
 def splitLines(s, buffer):
-    """splitLines(s, buffer) -> lines, buffer
+    """
+    splitLines(s, buffer) -> lines, buffer
 
     Append s to buffer and find any new lines of text in the
     string splitting at the standard IRC delimiter CRLF. Any
     new lines found, return them as a list and the remaining
     buffer for further processing.
     """
-
     lines = LINESEP.split(buffer + s)
     return lines[:-1], lines[-1]
 
 
 class line(Event):
-
     """line Event"""
 
 
 class Line(BaseComponent):
-
-    """Line Protocol
+    """
+    Line Protocol
 
     Implements the Line Protocol.
 
@@ -78,25 +80,24 @@ class Line(BaseComponent):
     """
 
     def __init__(self, *args, **kwargs):
-        "initializes x; see x.__class__.__doc__ for signature"
-
-        super(Line, self).__init__(*args, **kwargs)
+        """Initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(*args, **kwargs)
 
         self.encoding = kwargs.get('encoding', 'utf-8')
 
         # Used for Servers
-        self.getBuffer = kwargs.get("getBuffer")
-        self.updateBuffer = kwargs.get("updateBuffer")
+        self.getBuffer = kwargs.get('getBuffer')
+        self.updateBuffer = kwargs.get('updateBuffer')
 
-        self.splitter = kwargs.get("splitter", splitLines)
+        self.splitter = kwargs.get('splitter', splitLines)
 
-        self.buffer = b""
+        self.buffer = b''
 
-    @handler("read")
+    @handler('read')
     def _on_read(self, *args):
         if len(args) == 1:
             # Client read
-            data, = args
+            (data,) = args
             lines, self.buffer = self.splitter(data, self.buffer)
             [self.fire(line(x)) for x in lines]
         else:
