@@ -1,19 +1,16 @@
-"""
+""".. codeauthor: mnl"""
 
-.. codeauthor: mnl
-"""
 import os
 import random
 
 from circuits.core.components import BaseComponent
 from circuits.core.handlers import handler
 from circuits.net.events import close, read, write
-from circuits.six import string_types
 
 
 class WebSocketCodec(BaseComponent):
-
-    """WebSocket Protocol
+    """
+    WebSocket Protocol
 
     Implements the Data Framing protocol for WebSocket.
 
@@ -31,7 +28,7 @@ class WebSocketCodec(BaseComponent):
     encoded data is then forwarded as write events on the parents channel.
     """
 
-    channel = "ws"
+    channel = 'ws'
 
     def __init__(self, sock=None, data=bytearray(), *args, **kwargs):
         """
@@ -40,7 +37,7 @@ class WebSocketCodec(BaseComponent):
         :param sock: the socket used in Read and write events
             (if used in a server, else None)
         """
-        super(WebSocketCodec, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self._sock = sock
 
@@ -57,10 +54,11 @@ class WebSocketCodec(BaseComponent):
             else:
                 self.fire(read(message))
 
-    @handler("registered")
+    @handler('registered')
     def _on_registered(self, component, parent):
         if component is self:
-            @handler("read", priority=10, channel=parent.channel)
+
+            @handler('read', priority=10, channel=parent.channel)
             def _on_read_raw(self, event, *args):
                 if self._sock is not None:
                     if args[0] != self._sock:
@@ -78,12 +76,12 @@ class WebSocketCodec(BaseComponent):
 
             self.addHandler(_on_read_raw)
 
-            @handler("disconnect", channel=parent.channel)
+            @handler('disconnect', channel=parent.channel)
             def _on_disconnect(self, *args):
-                if self._sock is not None:
-                    if args[0] != self._sock:
-                        return
+                if self._sock is not None and args[0] != self._sock:
+                    return
                 self.unregister()
+
             self.addHandler(_on_disconnect)
 
     def _parse_messages(self, data):
@@ -94,21 +92,20 @@ class WebSocketCodec(BaseComponent):
         while data:
             # extract final flag, opcode and masking
             final = bool(data[0] & 0x80 != 0)
-            opcode = data[0] & 0xf
+            opcode = data[0] & 0xF
             masking = bool(data[1] & 0x80 != 0)
             # evaluate payload length
-            payload_length = data[1] & 0x7f
+            payload_length = data[1] & 0x7F
             offset = 2
             if payload_length >= 126:
                 payload_bytes = 2 if payload_length == 126 else 8
                 payload_length = 0
                 for _ in range(payload_bytes):
-                    payload_length = payload_length * 256 \
-                        + data[offset]
+                    payload_length = payload_length * 256 + data[offset]
                     offset += 1
             # retrieve optional masking key
             if masking:
-                masking_key = data[offset:offset + 4]
+                masking_key = data[offset : offset + 4]
                 offset += 4
             # if not enough bytes available yet, retry after next read
             if len(data) - offset < payload_length:
@@ -116,7 +113,7 @@ class WebSocketCodec(BaseComponent):
                 break
             self._buffer = bytearray()
             # rest of _buffer is payload
-            msg = data[offset:offset + payload_length]
+            msg = data[offset : offset + payload_length]
             if masking:  # unmask
                 msg = list(msg)
                 for i, c in enumerate(msg):
@@ -130,9 +127,8 @@ class WebSocketCodec(BaseComponent):
             if final:
                 if opcode < 8:
                     # if text or continuation of text, convert
-                    if opcode == 1 \
-                            or opcode == 0 and self._pending_type == 1:
-                        msg = msg.decode("utf-8", "replace")
+                    if opcode == 1 or (opcode == 0 and self._pending_type == 1):
+                        msg = msg.decode('utf-8', 'replace')
                     self._pending_type = None
                     self._pending_payload = bytearray()
                     msgs.append(msg)
@@ -147,7 +143,7 @@ class WebSocketCodec(BaseComponent):
                 # check for Ping
                 elif opcode == 9:
                     if self._close_sent:
-                        return
+                        return None
                     frame = bytearray(b'\x8a')
                     frame += self._encode_tail(msg, self._sock is None)
                     self._write(frame)
@@ -157,7 +153,7 @@ class WebSocketCodec(BaseComponent):
                     self._pending_type = opcode
         return msgs
 
-    @handler("write")
+    @handler('write')
     def _on_write(self, *args):
         if self._close_sent:
             return
@@ -171,9 +167,9 @@ class WebSocketCodec(BaseComponent):
 
         frame = bytearray()
         first = 0x80  # set FIN flag, we never fragment
-        if isinstance(data, string_types):
+        if isinstance(data, str):
             first += 1  # text
-            data = bytearray(data, "utf-8")
+            data = bytearray(data, 'utf-8')
         else:
             first += 2  # binary
         frame.append(first)
@@ -186,7 +182,7 @@ class WebSocketCodec(BaseComponent):
         if data_length <= 125:
             len_byte = data_length
             lbytes = 0
-        elif data_length <= 0xffff:
+        elif data_length <= 0xFFFF:
             len_byte = 126
             lbytes = 2
         else:
@@ -196,13 +192,12 @@ class WebSocketCodec(BaseComponent):
             len_byte = len_byte | 0x80
         tail.append(len_byte)
         for i in range(lbytes - 1, -1, -1):
-            tail.append(data_length >> (i * 8) & 0xff)
+            tail.append(data_length >> (i * 8) & 0xFF)
         if mask:
             try:
                 masking_key = bytearray(list(os.urandom(4)))
             except NotImplementedError:
-                masking_key \
-                    = bytearray([random.randint(0, 255) for i in range(4)])
+                masking_key = bytearray(random.randint(0, 255) for i in range(4))
             tail += masking_key
             for i, c in enumerate(data):
                 tail.append(c ^ masking_key[i % 4])
@@ -216,13 +211,12 @@ class WebSocketCodec(BaseComponent):
         else:
             self.fire(write(data), self.parent.channel)
 
-    @handler("close")
+    @handler('close')
     def _on_close(self, *args):
-        if self._sock is not None:
-            if args and (args[0] != self._sock):
-                return
+        if self._sock is not None and args and (args[0] != self._sock):
+            return
         if not self._close_sent:
-            self._write(b"\x88\x00")
+            self._write(b'\x88\x00')
             self._close_sent = True
         if self._close_received and self._close_sent:
             if self._sock:
