@@ -1,14 +1,14 @@
-"""Circuits Tools
+"""
+Circuits Tools
 
 circuits.tools contains a standard set of tools for circuits. These
 tools are installed as executables with a prefix of "circuits."
 """
+
 import inspect as _inspect
 from functools import wraps
 from warnings import warn, warn_explicit
 
-from circuits.six import _func_code
-
 
 def tryimport(modules, obj=None, message=None):
     modules = (modules,) if isinstance(modules, str) else modules
@@ -22,6 +22,8 @@ def tryimport(modules, obj=None, message=None):
 
     if message is not None:
         warn(message)
+        return None
+    return None
 
 
 def getargspec(func):
@@ -36,8 +38,7 @@ def walk(x, f, d=0, v=None):
     for c in x.components.copy():
         if c not in v:
             v.add(c)
-            for r in walk(c, f, d + 1, v):
-                yield r
+            yield from walk(c, f, d + 1, v)
 
 
 def edges(x, e=None, v=None, d=0):
@@ -55,8 +56,7 @@ def edges(x, e=None, v=None, d=0):
 def findroot(x):
     if x.parent == x:
         return x
-    else:
-        return findroot(x.parent)
+    return findroot(x.parent)
 
 
 def kill(x):
@@ -67,28 +67,28 @@ def kill(x):
 
 
 def _graph(x):
-    """Create a directed graph of the Component structure of x
+    """
+    Create a directed graph of the Component structure of x
 
     :param x: A Component or Manager to graph
     :type  x: Component or Manager
     """
-
-    networkx = tryimport("networkx")
-    pygraphviz = tryimport("pygraphviz")
-    plt = tryimport("matplotlib.pyplot", "pyplot")
+    networkx = tryimport('networkx')
+    pygraphviz = tryimport('pygraphviz')
+    plt = tryimport('matplotlib.pyplot', 'pyplot')
 
     if not all([networkx, pygraphviz, plt]):
         return None, None
 
     graph_edges = []
-    for (u, v, d) in edges(x):
+    for u, v, d in edges(x):
         graph_edges.append((u.name, v.name, float(d)))
 
     g = networkx.DiGraph()
     g.add_weighted_edges_from(graph_edges)
 
-    elarge = [(u, v) for (u, v, d) in g.edges(data=True) if d["weight"] > 3.0]
-    esmall = [(u, v) for (u, v, d) in g.edges(data=True) if d["weight"] <= 3.0]
+    elarge = [(u, v) for (u, v, d) in g.edges(data=True) if d['weight'] > 3.0]
+    esmall = [(u, v) for (u, v, d) in g.edges(data=True) if d['weight'] <= 3.0]
 
     pos = networkx.spring_layout(g)  # positions for all nodes
 
@@ -98,23 +98,32 @@ def _graph(x):
     # edges
     networkx.draw_networkx_edges(g, pos, edgelist=elarge, width=1)
     networkx.draw_networkx_edges(
-        g, pos, edgelist=esmall, width=1,
-        alpha=0.5, edge_color="b", style="dashed"
+        g,
+        pos,
+        edgelist=esmall,
+        width=1,
+        alpha=0.5,
+        edge_color='b',
+        style='dashed',
     )
 
     # labels
     networkx.draw_networkx_labels(
-        g, pos, font_size=10, font_family="sans-serif"
+        g,
+        pos,
+        font_size=10,
+        font_family='sans-serif',
     )
 
-    plt.axis("off")
+    plt.axis('off')
 
     plt.clf()
     return plt, g
 
 
 def graph_ascii(x):
-    """Display a directed graph of the Component structure of x
+    """
+    Display a directed graph of the Component structure of x
 
     :param x: A Component or Manager to graph
     :type  x: Component or Manager
@@ -122,10 +131,11 @@ def graph_ascii(x):
     @return: A directed graph representing x's Component structure.
     @rtype:  str
     """
-    def printer(d, x):
-        return "%s* %s" % (" " * d, x)
 
-    return "\n".join(walk(x, printer))
+    def printer(d, x):
+        return '%s* %s' % (' ' * d, x)
+
+    return '\n'.join(walk(x, printer))
 
 
 def graph_dot(x, name=None):
@@ -136,11 +146,10 @@ def graph_dot(x, name=None):
     :param name: A name for the graph (defaults to x's name)
     :type  name: str
     """
-
-    networkx = tryimport("networkx")
-    plt, g = _graph(x)
+    networkx = tryimport('networkx')
+    _plt, g = _graph(x)
     if g is not None:
-        networkx.drawing.nx_agraph.write_dot(g, "{}.dot".format(name or x.name))
+        networkx.drawing.nx_agraph.write_dot(g, f'{name or x.name}.dot')
 
 
 def graph_png(x, name=None):
@@ -151,9 +160,9 @@ def graph_png(x, name=None):
     :param name: A name for the graph (defaults to x's name)
     :type  name: str
     """
-    plt, g = _graph(x)
+    plt, _g = _graph(x)
     if plt is not None:
-        plt.savefig("{}.png".format(name or x.name))
+        plt.savefig(f'{name or x.name}.png')
 
 
 def graph(x, name=None):
@@ -170,7 +179,8 @@ def graph(x, name=None):
 
 
 def inspect(x):
-    """Display an inspection report of the Component or Manager x
+    """
+    Display an inspection report of the Component or Manager x
 
     :param x: A Component or Manager to graph
     :type  x: Component or Manager
@@ -178,34 +188,34 @@ def inspect(x):
     @return: A detailed inspection report of x
     @rtype:  str
     """
-
     s = []
     write = s.append
 
-    write(" Components: %d\n" % len(x.components))
+    write(' Components: %d\n' % len(x.components))
     for component in x.components:
-        write("  %s\n" % component)
-    write("\n")
+        write('  %s\n' % component)
+    write('\n')
 
     from circuits import reprhandler
 
-    write(" Event Handlers: %d\n" % len(x._handlers.values()))
-    for event, handlers in x._handlers.items():
-        write("  %s; %d\n" % (event, len(x._handlers[event])))
+    write(' Event Handlers: %d\n' % len(x._handlers.values()))
+    for event in x._handlers:
+        write('  %s; %d\n' % (event, len(x._handlers[event])))
         for handler in x._handlers[event]:
-            write("   %s\n" % reprhandler(handler))
+            write('   %s\n' % reprhandler(handler))
 
-    return "".join(s)
+    return ''.join(s)
 
 
 def deprecated(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
         warn_explicit(
-            "Call to deprecated function {}".format(f.__name__),
+            f'Call to deprecated function {f.__name__}',
             category=DeprecationWarning,
-            filename=getattr(f, _func_code).co_filename,
-            lineno=getattr(f, _func_code).co_firstlineno + 1
+            filename=f.__code__.co_filename,
+            lineno=f.__code__.co_firstlineno + 1,
         )
         return f(*args, **kwargs)
+
     return wrapper
