@@ -1,52 +1,47 @@
-"""XML RPC
+"""
+XML RPC
 
 This module implements a XML RPC dispatcher that translates incoming
 RPC calls over XML into RPC events.
 """
-try:
-    from xmlrpc.client import dumps, loads, Fault
-except ImportError:  # pragma: no cover
-    from xmlrpclib import dumps, loads, Fault
+
+from xmlrpc.client import Fault, dumps, loads
 
 from circuits import BaseComponent, Event, handler
 
 
 class rpc(Event):
-
     """rpc Event"""
 
 
 class XMLRPC(BaseComponent):
+    channel = 'web'
 
-    channel = "web"
-
-    def __init__(self, path=None, encoding="utf-8", rpc_channel="*"):
-        super(XMLRPC, self).__init__()
+    def __init__(self, path=None, encoding='utf-8', rpc_channel='*'):
+        super().__init__()
 
         self.path = path
         self.encoding = encoding
         self.rpc_channel = rpc_channel
 
-    @handler("request", priority=0.2)
+    @handler('request', priority=0.2)
     def _on_request(self, event, req, res):
-        if self.path is not None and self.path != req.path.rstrip("/"):
+        if self.path is not None and self.path != req.path.rstrip('/'):
             return
 
-        res.headers["Content-Type"] = "text/xml"
+        res.headers['Content-Type'] = 'text/xml'
 
         try:
             data = req.body.read()
             params, method = loads(data)
 
-            if not isinstance(method, (str, bytes, type(u''))):
+            if not isinstance(method, str):
                 method = str(method)
-            if not isinstance(method, bytes) and str is bytes:  # Python 2
-                method = method.encode(self.encoding)
 
             value = yield self.call(rpc.create(method, *params), self.rpc_channel)
             yield self._response(value.value)
         except Exception as exc:
-            yield self._error(1, "%s: %s" % (type(exc).__name__, exc))
+            yield self._error(1, f'{type(exc).__name__}: {exc}')
         finally:
             event.stop()
 
