@@ -1,13 +1,15 @@
-"""Events
+"""
+Events
 
 This module implements the necessary Events needed.
 """
+
 from circuits import Event
 
 
 class request(Event):
-
-    """request(Event) -> request Event
+    """
+    request(Event) -> request Event
 
     args: request, response
     """
@@ -18,8 +20,8 @@ class request(Event):
 
 
 class response(Event):
-
-    """response(Event) -> response Event
+    """
+    response(Event) -> response Event
 
     args: request, response
     """
@@ -30,8 +32,8 @@ class response(Event):
 
 
 class stream(Event):
-
-    """stream(Event) -> stream Event
+    """
+    stream(Event) -> stream Event
 
     args: request, response
     """
@@ -42,5 +44,4 @@ class stream(Event):
 
 
 class terminate(Event):
-
     """terminate Event"""
