@@ -1,10 +1,11 @@
-"""Headers Support
+"""
+Headers Support
 
 This module implements support for parsing and handling headers.
 """
+
 import re
 
-from circuits.six import b, iteritems, u
 
 # Regular expression that matches `special' characters in parameters, the
 # existence of which force quoting of the parameter value.
@@ -14,43 +15,41 @@ q_separator = re.compile(r'; *q *=')
 
 
 def _formatparam(param, value=None, quote=1):
-    """Convenience function to format and return a key=value pair.
+    """
+    Convenience function to format and return a key=value pair.
 
     This will quote the value if needed or if quote is true.
     """
     if value is not None and len(value) > 0:
         if quote or tspecials.search(value):
             value = value.replace('\\', '\\\\').replace('"', r'\"')
-            return '%s="%s"' % (param, value)
-        else:
-            return '%s=%s' % (param, value)
-    else:
-        return param
+            return f'{param}="{value}"'
+        return f'{param}={value}'
+    return param
 
 
 def header_elements(fieldname, fieldvalue):
-    """Return a sorted HeaderElement list.
+    """
+    Return a sorted HeaderElement list.
 
     Returns a sorted HeaderElement list
     from a comma-separated header string.
     """
-
     if not fieldvalue:
         return []
 
     result = []
-    for element in fieldvalue.split(","):
-        if fieldname.startswith("Accept") or fieldname == 'TE':
+    for element in fieldvalue.split(','):
+        if fieldname.startswith('Accept') or fieldname == 'TE':
             hv = AcceptElement.from_str(element)
         else:
             hv = HeaderElement.from_str(element)
         result.append(hv)
 
-    return list(reversed(sorted(result)))
+    return sorted(result, reverse=True)
 
 
-class HeaderElement(object):
-
+class HeaderElement:
     """An element (with parameters) from an HTTP header's element list."""
 
     def __init__(self, value, params=None):
@@ -66,34 +65,26 @@ class HeaderElement(object):
         return self.value < other.value
 
     def __str__(self):
-        p = [";%s=%s" % (k, v) for k, v in iteritems(self.params)]
-        return "%s%s" % (self.value, "".join(p))
+        p = [f';{k}={v}' for k, v in self.params.items()]
+        return '%s%s' % (self.value, ''.join(p))
 
     def __bytes__(self):
-        return b(self.__str__())
-
-    def __unicode__(self):
-        return u(self.__str__())
+        return self.__str__().encode('ISO8859-1')
 
     def parse(elementstr):
         """Transform 'token;key=val' to ('token', {'key': 'val'})."""
         # Split the element into a value and parameters. The 'value' may
         # be of the form, "token=token", but we don't split that here.
-        atoms = [x.strip() for x in elementstr.split(";") if x.strip()]
-        if not atoms:
-            initial_value = ''
-        else:
-            initial_value = atoms.pop(0).strip()
+        atoms = [x.strip() for x in elementstr.split(';') if x.strip()]
+        initial_value = '' if not atoms else atoms.pop(0).strip()
         params = {}
         for atom in atoms:
-            atom = [x.strip() for x in atom.split("=", 1) if x.strip()]
+            atom = [x.strip() for x in atom.split('=', 1) if x.strip()]
             key = atom.pop(0)
-            if atom:
-                val = atom[0]
-            else:
-                val = ""
+            val = atom[0] if atom else ''
             params[key] = val
         return initial_value, params
+
     parse = staticmethod(parse)
 
     @classmethod
@@ -104,8 +95,8 @@ class HeaderElement(object):
 
 
 class AcceptElement(HeaderElement):
-
-    """An element (with parameters) from an Accept* header's element list.
+    """
+    An element (with parameters) from an Accept* header's element list.
 
     AcceptElement objects are comparable; the more-preferred object will be
     "less than" the less-preferred object. They are also therefore sortable;
@@ -128,15 +119,16 @@ class AcceptElement(HeaderElement):
 
         media_type, params = cls.parse(media_range)
         if qvalue is not None:
-            params["q"] = qvalue
+            params['q'] = qvalue
         return cls(media_type, params)
 
     def qvalue(self):
-        val = self.params.get("q", "1")
+        val = self.params.get('q', '1')
         if isinstance(val, HeaderElement):
             val = val.value
         return float(val)
-    qvalue = property(qvalue, doc="The qvalue, or priority, of this value.")
+
+    qvalue = property(qvalue, doc='The qvalue, or priority, of this value.')
 
     def __eq__(self, other):
         return self.qvalue == other.qvalue
@@ -144,20 +136,19 @@ class AcceptElement(HeaderElement):
     def __lt__(self, other):
         if self.qvalue == other.qvalue:
             return str(self) < str(other)
-        else:
-            return self.qvalue < other.qvalue
+        return self.qvalue < other.qvalue
 
 
 class CaseInsensitiveDict(dict):
-
-    """A case-insensitive dict subclass.
+    """
+    A case-insensitive dict subclass.
 
     Each key is changed on entry to str(key).title().
     """
 
     def __init__(self, *args, **kwargs):
         d = dict(*args, **kwargs)
-        for key, value in iteritems(d):
+        for key, value in d.items():
             dict.__setitem__(self, str(key).title(), value)
         dict.__init__(self)
 
@@ -177,7 +168,7 @@ class CaseInsensitiveDict(dict):
         return dict.get(self, str(key).title(), default)
 
     def update(self, E):
-        for k in E.keys():
+        for k in E:
             self[str(k).title()] = E[k]
 
     @classmethod
@@ -233,14 +224,14 @@ class Headers(CaseInsensitiveDict):
         return [val.strip() for val in value.split(',')]
 
     def __repr__(self):
-        return "Headers(%s)" % repr(list(self.items()))
+        return 'Headers(%s)' % repr(list(self.items()))
 
     def __str__(self):
-        headers = ["%s: %s\r\n" % (k, v) for k, v in self.items()]
-        return "".join(headers) + '\r\n'
+        headers = [f'{k}: {v}\r\n' for k, v in self.items()]
+        return ''.join(headers) + '\r\n'
 
     def items(self):
-        for k, v in super(Headers, self).items():
+        for k, v in super().items():
             if isinstance(v, list):
                 for vv in v:
                     yield (str(k), str(vv))
@@ -248,7 +239,7 @@ class Headers(CaseInsensitiveDict):
                 yield (str(k), str(v))
 
     def __bytes__(self):
-        return str(self).encode("latin1")
+        return str(self).encode('latin1')
 
     def append(self, key, value):
         """
@@ -260,7 +251,7 @@ class Headers(CaseInsensitiveDict):
         the new value is appended to that list.
         """
         if key not in self:
-            if key.lower() == "set-cookie":
+            if key.lower() == 'set-cookie':
                 self[key] = [value]
             else:
                 self[key] = value
@@ -268,10 +259,11 @@ class Headers(CaseInsensitiveDict):
             if isinstance(self[key], list):
                 self[key].append(value)
             else:
-                self[key] = ", ".join([self[key], value])
+                self[key] = ', '.join([self[key], value])
 
     def add_header(self, _name, _value, **_params):
-        """Extended header setting.
+        """
+        Extended header setting.
 
         _name is the header field to add. keyword arguments can be used to set
         additional parameters for the header field, with underscores converted
@@ -279,12 +271,13 @@ class Headers(CaseInsensitiveDict):
         value is None, in which case only the key will be added.
 
         Example:
-
+        -------
         h.add_header('content-disposition', 'attachment', filename='bud.gif')
 
         Note that unlike the corresponding 'email.Message' method, this does
         *not* handle '(charset, language, value)' tuples: all values must be
         strings or None.
+
         """
         parts = []
         if _value is not None:
@@ -295,4 +288,4 @@ class Headers(CaseInsensitiveDict):
                 parts.append(k)
             else:
                 parts.append(_formatparam(k, v))
-        self.append(_name, "; ".join(parts))
+        self.append(_name, '; '.join(parts))
