@@ -1,16 +1,17 @@
-"""Hyper Text Transfer Protocol
+"""
+Hyper Text Transfer Protocol
 
 This module implements the server side Hyper Text Transfer Protocol
 or commonly known as HTTP.
 """
+
 from io import BytesIO
 from socket import socket
+from urllib.parse import quote
 
 from circuits.core import BaseComponent, Value, handler
 from circuits.net.events import close, write
 from circuits.net.utils import is_ssl_handshake
-from circuits.six import text_type
-from circuits.six.moves.urllib_parse import quote
 
 from . import wrappers
 from .constants import SERVER_PROTOCOL, SERVER_VERSION
@@ -21,12 +22,13 @@ from .parsers import BAD_FIRST_LINE, HttpParser
 from .url import parse_url
 from .utils import is_unix_socket
 
-MAX_HEADER_FRAGENTS = 20
+
 HTTP_ENCODING = 'utf-8'
 
 
 class HTTP(BaseComponent):
-    """HTTP Protocol Component
+    """
+    HTTP Protocol Component
 
     Implements the HTTP server protocol and parses and processes incoming
     HTTP messages, creating and sending an appropriate response.
@@ -43,10 +45,10 @@ class HTTP(BaseComponent):
     the client.
     """
 
-    channel = "web"
+    channel = 'web'
 
     def __init__(self, server, encoding=HTTP_ENCODING, channel=channel):
-        super(HTTP, self).__init__(channel=channel)
+        super().__init__(channel=channel)
 
         self._server = server
         self._encoding = encoding
@@ -65,49 +67,47 @@ class HTTP(BaseComponent):
 
     @property
     def scheme(self):
-        return "https" if self._server.secure else "http"
+        return 'https' if self._server.secure else 'http'
 
     @property
     def base(self):
         if self.uri is None:
-            return ""
-        return self.uri.utf8().rstrip(b"/").decode(self._encoding)
+            return ''
+        return self.uri.utf8().rstrip(b'/').decode(self._encoding)
 
     @property
     def uri(self):
         return self._uri
 
-    @handler("ready", priority=1.0)
+    @handler('ready', priority=1.0)
     def _on_ready(self, server, bind):
         if is_unix_socket(server.host):
             url = server.host
         else:
-            url = "{}://{}{}".format(
-                (server.secure and "https") or "http",
-                server.host or "0.0.0.0",
-                ":{0:d}".format(server.port or 80)
-                if server.port not in (80, 443)
-                else ""
+            url = '{}://{}{}'.format(
+                (server.secure and 'https') or 'http',
+                server.host or '0.0.0.0',
+                f':{server.port or 80:d}' if server.port not in (80, 443) else '',
             )
 
         self._uri = parse_url(url)
 
-    @handler("stream")  # noqa
+    @handler('stream')  # noqa
     def _on_stream(self, res, data):
         sock = res.request.sock
 
         if data is not None:
-            if isinstance(data, text_type):
+            if isinstance(data, str):
                 data = data.encode(self._encoding)
 
             if res.chunked:
                 buf = [
                     hex(len(data))[2:].encode(self._encoding),
-                    b"\r\n",
+                    b'\r\n',
                     data,
-                    b"\r\n"
+                    b'\r\n',
                 ]
-                data = b"".join(buf)
+                data = b''.join(buf)
 
             self.fire(write(sock, data))
 
@@ -123,7 +123,7 @@ class HTTP(BaseComponent):
             if res.body:
                 res.body.close()
             if res.chunked:
-                self.fire(write(sock, b"0\r\n\r\n"))
+                self.fire(write(sock, b'0\r\n\r\n'))
             if res.close:
                 self.fire(close(sock))
             if sock in self._clients:
@@ -131,9 +131,10 @@ class HTTP(BaseComponent):
 
             res.done = True
 
-    @handler("response")  # noqa
+    @handler('response')  # noqa
     def _on_response(self, res):
-        """``Response`` Event Handler
+        """
+        ``Response`` Event Handler
 
         :param response: the ``Response`` object created when the
             HTTP request was initially received.
@@ -143,53 +144,45 @@ class HTTP(BaseComponent):
         the information contained in the *response* object and
         sends it to the client (firing ``write`` events).
         """
-        # send HTTP response status line and headers
-
         req = res.request
         headers = res.headers
         sock = req.sock
 
-        if req.method == "HEAD":
-            self.fire(write(sock, bytes(res)))
-            self.fire(write(sock, bytes(headers)))
-        elif res.stream and res.body:
+        # send HTTP response status line and headers
+        res.prepare()
+        self.fire(write(sock, b'%s%s' % (bytes(res), bytes(headers))))
+
+        if req.method == 'HEAD':
+            return
+        if res.stream and res.body:
             try:
                 data = next(res.body)
             except StopIteration:
                 data = None
-            self.fire(write(sock, bytes(res)))
-            self.fire(write(sock, bytes(headers)))
             self.fire(stream(res, data))
         else:
-            self.fire(write(sock, bytes(res)))
-            self.fire(write(sock, bytes(headers)))
-
             if isinstance(res.body, bytes):
                 body = res.body
-            elif isinstance(res.body, text_type):
+            elif isinstance(res.body, str):
                 body = res.body.encode(self._encoding)
             else:
-                parts = (
-                    s
-                    if isinstance(s, bytes) else s.encode(self._encoding)
-                    for s in res.body if s is not None
-                )
-                body = b"".join(parts)
+                parts = (s if isinstance(s, bytes) else s.encode(self._encoding) for s in res.body if s is not None)
+                body = b''.join(parts)
 
             if body:
                 if res.chunked:
                     buf = [
                         hex(len(body))[2:].encode(self._encoding),
-                        b"\r\n",
+                        b'\r\n',
                         body,
-                        b"\r\n"
+                        b'\r\n',
                     ]
-                    body = b"".join(buf)
+                    body = b''.join(buf)
 
                 self.fire(write(sock, body))
 
                 if res.chunked:
-                    self.fire(write(sock, b"0\r\n\r\n"))
+                    self.fire(write(sock, b'0\r\n\r\n'))
 
             if not res.stream:
                 if res.close:
@@ -199,20 +192,20 @@ class HTTP(BaseComponent):
                     del self._clients[sock]
                 res.done = True
 
-    @handler("disconnect")
+    @handler('disconnect')
     def _on_disconnect(self, sock):
         if sock in self._clients:
             del self._clients[sock]
 
-    @handler("read")  # noqa
+    @handler('read')  # noqa
     def _on_read(self, sock, data):
-        """Read Event Handler
+        """
+        Read Event Handler
 
         Process any incoming data appending it to an internal buffer.
         Split the buffer by the standard HTTP delimiter CRLF and create
         Raw Event per line. Any unfinished lines of text, leave in the buffer.
         """
-
         if sock in self._buffers:
             parser = self._buffers[sock]
         else:
@@ -229,7 +222,7 @@ class HTTP(BaseComponent):
                     del self._clients[sock]
                 return self.fire(close(sock))
 
-        _scheme = "https" if self._server.secure else "http"
+        _scheme = 'https' if self._server.secure else 'http'
         parser.execute(data, len(data))
         if not parser.is_headers_complete():
             if parser.errno is not None:
@@ -243,13 +236,13 @@ class HTTP(BaseComponent):
                         parser.get_path(),
                         parser.get_version(),
                         parser.get_query_string(),
-                        server=self._server
+                        server=self._server,
                     )
                 req.server = self._server
                 res = wrappers.Response(req, encoding=self._encoding)
                 del self._buffers[sock]
                 return self.fire(httperror(req, res, 400))
-            return
+            return None
 
         if sock in self._clients:
             req, res = self._clients[sock]
@@ -261,8 +254,14 @@ class HTTP(BaseComponent):
             query_string = parser.get_query_string()
 
             req = wrappers.Request(
-                sock, method, scheme, path, version, query_string,
-                headers=parser.get_headers(), server=self._server
+                sock,
+                method,
+                scheme,
+                path,
+                version,
+                query_string,
+                headers=parser.get_headers(),
+                server=self._server,
             )
 
             res = wrappers.Response(req, encoding=self._encoding)
@@ -276,54 +275,49 @@ class HTTP(BaseComponent):
                 # the major HTTP version differs
                 return self.fire(httperror(req, res, 505))
 
-            res.protocol = "HTTP/{0:d}.{1:d}".format(*min(rp, sp))
+            res.protocol = 'HTTP/{:d}.{:d}'.format(*min(rp, sp))
             res.close = not parser.should_keep_alive()
 
-        clen = int(req.headers.get("Content-Length", "0"))
-        if (clen or req.headers.get("Transfer-Encoding") == "chunked") and not parser.is_message_complete():
-            return
+        clen = int(req.headers.get('Content-Length', '0'))
+        if (clen or req.headers.get('Transfer-Encoding') == 'chunked') and not parser.is_message_complete():
+            return None
 
-        if hasattr(sock, "getpeercert"):
+        if hasattr(sock, 'getpeercert'):
             peer_cert = sock.getpeercert()
-            if peer_cert:
-                e = request(req, res, peer_cert)
-            else:
-                e = request(req, res)
+            e = request(req, res, peer_cert) if peer_cert else request(req, res)
         else:
             e = request(req, res)
 
-        if req.protocol != (1, 0) and not req.headers.get("Host"):
+        if req.protocol != (1, 0) and not req.headers.get('Host'):
             del self._buffers[sock]
-            return self.fire(httperror(req, res, 400, description="No host header defined"))
+            return self.fire(httperror(req, res, 400, description='No host header defined'))
 
         # Guard against unwanted request paths (SECURITY).
         path = req.path
         _path = req.uri._path
-        if (path.encode(self._encoding) != _path) and (
-                quote(path).encode(self._encoding) != _path):
-            return self.fire(
-                redirect(req, res, [req.uri.utf8()], 301)
-            )
+        if (path.encode(self._encoding) != _path) and (quote(path).encode(self._encoding) != _path):
+            return self.fire(redirect(req, res, [req.uri.utf8()], 301))
 
         req.body = BytesIO(parser.recv_body())
         del self._buffers[sock]
 
         self.fire(e)
+        return None
 
-    @handler("httperror")
+    @handler('httperror')
     def _on_httperror(self, event, req, res, code, **kwargs):
-        """Default HTTP Error Handler
+        """
+        Default HTTP Error Handler
 
         Default Error Handler that by default just fires a ``Response``
         event with the *response* as argument. The *response* is normally
         modified by a :class:`~circuits.web.errors.HTTPError` instance
         or a subclass thereof.
         """
-
         res.body = str(event)
         self.fire(response(res))
 
-    @handler("request_success")  # noqa
+    @handler('request_success')  # noqa
     def _on_request_success(self, e, value):
         """
         Handler for the ``RequestSuccess`` event that is automatically
@@ -367,27 +361,14 @@ class HTTP(BaseComponent):
                 self.fire(response(res))
             elif value.errors:
                 error = value.value
-                etype, evalue, traceback = error
+                _etype, evalue, _traceback = error
                 if isinstance(evalue, RedirectException):
-                    self.fire(
-                        redirect(req, res, evalue.urls, evalue.code)
-                    )
+                    self.fire(redirect(req, res, evalue.urls, evalue.code))
                 elif isinstance(evalue, HTTPException):
                     if evalue.traceback:
-                        self.fire(
-                            httperror(
-                                req, res, evalue.code,
-                                description=evalue.description,
-                                error=error
-                            )
-                        )
+                        self.fire(httperror(req, res, evalue.code, description=evalue.description, error=error))
                     else:
-                        self.fire(
-                            httperror(
-                                req, res, evalue.code,
-                                description=evalue.description
-                            )
-                        )
+                        self.fire(httperror(req, res, evalue.code, description=evalue.description))
                 else:
                     self.fire(httperror(req, res, error=error))
             else:
@@ -396,41 +377,28 @@ class HTTP(BaseComponent):
                 value.event = e
                 value.notify = True
         elif isinstance(value, tuple):
-            etype, evalue, traceback = error = value
+            _etype, evalue, _traceback = error = value
 
             if isinstance(evalue, RedirectException):
-                self.fire(
-                    redirect(req, res, evalue.urls, evalue.code)
-                )
+                self.fire(redirect(req, res, evalue.urls, evalue.code))
             elif isinstance(evalue, HTTPException):
                 if evalue.traceback:
-                    self.fire(
-                        httperror(
-                            req, res, evalue.code,
-                            description=evalue.description,
-                            error=error
-                        )
-                    )
+                    self.fire(httperror(req, res, evalue.code, description=evalue.description, error=error))
                 else:
-                    self.fire(
-                        httperror(
-                            req, res, evalue.code,
-                            description=evalue.description
-                        )
-                    )
+                    self.fire(httperror(req, res, evalue.code, description=evalue.description))
             else:
                 self.fire(httperror(req, res, error=error))
         elif not isinstance(value, bool):
             res.body = value
             self.fire(response(res))
 
-    @handler("exception")
+    @handler('exception')
     def _on_exception(self, *args, **kwargs):
-        if not len(args) == 3:
+        if len(args) != 3:
             return
 
         etype, evalue, etraceback = args
-        fevent = kwargs["fevent"]
+        fevent = kwargs['fevent']
 
         if isinstance(fevent, response):
             res = fevent.args[0]
@@ -445,18 +413,11 @@ class HTTP(BaseComponent):
         else:
             return
 
-        if isinstance(evalue, HTTPException):
-            code = evalue.code
-        else:
-            code = None
+        code = evalue.code if isinstance(evalue, HTTPException) else None
 
-        self.fire(
-            httperror(
-                req, res, code=code, error=(etype, evalue, etraceback)
-            )
-        )
+        self.fire(httperror(req, res, code=code, error=(etype, evalue, etraceback)))
 
-    @handler("request_failure")
+    @handler('request_failure')
     def _on_request_failure(self, erequest, error):
         req, res = erequest.args
 
@@ -466,24 +427,16 @@ class HTTP(BaseComponent):
 
         req.handled = True
 
-        etype, evalue, traceback = error
+        _etype, evalue, _traceback = error
 
         if isinstance(evalue, RedirectException):
-            self.fire(
-                redirect(req, res, evalue.urls, evalue.code)
-            )
+            self.fire(redirect(req, res, evalue.urls, evalue.code))
         elif isinstance(evalue, HTTPException):
-            self.fire(
-                httperror(
-                    req, res, evalue.code,
-                    description=evalue.description,
-                    error=error
-                )
-            )
+            self.fire(httperror(req, res, evalue.code, description=evalue.description, error=error))
         else:
             self.fire(httperror(req, res, error=error))
 
-    @handler("response_failure")
+    @handler('response_failure')
     def _on_response_failure(self, eresponse, error):
         res = eresponse.args[0]
         req = res.request
@@ -495,24 +448,27 @@ class HTTP(BaseComponent):
         res = wrappers.Response(req, self._encoding, 500)
         self.fire(httperror(req, res, error=error))
 
-    @handler("request_complete")
+    @handler('request_complete')
     def _on_request_complete(self, *args, **kwargs):
-        """Dummy Event Handler for request events
+        """
+        Dummy Event Handler for request events
 
         - request_complete
         """
 
-    @handler("response_success", "response_complete")
+    @handler('response_success', 'response_complete')
     def _on_response_feedback(self, *args, **kwargs):
-        """Dummy Event Handler for response events
+        """
+        Dummy Event Handler for response events
 
         - response_success
         - response_complete
         """
 
-    @handler("stream_success", "stream_failure", "stream_complete")
+    @handler('stream_success', 'stream_failure', 'stream_complete')
     def _on_stream_feedback(self, *args, **kwargs):
-        """Dummy Event Handler for stream events
+        """
+        Dummy Event Handler for stream events
 
         - stream_success
         - stream_failure
