@@ -1,14 +1,15 @@
-"""Logger Component
+"""
+Logger Component
 
 This module implements Logger Components.
 """
+
 import datetime
 import os
 import sys
 from io import IOBase
 
 from circuits.core import BaseComponent, handler
-from circuits.six import string_types, text_type
 
 
 def formattime():
@@ -16,24 +17,23 @@ def formattime():
 
 
 class Logger(BaseComponent):
-
-    channel = "web"
+    channel = 'web'
 
     format = '%(h)s %(l)s %(u)s %(t)s "%(r)s" %(s)s %(b)s "%(f)s" "%(a)s"'
 
     def __init__(self, file=None, logger=None, **kwargs):
-        super(Logger, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
-        if isinstance(file, string_types):
-            self.file = open(os.path.abspath(os.path.expanduser(file)), "a")
-        elif isinstance(file, IOBase) or hasattr(file, "write"):
+        if isinstance(file, str):
+            self.file = open(os.path.abspath(os.path.expanduser(file)), 'a')
+        elif isinstance(file, IOBase) or hasattr(file, 'write'):
             self.file = file
         else:
             self.file = sys.stdout
 
         self.logger = logger
 
-    @handler("response_success")
+    @handler('response_success')
     def log_response(self, response_event, value):
         response = response_event.args[0]
         self.log(response)
@@ -44,23 +44,24 @@ class Logger(BaseComponent):
         outheaders = response.headers
         inheaders = request.headers or {}
 
-        protocol = "HTTP/%d.%d" % request.protocol
+        protocol = 'HTTP/%d.%d' % request.protocol
 
-        host = inheaders.get("X-Forwarded-For", (remote.name or remote.ip))
+        host = inheaders.get('X-Forwarded-For', (remote.name or remote.ip))
 
-        atoms = {"h": host,
-                 "l": "-",
-                 "u": getattr(request, "login", None) or "-",
-                 "t": formattime(),
-                 "r": "%s %s %s" % (request.method, request.path, protocol),
-                 "s": int(response.status),
-                 "b": outheaders.get("Content-Length", "") or "-",
-                 "f": inheaders.get("Referer", ""),
-                 "a": inheaders.get("User-Agent", ""),
-                 }
+        atoms = {
+            'h': host,
+            'l': '-',
+            'u': getattr(request, 'login', None) or '-',
+            't': formattime(),
+            'r': f'{request.method} {request.path} {protocol}',
+            's': int(response.status),
+            'b': outheaders.get('Content-Length', '') or '-',
+            'f': inheaders.get('Referer', ''),
+            'a': inheaders.get('User-Agent', ''),
+        }
         for k, v in list(atoms.items()):
-            if isinstance(v, text_type):
-                v = v.encode("utf8")
+            if isinstance(v, str):
+                v = v.encode('utf8')
             elif not isinstance(v, str):
                 v = str(v)
             # Fortunately, repr(str) escapes unprintable chars, \n, \t, etc
@@ -73,5 +74,5 @@ class Logger(BaseComponent):
             self.logger.info(self.format % atoms)
         else:
             self.file.write(self.format % atoms)
-            self.file.write("\n")
+            self.file.write('\n')
             self.file.flush()
