@@ -1,12 +1,13 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-"""Main
+"""
+Main
 
 circutis.web Web Server and Testing Tool.
 """
+
 import os
+from argparse import ArgumentParser
 from hashlib import md5
-from optparse import OptionParser
 from sys import stderr
 from wsgiref.simple_server import make_server
 from wsgiref.validate import validator
@@ -19,6 +20,7 @@ from circuits.web import BaseServer, Controller, Logger, Server, Static
 from circuits.web.tools import check_auth, digest_auth
 from circuits.web.wsgi import Application
 
+
 try:
     import hotshot
     import hotshot.stats
@@ -37,124 +39,134 @@ except ImportError:
     EPoll = None  # NOQA
 
 
-USAGE = "%prog [options] [docroot]"
-VERSION = "%prog v" + circuits.__version__
-
-
 def parse_options():
-    parser = OptionParser(usage=USAGE, version=VERSION)
+    parser = ArgumentParser()
 
-    parser.add_option(
-        "-b", "--bind",
-        action="store", type="string", default="0.0.0.0:8000", dest="bind",
-        help="Bind to address:[port]"
+    parser.add_argument(
+        '-b',
+        '--bind',
+        action='store',
+        default='0.0.0.0:8000',
+        help='Bind to address:[port]',
     )
 
-    parser.add_option(
-        "-l", "--logging",
-        action="store_true", default=False, dest="logging",
-        help="Enable logging of requests"
+    parser.add_argument(
+        '-l',
+        '--logging',
+        action='store_true',
+        default=False,
+        help='Enable logging of requests',
     )
 
-    parser.add_option(
-        "-p", "--passwd",
-        action="store", default=None, dest="passwd",
-        help="Location to passwd file for Digest Auth"
+    parser.add_argument(
+        '-p',
+        '--passwd',
+        action='store',
+        default=None,
+        help='Location to passwd file for Digest Auth',
     )
 
-    parser.add_option(
-        "-j", "--jobs",
-        action="store", type="int", default=0, dest="jobs",
-        help="Specify no. of jobs/processes to start"
+    parser.add_argument(
+        '-j',
+        '--jobs',
+        action='store',
+        type=int,
+        default=0,
+        help='Specify number of jobs/processes to start',
     )
 
-    parser.add_option(
-        "", "--poller",
-        action="store", type="string", default="select", dest="poller",
-        help="Specify type of poller to use"
+    parser.add_argument(
+        '--poller',
+        action='store',
+        default='select',
+        help='Specify type of poller to use',
     )
 
-    parser.add_option(
-        "", "--server",
-        action="store", type="string", default="server", dest="server",
-        help="Specify server to use"
+    parser.add_argument(
+        '--server',
+        action='store',
+        default='server',
+        help='Specify server to use',
     )
 
-    parser.add_option(
-        "", "--profile",
-        action="store_true", default=False, dest="profile",
-        help="Enable execution profiling support"
+    parser.add_argument(
+        '--profile',
+        action='store_true',
+        default=False,
+        help='Enable execution profiling support',
     )
 
-    parser.add_option(
-        "", "--debug",
-        action="store_true", default=False, dest="debug",
-        help="Enable debug mode"
+    parser.add_argument(
+        '--debug',
+        action='store_true',
+        default=False,
+        help='Enable debug mode',
     )
 
-    parser.add_option(
-        "", "--validate",
-        action="store_true", default=False, dest="validate",
-        help="Enable WSGI validation mode"
+    parser.add_argument(
+        '--validate',
+        action='store_true',
+        default=False,
+        help='Enable WSGI validation mode',
     )
 
-    opts, args = parser.parse_args()
+    parser.add_argument('-v', '--version', action='version', version=f'%(prog)s v{circuits.__version__}')
 
-    return opts, args
+    parser.add_argument('docroot', nargs='?', default=os.getcwd())
+
+    return parser.parse_args()
 
 
 class Authentication(Component):
+    channel = 'web'
 
-    channel = "web"
-
-    realm = "Secure Area"
-    users = {"admin": md5("admin").hexdigest()}
+    realm = 'Secure Area'
+    users = {'admin': md5(b'admin').hexdigest()}
 
     def __init__(self, channel=channel, realm=None, passwd=None):
-        super(Authentication, self).__init__(self, channel=channel)
+        super().__init__(self, channel=channel)
 
         if realm is not None:
             self.realm = realm
 
         if passwd is not None:
-            with open(passwd, "r") as f:
+            with open(passwd) as f:
                 lines = (line.strip() for line in f)
-                self.users = dict((line.split(":", 1) for line in lines))
+                self.users = dict(line.split(':', 1) for line in lines)
 
-    @handler("request", priority=10)
+    @handler('request', priority=10)
     def request(self, event, request, response):
         if not check_auth(request, response, self.realm, self.users):
             event.stop()
             return digest_auth(request, response, self.realm, self.users)
+        return None
 
 
 class HelloWorld(Component):
-
-    channel = "web"
+    channel = 'web'
 
     def request(self, request, response):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 class Root(Controller):
-
     def hello(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 def select_poller(poller):
-    if poller == "poll":
+    if poller == 'poll':
         if Poll is None:
             stderr.write(
-                "No poll support available - defaulting to Select..."
+                'No poll support available - defaulting to Select...',
             )
             Poller = Select
         else:
             Poller = Poll
-    elif poller == "epoll":
+    elif poller == 'epoll':
         if EPoll is None:
             stderr.write(
-                "No epoll support available - defaulting to Select..."
+                'No epoll support available - defaulting to Select...',
             )
             Poller = Select
         else:
@@ -166,8 +178,8 @@ def select_poller(poller):
 
 
 def parse_bind(bind):
-    if ":" in bind:
-        address, port = bind.split(":")
+    if ':' in bind:
+        address, port = bind.split(':')
         port = int(port)
     else:
         address, port = bind, 8000
@@ -176,12 +188,12 @@ def parse_bind(bind):
 
 
 def main():
-    opts, args = parse_options()
+    opts = parse_options()
 
     bind = parse_bind(opts.bind)
 
     if opts.validate:
-        application = (Application() + Root())
+        application = Application() + Root()
         app = validator(application)
 
         httpd = make_server(bind[0], bind[1], app)
@@ -196,31 +208,29 @@ def main():
     Poller = select_poller(opts.poller.lower())
     Poller().register(manager)
 
-    if opts.server.lower() == "base":
+    if opts.server.lower() == 'base':
         BaseServer(bind).register(manager)
         HelloWorld().register(manager)
     else:
         Server(bind).register(manager)
         Root().register(manager)
 
-    docroot = os.getcwd() if not args else args[0]
-
-    Static(docroot=docroot, dirlisting=True).register(manager)
+    Static(docroot=opts.docroot, dirlisting=True).register(manager)
 
     opts.passwd and Authentication(passwd=opts.passwd).register(manager)
 
     opts.logging and Logger().register(manager)
 
     if opts.profile and hotshot:
-        profiler = hotshot.Profile(".profile")
+        profiler = hotshot.Profile('.profile')
         profiler.start()
 
     if opts.debug:
-        print(graph(manager, name="circuits.web"))
+        print(graph(manager, name='circuits.web'))
         print()
         print(inspect(manager))
 
-    for i in range(opts.jobs):
+    for _i in range(opts.jobs):
         manager.start(process=True)
 
     manager.run()
@@ -229,11 +239,11 @@ def main():
         profiler.stop()
         profiler.close()
 
-        stats = hotshot.stats.load(".profile")
+        stats = hotshot.stats.load('.profile')
         stats.strip_dirs()
-        stats.sort_stats("time", "calls")
+        stats.sort_stats('time', 'calls')
         stats.print_stats(20)
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
