@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 '''
 Parser for multipart/form-data
 ==============================
 
 This module provides a parser for the multipart/form-data format. It can read
 from a file, a socket or a WSGI environment. The parser can be used to replace
-cgi.FieldStorage (without the bugs) and works with Python 2.5+ and 3.x (2to3).
+cgi.FieldStorage (without the bugs) and works with Python 3.x.
 
 Licence (MIT)
 -------------
@@ -40,14 +39,9 @@ __license__ = 'MIT'
 import re
 from tempfile import TemporaryFile
 from wsgiref.headers import Headers
+from urllib.parse import parse_qs
 
-from circuits.six import text_type
-from circuits.six.moves.urllib_parse import parse_qs
-
-try:
-    from io import BytesIO
-except ImportError:  # pragma: no cover (fallback for Python 2.5)
-    from StringIO import StringIO as BytesIO
+from io import BytesIO
 
 
 ##############################################################################
@@ -55,21 +49,14 @@ except ImportError:  # pragma: no cover (fallback for Python 2.5)
 ##############################################################################
 # Some of these were copied from bottle: http://bottle.paws.de/
 
-try:
-    from collections.abc import MutableMapping
-except ImportError:  # pragma: no cover (fallback for Python 2.5)
-    try:
-        from collections import MutableMapping
-    except ImportError:  # pragma: no cover (fallback for Python 2.5)
-        from UserDict import DictMixin as MutableMapping
+from collections.abc import MutableMapping
 
 
 class MultiDict(MutableMapping):
-
     """ A dict that remembers old values for each key """
 
     def __init__(self, *a, **k):
-        self.dict = dict()
+        self.dict = {}
         for k, v in dict(*a, **k).iteritems():
             self[k] = v
 
@@ -115,7 +102,7 @@ class MultiDict(MutableMapping):
 
 
 def tob(data, enc='utf8'):  # Convert strings to bytes (py2 and py3)
-    return data.encode(enc) if isinstance(data, text_type) else data
+    return data.encode(enc) if isinstance(data, str) else data
 
 
 def copy_file(stream, target, maxread=-1, buffer_size=2 * 16):
@@ -137,8 +124,8 @@ def copy_file(stream, target, maxread=-1, buffer_size=2 * 16):
 _special = re.escape('()<>@,;:\\"/[]?={} \t')
 _re_special = re.compile('[%s]' % _special)
 _qstr = '"(?:\\\\.|[^"])*"'  # Quoted string
-_value = '(?:[^%s]+|%s)' % (_special, _qstr)  # Save or quoted string
-_option = '(?:;|^)\s*([^%s]+)\s*=\s*(%s)' % (_special, _value)
+_value = f'(?:[^{_special}]+|{_qstr})'  # Save or quoted string
+_option = fr'(?:;|^)\s*([^{_special}]+)\s*=\s*({_value})'
 # key=value part of an Content-Type like header
 _re_option = re.compile(_option)
 
@@ -178,12 +165,13 @@ class MultipartError(ValueError):
     pass
 
 
-class MultipartParser(object):
+class MultipartParser:
 
     def __init__(self, stream, boundary, content_length=-1,
                  disk_limit=2 ** 30, mem_limit=2 ** 20, memfile_limit=2 ** 18,
                  buffer_size=2 ** 16, charset='latin1'):
-        ''' Parse a multipart/form-data byte stream. This object is an iterator
+        '''
+        Parse a multipart/form-data byte stream. This object is an iterator
             over the parts of the message.
 
             :param stream: A file-like stream. Must implement ``.read(size)``.
@@ -228,7 +216,8 @@ class MultipartParser(object):
         return [p for p in self if p.name == name]
 
     def _lineiter(self):
-        ''' Iterate over a binary file-like object line by line. Each line is
+        '''
+        Iterate over a binary file-like object line by line. Each line is
             returned as a (line, line_ending) tuple. If the line does not fit
             into self.buffer_size, line_ending is empty and the rest of the line
             is returned with the next iteration.
@@ -275,7 +264,7 @@ class MultipartParser(object):
         separator = tob('--') + tob(self.boundary)
         terminator = tob('--') + tob(self.boundary) + tob('--')
         # Consume first boundary. Ignore leading blank lines
-        for line, nl in lines:
+        for line, _nl in lines:
             if line:
                 break
         if line != separator:
@@ -312,7 +301,7 @@ class MultipartParser(object):
             raise MultipartError("Unexpected end of multipart stream.")
 
 
-class MultipartPart(object):
+class MultipartPart:
 
     def __init__(self, buffer_size=2 ** 16, memfile_limit=2 ** 18, charset='latin1'):
         self.headerlist = []
@@ -403,10 +392,11 @@ class MultipartPart(object):
 
 
 def parse_form_data(environ, charset='utf8', strict=False, **kw):
-    ''' Parse form data from an environ dict and return a (forms, files) tuple.
+    '''
+    Parse form data from an environ dict and return a (forms, files) tuple.
         Both tuple values are dictionaries with the form-field name as a key
-        (text_type) and lists as values (multiple values per key are possible).
-        The forms-dictionary contains form-field values as text_type strings.
+        (str) and lists as values (multiple values per key are possible).
+        The forms-dictionary contains form-field values as str strings.
         The files-dictionary contains :class:`MultipartPart` instances, either
         because the form-field was a file-upload or the value is to big to fit
         into memory limits.
@@ -416,7 +406,6 @@ def parse_form_data(environ, charset='utf8', strict=False, **kw):
         :param strict: If True, raise :exc:`MultipartError` on any parsing
                        errors. These are silently ignored by default.
     '''
-
     forms, files = MultiDict(), MultiDict()
     try:
         if environ.get('REQUEST_METHOD', 'GET').upper() not in ('POST', 'PUT'):
