@@ -1,7 +1,9 @@
-"""Web Servers
+"""
+Web Servers
 
 This module implements the several Web Server components.
 """
+
 from sys import stderr
 
 from circuits import io
@@ -15,8 +17,8 @@ from .http import HTTP
 
 
 class BaseServer(BaseComponent):
-
-    """Create a Base Web Server
+    """
+    Create a Base Web Server
 
     Create a Base Web Server (HTTP) bound to the IP Address / Port or
     UNIX Socket specified by the 'bind' parameter.
@@ -46,83 +48,91 @@ class BaseServer(BaseComponent):
     bound to the file given by the 'bind' argument.
     """
 
-    channel = "web"
+    channel = 'web'
 
-    def __init__(self, bind, encoding="utf-8", secure=False, certfile=None,
-                 channel=channel, display_banner=True, bufsize=BUFSIZE):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(BaseServer, self).__init__(channel=channel)
+    def __init__(
+        self,
+        bind,
+        encoding='utf-8',
+        secure=False,
+        certfile=None,
+        channel=channel,
+        display_banner=True,
+        bufsize=BUFSIZE,
+        **kwargs,
+    ):
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(channel=channel)
 
         self._display_banner = display_banner
 
-        if isinstance(bind, (int, list, tuple,)):
-            SocketType = TCPServer
-        else:
-            SocketType = TCPServer if ":" in bind else UNIXServer
+        SocketType = TCPServer if isinstance(bind, (int, list, tuple)) else TCPServer if ':' in bind else UNIXServer
 
         self.server = SocketType(
             bind,
             secure=secure,
             certfile=certfile,
             channel=channel,
-            bufsize=bufsize
+            bufsize=bufsize,
+            **kwargs,
         ).register(self)
 
         self.http = HTTP(
-            self, encoding=encoding, channel=channel
+            self,
+            encoding=encoding,
+            channel=channel,
         ).register(self)
 
     @property
     def host(self):
-        if hasattr(self, "server"):
+        if hasattr(self, 'server'):
             return self.server.host
+        return None
 
     @property
     def port(self):
-        if hasattr(self, "server"):
+        if hasattr(self, 'server'):
             return self.server.port
+        return None
 
     @property
     def display_banner(self):
-        return getattr(self, "_display_banner", False)
+        return getattr(self, '_display_banner', False)
 
     @property
     def secure(self):
-        if hasattr(self, "server"):
+        if hasattr(self, 'server'):
             return self.server.secure
+        return None
 
-    @handler("connect")
+    @handler('connect')
     def _on_connect(self, *args, **kwargs):
         """Dummy Event Handler for connect"""
 
-    @handler("closed")
+    @handler('closed')
     def _on_closed(self, *args, **kwargs):
         """Dummy Event Handler for closed"""
 
-    @handler("signal")
+    @handler('signal')
     def _on_signal(self, *args, **kwargs):
-        """signal Event Handler"""
-
+        """Signal Event Handler"""
         self.fire(close())
         Timer(3, terminate()).register(self)
 
-    @handler("terminate")
+    @handler('terminate')
     def _on_terminate(self):
         raise SystemExit(0)
 
-    @handler("ready")
+    @handler('ready')
     def _on_ready(self, server, bind):
         stderr.write(
-            "{} ready! Listening on: {}\n".format(
-                self.http.version, self.http.base
-            )
+            f'{self.http.version} ready! Listening on: {self.http.base}\n',
         )
 
 
 class Server(BaseServer):
-
-    """Create a Web Server
+    """
+    Create a Web Server
 
     Create a Web Server (HTTP) complete with the default Dispatcher to
     parse requests and posted form data dispatching to appropriate
@@ -132,29 +142,28 @@ class Server(BaseServer):
     """
 
     def __init__(self, bind, **kwargs):
-        "x.__init__(...) initializes x; see x.__class__.__doc__ for signature"
-
-        super(Server, self).__init__(bind, **kwargs)
+        """x.__init__(...) initializes x; see x.__class__.__doc__ for signature"""
+        super().__init__(bind, **kwargs)
 
         Dispatcher(channel=self.channel).register(self.http)
 
 
-class FakeSock():
-
+class FakeSock:
     def getpeername(self):
         return (None, None)
 
 
 class StdinServer(BaseComponent):
+    channel = 'web'
 
-    channel = "web"
-
-    def __init__(self, encoding="utf-8", channel=channel):
-        super(StdinServer, self).__init__(channel=channel)
+    def __init__(self, encoding='utf-8', channel=channel):
+        super().__init__(channel=channel)
 
         self.server = (io.stdin + io.stdout).register(self)
         self.http = HTTP(
-            self, encoding=encoding, channel=channel
+            self,
+            encoding=encoding,
+            channel=channel,
         ).register(self)
 
         Dispatcher(channel=self.channel).register(self)
@@ -171,10 +180,10 @@ class StdinServer(BaseComponent):
     def secure(self):
         return False
 
-    @handler("read", channel="stdin")
+    @handler('read', channel='stdin')
     def read(self, data):
         self.fire(read(FakeSock(), data))
 
-    @handler("write")
+    @handler('write')
     def write(self, sock, data):
         self.fire(write(data))
