@@ -1,48 +1,48 @@
-"""Session Components
+"""
+Session Components
 
 This module implements Session Components that can be used to store
 and access persistent information.
 """
-from abc import ABCMeta, abstractmethod
+
+from abc import ABC, abstractmethod
 from collections import defaultdict
 from hashlib import sha1 as sha
 from uuid import uuid4 as uuid
 
 from circuits import Component, handler
-from circuits.six import with_metaclass
 
 
-def who(request, encoding="utf-8"):
+def who(request, encoding='utf-8'):
     """Create a SHA1 Hash of the User's IP Address and User-Agent"""
-
     ip = request.remote.ip
-    agent = request.headers.get("User-Agent", "")
+    agent = request.headers.get('User-Agent', '')
 
-    return sha("{}{}".format(ip, agent).encode(encoding)).hexdigest()
+    return sha(f'{ip}{agent}'.encode(encoding)).hexdigest()
 
 
 def create_session(request):
-    """Create a unique session id from the request
+    """
+    Create a unique session id from the request
 
     Returns a unique session using ``uuid4()`` and a ``sha1()`` hash
     of the users IP Address and User Agent in the form of ``sid/who``.
     """
-
-    return "{}/{}".format(uuid().hex, who(request))
+    return f'{uuid().hex}/{who(request)}'
 
 
 def verify_session(request, sid):
-    """Verify a User's Session
+    """
+    Verify a User's Session
 
     This verifies the User's Session by verifying the SHA1 Hash
     of the User's IP Address and User-Agent match the provided
     Session ID.
     """
-
-    if "/" not in sid:
+    if '/' not in sid:
         return create_session(request)
 
-    user = sid.split("/", 1)[1]
+    user = sid.split('/', 1)[1]
 
     if user != who(request):
         return create_session(request)
@@ -51,9 +51,8 @@ def verify_session(request, sid):
 
 
 class Session(dict):
-
     def __init__(self, sid, data, store):
-        super(Session, self).__init__(data)
+        super().__init__(data)
 
         self._sid = sid
         self._store = store
@@ -77,8 +76,7 @@ class Session(dict):
             self.store.save(self.sid, self)
 
 
-class Store(with_metaclass(ABCMeta, object)):
-
+class Store(ABC):
     @abstractmethod
     def delete(self, sid):
         """Delete the session data identified by sid"""
@@ -93,7 +91,6 @@ class Store(with_metaclass(ABCMeta, object)):
 
 
 class MemoryStore(Store):
-
     def __init__(self):
         self._data = defaultdict(dict)
 
@@ -112,11 +109,10 @@ class MemoryStore(Store):
 
 
 class Sessions(Component):
+    channel = 'web'
 
-    channel = "web"
-
-    def __init__(self, name="circuits", store=MemoryStore, channel=channel):
-        super(Sessions, self).__init__(channel=channel)
+    def __init__(self, name='circuits', store=MemoryStore, channel=channel):
+        super().__init__(channel=channel)
 
         self._name = name
         self._store = store()
@@ -129,7 +125,7 @@ class Sessions(Component):
     def store(self):
         return self._store
 
-    @handler("request", priority=10)
+    @handler('request', priority=10)
     def request(self, request, response):
         if self.name in request.cookie:
             sid = request.cookie[self._name].value
