@@ -1,20 +1,19 @@
-"""Tools
+"""
+Tools
 
 This module implements tools used throughout circuits.web.
 These tools can also be used within Controllers and request handlers.
 """
+
 import hashlib
 import mimetypes
 import os
 import stat
+from collections.abc import Callable
 from datetime import datetime, timedelta
 from email.generator import _make_boundary
 from email.utils import formatdate
 from time import mktime
-try:
-    from collections import Callable
-except ImportError:
-    from collections.abc import Callable
 
 from circuits import BaseComponent, handler
 from circuits.web.wrappers import Host
@@ -23,15 +22,17 @@ from . import _httpauth
 from .errors import httperror, notfound, redirect, unauthorized
 from .utils import compress, get_ranges
 
+
 mimetypes.init()
-mimetypes.add_type("image/x-dwg", ".dwg")
-mimetypes.add_type("image/x-icon", ".ico")
-mimetypes.add_type("text/javascript", ".js")
-mimetypes.add_type("application/xhtml+xml", ".xhtml")
+mimetypes.add_type('image/x-dwg', '.dwg')
+mimetypes.add_type('image/x-icon', '.ico')
+mimetypes.add_type('text/javascript', '.js')
+mimetypes.add_type('application/xhtml+xml', '.xhtml')
 
 
 def expires(request, response, secs=0, force=False):
-    """Tool for influencing cache mechanisms using the 'Expires' header.
+    """
+    Tool for influencing cache mechanisms using the 'Expires' header.
 
     'secs' must be either an int or a datetime.timedelta, and indicates the
     number of seconds between response.time and when the response should
@@ -46,7 +47,6 @@ def expires(request, response, secs=0, force=False):
     'Etag', 'Last-Modified', 'Age', 'Expires'. If any are already present,
     none of the above response headers are set.
     """
-
     headers = response.headers
 
     cacheable = False
@@ -59,29 +59,29 @@ def expires(request, response, secs=0, force=False):
 
     if not cacheable:
         if isinstance(secs, timedelta):
-            secs = (86400 * secs.days) + secs.seconds
+            secs = secs.total_seconds()
 
         if secs == 0:
-            if force or "Pragma" not in headers:
-                headers["Pragma"] = "no-cache"
-            if request.protocol >= (1, 1):
-                if force or "Cache-Control" not in headers:
-                    headers["Cache-Control"] = "no-cache, must-revalidate"
+            if force or 'Pragma' not in headers:
+                headers['Pragma'] = 'no-cache'
+            if request.protocol >= (1, 1) and (force or 'Cache-Control' not in headers):
+                headers['Cache-Control'] = 'no-cache, must-revalidate'
             # Set an explicit Expires date in the past.
             now = datetime.now()
             lastyear = now.replace(year=now.year - 1)
             expiry = formatdate(
-                mktime(lastyear.timetuple()), usegmt=True
+                mktime(lastyear.timetuple()),
+                usegmt=True,
             )
         else:
             expiry = formatdate(response.time + secs, usegmt=True)
-        if force or "Expires" not in headers:
-            headers["Expires"] = expiry
+        if force or 'Expires' not in headers:
+            headers['Expires'] = expiry
 
 
-def serve_file(request, response, path, type=None, disposition=None,
-               name=None):
-    """Set status, headers, and body in order to serve the given file.
+def serve_file(request, response, path, type=None, disposition=None, name=None):
+    """
+    Set status, headers, and body in order to serve the given file.
 
     The Content-Type header will be set to the type arg, if provided.
     If not provided, the Content-Type will be guessed by the file extension
@@ -92,7 +92,6 @@ def serve_file(request, response, path, type=None, disposition=None,
     to the basename of path. If disposition is None, no Content-Disposition
     header will be written.
     """
-
     if not os.path.isabs(path):
         raise ValueError("'%s' is not an absolute path." % path)
 
@@ -109,7 +108,8 @@ def serve_file(request, response, path, type=None, disposition=None,
     # Set the Last-Modified response header, so that
     # modified-since validation code can work.
     response.headers['Last-Modified'] = formatdate(
-        st.st_mtime, usegmt=True
+        st.st_mtime,
+        usegmt=True,
     )
 
     result = validate_since(request, response)
@@ -118,18 +118,15 @@ def serve_file(request, response, path, type=None, disposition=None,
 
     if type is None:
         # Set content-type based on filename extension
-        ext = ""
-        i = path.rfind('.')
-        if i != -1:
-            ext = path[i:].lower()
-        type = mimetypes.types_map.get(ext, "text/plain")
+        ext = os.path.splitext(path)[-1].lower()
+        type = mimetypes.types_map.get(ext, 'text/plain')
     response.headers['Content-Type'] = type
 
     if disposition is not None:
         if name is None:
             name = os.path.basename(path)
-        cd = '%s; filename="%s"' % (disposition, name)
-        response.headers["Content-Disposition"] = cd
+        cd = f'{disposition}; filename="{name}"'
+        response.headers['Content-Disposition'] = cd
 
     # Set Content-Length and use an iterable (file object)
     #   this way CP won't load the whole file in memory
@@ -138,10 +135,10 @@ def serve_file(request, response, path, type=None, disposition=None,
 
     # HTTP/1.0 didn't have Range/Accept-Ranges headers, or the 206 code
     if request.protocol >= (1, 1):
-        response.headers["Accept-Ranges"] = "bytes"
+        response.headers['Accept-Ranges'] = 'bytes'
         r = get_ranges(request.headers.get('Range'), c_len)
         if r == []:
-            response.headers['Content-Range'] = "bytes */%s" % c_len
+            response.headers['Content-Range'] = 'bytes */%s' % c_len
             return httperror(request, response, 416)
         if r:
             if len(r) == 1:
@@ -149,9 +146,7 @@ def serve_file(request, response, path, type=None, disposition=None,
                 start, stop = r[0]
                 r_len = stop - start
                 response.status = 206
-                response.headers['Content-Range'] = (
-                    "bytes %s-%s/%s" % (start, stop - 1, c_len)
-                )
+                response.headers['Content-Range'] = f'bytes {start}-{stop - 1}/{c_len}'
                 response.headers['Content-Length'] = r_len
                 bodyfile.seek(start)
                 response.body = bodyfile.read(r_len)
@@ -159,29 +154,29 @@ def serve_file(request, response, path, type=None, disposition=None,
                 # Return a multipart/byteranges response.
                 response.status = 206
                 boundary = _make_boundary()
-                ct = "multipart/byteranges; boundary=%s" % boundary
+                ct = 'multipart/byteranges; boundary=%s' % boundary
                 response.headers['Content-Type'] = ct
-                if "Content-Length" in response.headers:
+                if 'Content-Length' in response.headers:
                     # Delete Content-Length header so finalize() recalcs it.
-                    del response.headers["Content-Length"]
+                    del response.headers['Content-Length']
 
                 def file_ranges():
                     # Apache compatibility:
-                    yield "\r\n"
+                    yield '\r\n'
 
                     for start, stop in r:
-                        yield "--" + boundary
-                        yield "\r\nContent-type: %s" % type
-                        yield ("\r\nContent-range: bytes %s-%s/%s\r\n\r\n"
-                               % (start, stop - 1, c_len))
+                        yield '--' + boundary
+                        yield '\r\nContent-type: %s' % type
+                        yield ('\r\nContent-range: bytes %s-%s/%s\r\n\r\n' % (start, stop - 1, c_len))
                         bodyfile.seek(start)
                         yield bodyfile.read(stop - start)
-                        yield "\r\n"
+                        yield '\r\n'
                     # Final boundary
-                    yield "--" + boundary + "--"
+                    yield '--' + boundary + '--'
 
                     # Apache compatibility:
-                    yield "\r\n"
+                    yield '\r\n'
+
                 response.body = file_ranges()
         else:
             response.headers['Content-Length'] = c_len
@@ -195,15 +190,15 @@ def serve_file(request, response, path, type=None, disposition=None,
 
 def serve_download(request, response, path, name=None):
     """Serve 'path' as an application/x-download attachment."""
-
-    type = "application/x-download"
-    disposition = "attachment"
+    type = 'application/x-download'
+    disposition = 'attachment'
 
     return serve_file(request, response, path, type, disposition, name)
 
 
 def validate_etags(request, response, autotags=False):
-    """Validate the current ETag against If-Match, If-None-Match headers.
+    """
+    Validate the current ETag against If-Match, If-None-Match headers.
 
     If autotags is True, an ETag response-header value will be provided
     from an MD5 hash of the response body (unless some other code has
@@ -218,21 +213,19 @@ def validate_etags(request, response, autotags=False):
     will be incorrect, and your application will break.
     See http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.24
     """
-
     # Guard against being run twice.
-    if hasattr(response, "ETag"):
-        return
+    if hasattr(response, 'ETag'):
+        return None
 
     status = response.status
 
     etag = response.headers.get('ETag')
 
     # Automatic ETag generation. See warning in docstring.
-    if (not etag) and autotags:
-        if status == 200:
-            etag = response.collapse_body()
-            etag = '"%s"' % hashlib.new('md5', etag).hexdigest()
-            response.headers['ETag'] = etag
+    if (not etag) and autotags and status == 200:
+        etag = response.collapse_body()
+        etag = '"%s"' % hashlib.new('md5', etag).hexdigest()
+        response.headers['ETag'] = etag
 
     response.ETag = etag
 
@@ -242,57 +235,66 @@ def validate_etags(request, response, autotags=False):
     if status >= 200 and status <= 299:
         conditions = request.headers.elements('If-Match') or []
         conditions = [str(x) for x in conditions]
-        if conditions and not (conditions == ["*"] or etag in conditions):
+        if conditions and not (conditions == ['*'] or etag in conditions):
             return httperror(
-                request, response, 412,
-                description="If-Match failed: ETag %r did not match %r" % (
-                    etag, conditions
-                )
+                request,
+                response,
+                412,
+                description='If-Match failed: ETag %r did not match %r'
+                % (
+                    etag,
+                    conditions,
+                ),
             )
 
         conditions = request.headers.elements('If-None-Match') or []
         conditions = [str(x) for x in conditions]
-        if conditions == ["*"] or etag in conditions:
-            if request.method in ("GET", "HEAD"):
+        if conditions == ['*'] or etag in conditions:
+            if request.method in ('GET', 'HEAD'):
                 return redirect(request, response, [], code=304)
-            else:
-                return httperror(
-                    request, response, 412,
-                    description=(
-                        "If-None-Match failed: ETag %r matched %r" % (
-                            etag, conditions
-                        )
+            return httperror(
+                request,
+                response,
+                412,
+                description=(
+                    'If-None-Match failed: ETag %r matched %r'
+                    % (
+                        etag,
+                        conditions,
                     )
-                )
+                ),
+            )
+        return None
+    return None
 
 
 def validate_since(request, response):
-    """Validate the current Last-Modified against If-Modified-Since headers.
+    """
+    Validate the current Last-Modified against If-Modified-Since headers.
 
     If no code has set the Last-Modified response header, then no validation
     will be performed.
     """
-
     lastmod = response.headers.get('Last-Modified')
     if lastmod:
         status = response.status
 
         since = request.headers.get('If-Unmodified-Since')
-        if since and since != lastmod:
-            if (status >= 200 and status <= 299) or status == 412:
-                return httperror(request, response, 412)
+        if since and since != lastmod and ((status >= 200 and status <= 299) or status == 412):
+            return httperror(request, response, 412)
 
         since = request.headers.get('If-Modified-Since')
-        if since and since == lastmod:
-            if (status >= 200 and status <= 299) or status == 304:
-                if request.method in ("GET", "HEAD"):
-                    return redirect(request, response, [], code=304)
-                else:
-                    return httperror(request, response, 412)
+        if since and since == lastmod and ((status >= 200 and status <= 299) or status == 304):
+            if request.method in ('GET', 'HEAD'):
+                return redirect(request, response, [], code=304)
+            return httperror(request, response, 412)
+        return None
+    return None
 
 
 def check_auth(request, response, realm, users, encrypt=None):
-    """Check Authentication
+    """
+    Check Authentication
 
     If an Authorization header contains credentials, return True, else False.
 
@@ -307,10 +309,9 @@ def check_auth(request, response, realm, users, encrypt=None):
                     the user-agent. if None it defaults to a md5 encryption.
     :type  encrypt: callable
     """
-
-    if "Authorization" in request.headers:
+    if 'Authorization' in request.headers:
         # make sure the provided credentials are correctly set
-        ah = _httpauth.parseAuthorization(request.headers.get("Authorization"))
+        ah = _httpauth.parseAuthorization(request.headers.get('Authorization'))
         if ah is None:
             return httperror(request, response, 400)
 
@@ -323,25 +324,24 @@ def check_auth(request, response, realm, users, encrypt=None):
                 users = users()  # expect it to return a dictionary
 
                 if not isinstance(users, dict):
-                    raise ValueError("Authentication users must be a dict")
+                    raise ValueError('Authentication users must be a dict')
 
                 # fetch the user password
-                password = users.get(ah["username"], None)
+                password = users.get(ah['username'], None)
             except TypeError:
                 # returns a password (encrypted or clear text)
-                password = users(ah["username"])
+                password = users(ah['username'])
         else:
             if not isinstance(users, dict):
-                raise ValueError("Authentication users must be a dict")
+                raise ValueError('Authentication users must be a dict')
 
             # fetch the user password
-            password = users.get(ah["username"], None)
+            password = users.get(ah['username'], None)
 
         # validate the Authorization by re-computing it here
         # and compare it with what the user-agent provided
-        if _httpauth.checkResponse(ah, password, method=request.method,
-                                   encrypt=encrypt, realm=realm):
-            request.login = ah["username"]
+        if _httpauth.checkResponse(ah, password, method=request.method, encrypt=encrypt, realm=realm):
+            request.login = ah['username']
             return True
 
         request.login = False
@@ -349,7 +349,8 @@ def check_auth(request, response, realm, users, encrypt=None):
 
 
 def basic_auth(request, response, realm, users, encrypt=None):
-    """Perform Basic Authentication
+    """
+    Perform Basic Authentication
 
     If auth fails, returns an Unauthorized error  with a
     basic authentication header.
@@ -365,18 +366,18 @@ def basic_auth(request, response, realm, users, encrypt=None):
                     the user-agent. if None it defaults to a md5 encryption.
     :type  encrypt: callable
     """
-
     if check_auth(request, response, realm, users, encrypt):
-        return
+        return None
 
     # inform the user-agent this path is protected
-    response.headers["WWW-Authenticate"] = _httpauth.basicAuth(realm)
+    response.headers['WWW-Authenticate'] = _httpauth.basicAuth(realm)
 
     return unauthorized(request, response)
 
 
 def digest_auth(request, response, realm, users):
-    """Perform Digest Authentication
+    """
+    Perform Digest Authentication
 
     If auth fails, raise 401 with a digest authentication header.
 
@@ -387,18 +388,18 @@ def digest_auth(request, response, realm, users):
                   returning a dict.
     :type  users: dict or callable
     """
-
     if check_auth(request, response, realm, users):
-        return
+        return None
 
     # inform the user-agent this path is protected
-    response.headers["WWW-Authenticate"] = _httpauth.digestAuth(realm)
+    response.headers['WWW-Authenticate'] = _httpauth.digestAuth(realm)
 
     return unauthorized(request, response)
 
 
-def gzip(response, level=4, mime_types=("text/html", "text/plain",)):
-    """Try to gzip the response body if Content-Type in mime_types.
+def gzip(response, level=4, mime_types=('text/html', 'text/plain')):
+    """
+    Try to gzip the response body if Content-Type in mime_types.
 
     response.headers['Content-Type'] must be set to one of the
     values in the mime_types arg before calling this function.
@@ -409,14 +410,13 @@ def gzip(response, level=4, mime_types=("text/html", "text/plain",)):
         * No 'gzip' or 'x-gzip' with a qvalue > 0 is present
         * The 'identity' value is given with a qvalue > 0.
     """
-
     if not response.body:
         # Response body is empty (might be a 304 for instance)
         return response
 
     # If returning cached content (which should already have been gzipped),
     # don't re-zip.
-    if getattr(response.request, "cached", False):
+    if getattr(response.request, 'cached', False):
         return response
 
     acceptable = response.request.headers.elements('Accept-Encoding')
@@ -439,37 +439,39 @@ def gzip(response, level=4, mime_types=("text/html", "text/plain",)):
                 return response
             if ct in mime_types:
                 # Return a generator that compresses the page
-                varies = response.headers.get("Vary", "")
-                varies = [x.strip() for x in varies.split(",") if x.strip()]
-                if "Accept-Encoding" not in varies:
-                    varies.append("Accept-Encoding")
-                response.headers['Vary'] = ", ".join(varies)
+                varies = response.headers.get('Vary', '')
+                varies = [x.strip() for x in varies.split(',') if x.strip()]
+                if 'Accept-Encoding' not in varies:
+                    varies.append('Accept-Encoding')
+                response.headers['Vary'] = ', '.join(varies)
 
                 response.headers['Content-Encoding'] = 'gzip'
                 response.body = compress(response.body, level)
-                if "Content-Length" in response.headers:
+                if 'Content-Length' in response.headers:
                     # Delete Content-Length header so finalize() recalcs it.
-                    del response.headers["Content-Length"]
+                    del response.headers['Content-Length']
             return response
     return httperror(
-        response.request, response, 406, description="identity, gzip"
+        response.request,
+        response,
+        406,
+        description='identity, gzip',
     )
 
 
 class ReverseProxy(BaseComponent):
-
     headers = ('X-Real-IP', 'X-Forwarded-For')
 
     def init(self, headers=None):
-        """Web Component for identifying the original client IP when a reverse proxy is used
+        """
+        Web Component for identifying the original client IP when a reverse proxy is used
 
         :param headers: List of HTTP headers to read the original client IP
         """
-
         if headers:
             self.headers = headers
 
     @handler('request', priority=1)
     def _on_request(self, req, *_):
         ip = [v for v in map(req.headers.get, self.headers) if v]
-        req.remote = ip and Host(ip[0], "", ip[0]) or req.remote
+        req.remote = (ip and Host(ip[0], '', ip[0])) or req.remote
