@@ -20,15 +20,12 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-'''This is a module for dealing with urls. In particular, sanitizing them.'''
+"""This is a module for dealing with urls. In particular, sanitizing them."""
 
 import codecs
 import re
+from urllib.parse import quote, unquote, urljoin, urlparse, urlunparse
 
-from circuits.six import string_types, text_type
-from circuits.six.moves.urllib_parse import (
-    quote, unquote, urljoin, urlparse, urlunparse,
-)
 
 # Come codes that we'll need
 IDNA = codecs.lookup('idna')
@@ -39,111 +36,106 @@ W1252 = codecs.lookup('windows-1252')
 # The default ports associated with each scheme
 PORTS = {
     'http': 80,
-    'https': 443
+    'https': 443,
 }
 
 
 def parse_url(url, encoding='utf-8'):
-    '''Parse the provided url string and return an URL object'''
+    """Parse the provided url string and return an URL object"""
     return URL.parse(url, encoding)
 
 
-class URL(object):
-
-    '''
+class URL:
+    """
     For more information on how and what we parse / sanitize:
         http://tools.ietf.org/html/rfc1808.html
     The more up-to-date RFC is this one:
         http://www.ietf.org/rfc/rfc3986.txt
-    '''
+    """
 
     @classmethod
     def parse(cls, url, encoding):
-        '''Parse the provided url, and return a URL instance'''
-
-        if isinstance(url, text_type):
-            parsed = urlparse(url.encode('utf-8'))
-        else:
-            parsed = urlparse(url.decode(encoding).encode('utf-8'))
+        """Parse the provided url, and return a URL instance"""
+        parsed = urlparse(url.encode('utf-8')) if isinstance(url, str) else urlparse(url.decode(encoding).encode('utf-8'))
 
         if isinstance(parsed.port, int):
-            port = (
-                str(parsed.port).encode("utf-8")
-                if parsed.port not in (80, 443)
-                else None
-            )
+            port = str(parsed.port).encode('utf-8') if parsed.port not in (80, 443) else None
         else:
             port = None
 
         return cls(
-            parsed.scheme, parsed.hostname,
-            port, parsed.path, parsed.params,
-            parsed.query, parsed.fragment
+            parsed.scheme,
+            parsed.hostname,
+            port,
+            parsed.path,
+            parsed.params,
+            parsed.query,
+            parsed.fragment,
         )
 
-    def __init__(self, scheme, host, port, path,
-                 params=b"", query=b"", fragment=b""):
-        assert not type(port) is int
+    def __init__(self, scheme, host, port, path, params=b'', query=b'', fragment=b''):
+        assert type(port) is not int
         self._scheme = scheme
         self._host = host
         self._port = port
         self._path = path or b'/'
         self._params = re.sub(b'^;+', b'', params)
         self._params = re.sub(
-            b'^;|;$', b'', re.sub(b';{2,}', b';', self._params)
+            b'^;|;$',
+            b'',
+            re.sub(b';{2,}', b';', self._params),
         )
         # Strip off extra leading ?'s
         self._query = query.lstrip(b'?')
         self._query = re.sub(
-            b'^&|&$', b'', re.sub(b'&{2,}', b'&', self._query)
+            b'^&|&$',
+            b'',
+            re.sub(b'&{2,}', b'&', self._query),
         )
         self._fragment = fragment
 
-    def __call__(self, path, encoding="utf-8"):
+    def __call__(self, path, encoding='utf-8'):
         return self.relative(path, encoding=encoding).unicode()
 
     def equiv(self, other):
-        '''Return true if this url is equivalent to another'''
-        if isinstance(other, string_types[0]):
-            _other = self.parse(other, 'utf-8')
-        else:
-            _other = self.parse(other.utf8(), 'utf-8')
+        """Return true if this url is equivalent to another"""
+        _other = self.parse(other, 'utf-8') if isinstance(other, str) else self.parse(other.utf8(), 'utf-8')
 
         _self = self.parse(self.utf8(), 'utf-8')
         _self.lower().canonical().defrag().abspath().escape().punycode()
         _other.lower().canonical().defrag().abspath().escape().punycode()
 
         result = (
-            _self._scheme == _other._scheme and
-            _self._host == _other._host and
-            _self._path == _other._path and
-            _self._params == _other._params and
-            _self._query == _other._query)
+            _self._scheme == _other._scheme
+            and _self._host == _other._host
+            and _self._path == _other._path
+            and _self._params == _other._params
+            and _self._query == _other._query
+        )
 
         if result:
             if _self._port and not _other._port:
                 # Make sure _self._port is the default for the scheme
                 return _self._port == PORTS.get(_self._scheme, None)
-            elif _other._port and not _self._port:
+            if _other._port and not _self._port:
                 # Make sure _other._port is the default for the scheme
                 return _other._port == PORTS.get(_other._scheme, None)
-            else:
-                return _self._port == _other._port
-        else:
-            return False
+            return _self._port == _other._port
+        return False
 
     def __eq__(self, other):
-        '''Return true if this url is /exactly/ equal to another'''
-        if isinstance(other, string_types):
+        """Return true if this url is /exactly/ equal to another"""
+        if isinstance(other, str):
             return self.__eq__(self.parse(other, 'utf-8'))
         return (
-            self._scheme == other._scheme and
-            self._host == other._host and
-            self._path == other._path and
-            self._port == other._port and
-            self._params == other._params and
-            self._query == other._query and
-            self._fragment == other._fragment)
+            self._scheme == other._scheme
+            and self._host == other._host
+            and self._path == other._path
+            and self._port == other._port
+            and self._params == other._params
+            and self._query == other._query
+            and self._fragment == other._fragment
+        )
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -155,35 +147,35 @@ class URL(object):
         return '<url.URL object "%s" >' % self.utf8()
 
     def canonical(self):
-        '''Canonicalize this url. This includes reordering parameters and args
-        to have a consistent ordering'''
+        """
+        Canonicalize this url. This includes reordering parameters and args
+        to have a consistent ordering
+        """
         self._query = b'&'.join(
-            sorted([q for q in self._query.split(b'&')])
+            sorted(q for q in self._query.split(b'&')),
         )
         self._params = b';'.join(
-            sorted([q for q in self._params.split(b';')])
+            sorted(q for q in self._params.split(b';')),
         )
         return self
 
     def defrag(self):
-        '''Remove the fragment from this url'''
+        """Remove the fragment from this url"""
         self._fragment = None
         return self
 
     def deparam(self, params=None):
-        '''Strip any of the provided parameters out of the url'''
+        """Strip any of the provided parameters out of the url"""
         # And remove all the black-listed query parameters
-        self._query = '&'.join(q for q in self._query.split('&')
-                               if q.partition('=')[0].lower() not in params)
+        self._query = '&'.join(q for q in self._query.split('&') if q.partition('=')[0].lower() not in params)
         # And remove all the black-listed param parameters
-        self._params = ';'.join(q for q in self._params.split(';') if
-                                q.partition('=')[0].lower() not in params)
+        self._params = ';'.join(q for q in self._params.split(';') if q.partition('=')[0].lower() not in params)
         return self
 
     def abspath(self):
-        '''Clear out any '..' and excessive slashes from the path'''
+        """Clear out any '..' and excessive slashes from the path"""
         # Remove double forward-slashes from the path
-        path = re.sub(br'\/{2,}', b'/', self._path)
+        path = re.sub(rb'\/{2,}', b'/', self._path)
         # With that done, go through and remove all the relative references
         unsplit = []
         directory = False
@@ -207,59 +199,65 @@ class URL(object):
         return self
 
     def lower(self):
-        '''Lowercase the hostname'''
+        """Lowercase the hostname"""
         if self._host is not None:
             self._host = self._host.lower()
         return self
 
     def sanitize(self):
-        '''A shortcut to abspath, escape and lowercase'''
+        """A shortcut to abspath, escape and lowercase"""
         return self.abspath().escape().lower()
 
     def escape(self):
-        '''Make sure that the path is correctly escaped'''
-        self._path = quote(unquote(self._path.decode("utf-8"))).encode("utf-8")
+        """Make sure that the path is correctly escaped"""
+        self._path = quote(unquote(self._path.decode('utf-8'))).encode('utf-8')
         return self
 
     def unescape(self):
-        '''Unescape the path'''
+        """Unescape the path"""
         self._path = unquote(self._path)
         return self
 
     def encode(self, encoding):
-        '''Return the url in an arbitrary encoding'''
+        """Return the url in an arbitrary encoding"""
         netloc = self._host
         if self._port:
-            netloc += (b':' + bytes(self._port))
+            netloc += b':' + bytes(self._port)
 
-        result = urlunparse((
-            self._scheme, netloc, self._path,
-            self._params, self._query, self._fragment
-        ))
+        result = urlunparse(
+            (
+                self._scheme,
+                netloc,
+                self._path,
+                self._params,
+                self._query,
+                self._fragment,
+            )
+        )
         return result.decode('utf-8').encode(encoding)
 
     def relative(self, path, encoding='utf-8'):
-        '''Evaluate the new path relative to the current url'''
-        if isinstance(path, text_type):
+        """Evaluate the new path relative to the current url"""
+        if isinstance(path, str):
             newurl = urljoin(self.utf8(), path.encode('utf-8'))
         else:
             newurl = urljoin(
-                self.utf8(), path.decode(encoding).encode('utf-8')
+                self.utf8(),
+                path.decode(encoding).encode('utf-8'),
             )
         return URL.parse(newurl, 'utf-8')
 
     def punycode(self):
-        '''Convert to punycode hostname'''
+        """Convert to punycode hostname"""
         if self._host:
             self._host = IDNA.encode(self._host.decode('utf-8'))[0]
             return self
         raise TypeError('Cannot punycode a relative url')
 
     def unpunycode(self):
-        '''Convert to an unpunycoded hostname'''
+        """Convert to an unpunycoded hostname"""
         if self._host:
-            self._host = IDNA.decode(
-                self._host.decode('utf-8'))[0].encode('utf-8')
+            self._host = IDNA.decode(self._host.decode('utf-8'))[0].encode('utf-8')
             return self
         raise TypeError('Cannot unpunycode a relative url')
 
@@ -267,8 +265,10 @@ class URL(object):
     # Information about the type of url it is
     ###########################################################################
     def absolute(self):
-        '''Return True if this is a fully-qualified URL with a hostname and
-        everything'''
+        """
+        Return True if this is a fully-qualified URL with a hostname and
+        everything
+        """
         return bool(self._host)
 
     ###########################################################################
@@ -276,9 +276,9 @@ class URL(object):
     # return strings
     ###########################################################################
     def unicode(self):
-        '''Return a unicode version of this url'''
+        """Return a unicode version of this url"""
         return self.encode('utf-8').decode('utf-8')
 
     def utf8(self):
-        '''Return a utf-8 version of this url'''
+        """Return a utf-8 version of this url"""
         return self.encode('utf-8')
