@@ -1,24 +1,22 @@
-"""Utilities
+"""
+Utilities
 
 This module implements utility functions.
 """
+
 import os
 import re
 import stat
 import struct
 import time
 import zlib
-from cgi import FieldStorage
-from io import TextIOWrapper
 from math import sqrt
+from urllib.parse import parse_qs as _parse_qs
 
-from circuits.net.utils import is_ssl_handshake  # noqa
-from circuits.six.moves.urllib_parse import parse_qs as _parse_qs
+from .exceptions import RangeUnsatisfiable
 
-from .exceptions import RangeUnsatisfiable, RequestEntityTooLarge
 
-quoted_slash = re.compile("(?i)%2F")
-image_map_pattern = re.compile("^[0-9]+,[0-9]+$")
+image_map_pattern = re.compile('^[0-9]+,[0-9]+$')
 
 
 def is_unix_socket(path):
@@ -36,85 +34,37 @@ def average(xs):
 
 def variance(xs):
     avg = average(xs)
-    return list(map(lambda x: (x - avg) ** 2, xs))
+    return [(x - avg) ** 2 for x in xs]
 
 
 def stddev(xs):
     return sqrt(average(variance(xs)))
 
 
-def parse_body(request, response, params):
-    if "Content-Type" not in request.headers:
-        request.headers["Content-Type"] = ""
-
-    try:
-        form = FieldStorage(
-            environ={"REQUEST_METHOD": "POST"},
-            fp=TextIOWrapper(request.body),
-            headers=request.headers,
-            keep_blank_values=True
-        )
-    except Exception as e:
-        if e.__class__.__name__ == 'MaxSizeExceeded':
-            # Post data is too big
-            raise RequestEntityTooLarge()
-        raise
-
-    if form.file:
-        request.body = form.file
-    else:
-        params.update(dictform(form))
-
-
 def parse_qs(query_string, keep_blank_values=True):
-    """parse_qs(query_string) -> dict
+    """
+    parse_qs(query_string) -> dict
 
     Build a params dictionary from a query_string.
     If keep_blank_values is True (the default), keep
     values that are blank.
     """
-
     if image_map_pattern.match(query_string):
         # Server-side image map. Map the coords to "x" and "y"
         # (like CGI::Request does).
-        pm = query_string.split(",")
-        return {"x": int(pm[0]), "y": int(pm[1])}
-    else:
-        pm = _parse_qs(query_string, keep_blank_values)
-        return dict((k, v[0]) for k, v in pm.items() if v)
-
-
-def dictform(form):
-    d = {}
-    for key in list(form.keys()):
-        values = form[key]
-        if isinstance(values, list):
-            d[key] = []
-            for item in values:
-                if item.filename is not None:
-                    value = item  # It's a file upload
-                else:
-                    value = item.value  # It's a regular field
-                d[key].append(value)
-        else:
-            if values.filename is not None:
-                value = values  # It's a file upload
-            else:
-                value = values.value  # It's a regular field
-            d[key] = value
-    return d
+        pm = query_string.split(',')
+        return {'x': int(pm[0]), 'y': int(pm[1])}
+    pm = _parse_qs(query_string, keep_blank_values)
+    return {k: v[0] for k, v in pm.items() if v}
 
 
 def compress(body, compress_level):
     """Compress 'body' at the given compress_level."""
-
     # Header
-    yield b"\037\213\010\0" \
-        + struct.pack("<L", int(time.time())) \
-        + b"\002\377"
+    yield b'\037\213\010\0' + struct.pack('<L', int(time.time())) + b'\002\377'
 
     size = 0
-    crc = zlib.crc32(b"")
+    crc = zlib.crc32(b'')
 
     zobj = zlib.compressobj(
         compress_level,
@@ -126,19 +76,18 @@ def compress(body, compress_level):
 
     for chunk in body:
         if not isinstance(chunk, bytes):
-            chunk = chunk.encode("utf-8")
+            chunk = chunk.encode('utf-8')
 
         size += len(chunk)
         crc = zlib.crc32(chunk, crc)
         yield zobj.compress(chunk)
 
-    yield zobj.flush() \
-        + struct.pack("<l", crc) \
-        + struct.pack("<L", size & 0xFFFFFFFF)
+    yield zobj.flush() + struct.pack('<l', crc) + struct.pack('<L', size & 0xFFFFFFFF)
 
 
 def get_ranges(headervalue, content_length):
-    """Return a list of (start, stop) indices from a Range header, or None.
+    """
+    Return a list of (start, stop) indices from a Range header, or None.
 
     Each (start, stop) tuple will be composed of two ints, which are suitable
     for use in a slicing operation. That is, the header "Range: bytes=3-6",
@@ -147,14 +96,13 @@ def get_ranges(headervalue, content_length):
 
     If this function returns an empty list, you should return HTTP 416.
     """
-
     if not headervalue:
         return None
 
     result = []
-    bytesunit, byteranges = headervalue.split("=", 1)
-    for brange in byteranges.split(","):
-        start, stop = [x.strip() for x in brange.split("-", 1)]
+    _bytesunit, byteranges = headervalue.split('=', 1)
+    for brange in byteranges.split(','):
+        start, stop = (x.strip() for x in brange.split('-', 1))
         if start:
             if not stop:
                 stop = content_length - 1
