@@ -1,35 +1,24 @@
-"""Request/Response Wrappers
+"""
+Request/Response Wrappers
 
 This module implements the Request and Response objects.
 """
+
+from email.utils import formatdate
 from functools import partial
+from http.cookies import SimpleCookie
 from io import BytesIO
 from time import time
 
 from circuits.net.sockets import BUFSIZE
-from circuits.six import binary_type, text_type
 
 from .constants import HTTP_STATUS_CODES, SERVER_VERSION
 from .errors import httperror
 from .headers import Headers
 from .url import parse_url
 
-try:
-    from Cookie import SimpleCookie
-except ImportError:
-    from http.cookies import SimpleCookie  # NOQA
 
-try:
-    from email.utils import formatdate
-    formatdate = partial(formatdate, usegmt=True)
-except ImportError:
-    from rfc822 import formatdate  # NOQA
-
-
-try:
-    unicode
-except NameError:
-    unicode = str
+formatdate = partial(formatdate, usegmt=True)
 
 
 def file_generator(input, chunkSize=BUFSIZE):
@@ -40,17 +29,17 @@ def file_generator(input, chunkSize=BUFSIZE):
     input.close()
 
 
-class Host(object):
-
-    """An internet address.
+class Host:
+    """
+    An internet address.
 
     name should be the client's host name. If not available (because no DNS
     lookup is performed), the IP address should be used instead.
     """
 
-    ip = "0.0.0.0"
+    ip = '0.0.0.0'
     port = 80
-    name = "unknown.tld"
+    name = 'unknown.tld'
 
     def __init__(self, ip, port, name=None):
         self.ip = ip
@@ -60,16 +49,15 @@ class Host(object):
         self.name = name
 
     def __repr__(self):
-        return "Host(%r, %r, %r)" % (self.ip, self.port, self.name)
+        return f'Host({self.ip!r}, {self.port!r}, {self.name!r})'
 
 
-class HTTPStatus(object):
-
-    __slots__ = ("_reason", "_status",)
+class HTTPStatus:
+    __slots__ = ('_reason', '_status')
 
     def __init__(self, status=200, reason=None):
         self._status = status
-        self._reason = reason or HTTP_STATUS_CODES.get(status, "")
+        self._reason = reason or HTTP_STATUS_CODES.get(status, '')
 
     def __int__(self):
         return self._status
@@ -77,35 +65,33 @@ class HTTPStatus(object):
     def __lt__(self, other):
         if isinstance(other, int):
             return self._status < other
-        return super(HTTPStatus, self).__lt__(other)
+        return super().__lt__(other)
 
     def __gt__(self, other):
         if isinstance(other, int):
             return self._status > other
-        return super(HTTPStatus, self).__gt__(other)
+        return super().__gt__(other)
 
     def __le__(self, other):
         if isinstance(other, int):
             return self._status <= other
-        return super(HTTPStatus, self).__le__(other)
+        return super().__le__(other)
 
     def __ge__(self, other):
         if isinstance(other, int):
             return self._status >= other
-        return super(HTTPStatus, self).__ge__(other)
+        return super().__ge__(other)
 
     def __eq__(self, other):
         if isinstance(other, int):
             return self._status == other
-        return super(HTTPStatus, self).__eq__(other)
+        return super().__eq__(other)
 
     def __str__(self):
-        return "{:d} {}".format(self._status, self._reason)
+        return f'{self._status:d} {self._reason}'
 
     def __repr__(self):
-        return "<Status (status={:d} reason={}>".format(
-            self._status, self._reason
-        )
+        return f'<Status (status={self._status:d} reason={self._reason}>'
 
     def __format__(self, format_spec):
         return format(str(self), format_spec)
@@ -119,9 +105,9 @@ class HTTPStatus(object):
         return self._reason
 
 
-class Request(object):
-
-    """Creates a new Request object to hold information about a request.
+class Request:
+    """
+    Creates a new Request object to hold information about a request.
 
     :param sock: The socket object of the request.
     :type  sock: socket.socket
@@ -145,29 +131,27 @@ class Request(object):
     server = None
     """:cvar: A reference to the underlying server"""
 
-    scheme = "http"
+    scheme = 'http'
     protocol = (1, 1)
-    host = ""
-    local = Host("127.0.0.1", 80)
-    remote = Host("", 0)
+    host = ''
+    local = Host('127.0.0.1', 80)
+    remote = Host('', 0)
 
     index = None
-    script_name = ""
+    script_name = ''
 
     login = None
     handled = False
 
-    def __init__(self, sock, method="GET", scheme="http", path="/",
-                 protocol=(1, 1), qs="", headers=None, server=None):
-        "initializes x; see x.__class__.__doc__ for signature"
-
+    def __init__(self, sock, method='GET', scheme='http', path='/', protocol=(1, 1), qs='', headers=None, server=None):
+        """Initializes x; see x.__class__.__doc__ for signature"""
         self.sock = sock
         self.method = method
         self.scheme = scheme or Request.scheme
         self.path = path
         self.protocol = protocol
         self.qs = qs
-        self.print_debug = getattr(server, "display_banner", False)
+        self.print_debug = getattr(server, 'display_banner', False)
 
         self.headers = headers or Headers()
         self.server = server
@@ -183,7 +167,7 @@ class Request(object):
                 ip, port = None, None
             self.remote = Host(ip, port, name)
 
-        cookie = self.headers.get("Cookie")
+        cookie = self.headers.get('Cookie')
         if cookie is not None:
             self.cookie.load(cookie)
 
@@ -193,45 +177,42 @@ class Request(object):
             self.local = Host(self.server.host, self.server.port)
 
         try:
-            host = self.headers["Host"]
-            if ":" in host:
-                parts = host.split(":", 1)
+            host = self.headers['Host']
+            if ':' in host:
+                parts = host.split(':', 1)
                 host = parts[0]
                 port = int(parts[1])
             else:
-                port = 443 if self.scheme == "https" else 80
+                port = 443 if self.scheme == 'https' else 80
         except KeyError:
             host = self.local.name or self.local.ip
-            port = getattr(self.server, "port")
+            port = self.server.port
 
         self.host = host
         self.port = port
 
-        base = "{}://{}{}/".format(
+        base = '{}://{}{}/'.format(
             self.scheme,
             self.host,
-            ":{0:d}".format(self.port)
-            if self.port not in (80, 443)
-            else ""
+            f':{self.port:d}' if self.port not in (80, 443) else '',
         )
 
         self.base = parse_url(base)
 
-        url = "{}{}{}".format(
+        url = '{}{}{}'.format(
             base,
             self.path,
-            "?{}".format(self.qs) if self.qs else ""
+            f'?{self.qs}' if self.qs else '',
         )
         self.uri = parse_url(url)
         self.uri.sanitize()
 
     def __repr__(self):
-        protocol = "HTTP/%d.%d" % self.protocol
-        return "<Request %s %s %s>" % (self.method, self.path, protocol)
+        protocol = 'HTTP/%d.%d' % self.protocol
+        return f'<Request {self.method} {self.path} {protocol}>'
 
 
-class Body(object):
-
+class Body:
     """Response Body"""
 
     encode_errors = 'strict'
@@ -239,24 +220,17 @@ class Body(object):
     def __get__(self, response, cls=None):
         if response is None:
             return self
-        else:
-            return response._body
+        return response._body
 
     def __set__(self, response, value):
         if response == value:
             return
 
-        if isinstance(value, binary_type):
-            if value:
-                value = [value]
-            else:
-                value = []
-        elif isinstance(value, text_type):
-            if value:
-                value = [value.encode(response.encoding, self.encode_errors)]
-            else:
-                value = []
-        elif hasattr(value, "read"):
+        if isinstance(value, bytes):
+            value = [value] if value else []
+        elif isinstance(value, str):
+            value = [value.encode(response.encoding, self.encode_errors)] if value else []
+        elif hasattr(value, 'read'):
             response.stream = True
             value = file_generator(value)
         elif isinstance(value, httperror):
@@ -267,15 +241,13 @@ class Body(object):
         response._body = value
 
 
-class Status(object):
-
+class Status:
     """Response Status"""
 
     def __get__(self, response, cls=None):
         if response is None:
             return self
-        else:
-            return response._status
+        return response._status
 
     def __set__(self, response, value):
         value = HTTPStatus(value) if isinstance(value, int) else value
@@ -283,9 +255,9 @@ class Status(object):
         response._status = value
 
 
-class Response(object):
-
-    """Response(sock, request) -> new Response object
+class Response:
+    """
+    Response(sock, request) -> new Response object
 
     A Response object that holds the response to
     send back to the client. This ensure that the correct data
@@ -301,8 +273,7 @@ class Response(object):
     chunked = False
 
     def __init__(self, request, encoding='utf-8', status=None):
-        "initializes x; see x.__class__.__doc__ for signature"
-
+        """Initializes x; see x.__class__.__doc__ for signature"""
         self.request = request
         self.encoding = encoding
 
@@ -312,86 +283,81 @@ class Response(object):
         self.time = time()
 
         self.headers = Headers()
-        self.headers["Date"] = formatdate()
+        self.headers['Date'] = formatdate()
 
-        if getattr(self.request.server, "display_banner", False):
+        if getattr(self.request.server, 'display_banner', False):
             if self.request.server is not None:
-                self.headers.add_header("Server", request.server.http.version)
+                self.headers.add_header('Server', request.server.http.version)
             else:
-                self.headers.add_header("X-Powered-By", SERVER_VERSION)
+                self.headers.add_header('X-Powered-By', SERVER_VERSION)
 
         self.cookie = self.request.cookie
 
-        self.protocol = "HTTP/%d.%d" % self.request.protocol
+        self.protocol = 'HTTP/%d.%d' % self.request.protocol
 
     def __repr__(self):
-        return "<Response %s %s (%d)>" % (
+        return '<Response %s %s (%d)>' % (
             self.status,
-            self.headers.get("Content-Type"),
-            (len(self.body) if isinstance(self.body, str) else 0)
+            self.headers.get('Content-Type'),
+            (len(self.body) if isinstance(self.body, str) else 0),
         )
 
     def __str__(self):
-        self.prepare()
-        protocol = self.protocol
-        status = "{}".format(self.status)
-        return "{} {}\r\n".format(protocol, status)
+        return f'{self.protocol} {self.status}\r\n'
 
     def __bytes__(self):
-        return str(self).encode(self.encoding)  # FIXME: this is wrong. HTTP headers must be ISO8859-1. This should only encode the body as UTF-8.
+        return str(self).encode('ISO8859-1')
 
     def prepare(self):
         # Set a default content-Type if we don't have one.
         self.headers.setdefault(
-            "Content-Type", "text/html; charset={}".format(self.encoding)
+            'Content-Type',
+            f'text/html; charset={self.encoding}',
         )
 
         cLength = None
         if self.body is not None:
             if isinstance(self.body, bytes):
                 cLength = len(self.body)
-            elif isinstance(self.body, unicode):
+            elif isinstance(self.body, str):
                 cLength = len(self.body.encode(self.encoding))
             elif isinstance(self.body, list):
                 cLength = sum(
-                    [
-                        len(s.encode(self.encoding))
-                        if not isinstance(s, bytes)
-                        else len(s) for s in self.body
-                        if s is not None
-                    ]
+                    len(s.encode(self.encoding)) if not isinstance(s, bytes) else len(s) for s in self.body if s is not None
                 )
 
         if cLength is not None:
-            self.headers["Content-Length"] = str(cLength)
+            self.headers['Content-Length'] = str(cLength)
 
-        for k, v in self.cookie.items():
-            self.headers.add_header("Set-Cookie", v.OutputString())
+        for v in self.cookie.values():
+            self.headers.add_header('Set-Cookie', v.OutputString())
 
         status = self.status
 
         if status == 413:
             self.close = True
-        elif "Content-Length" not in self.headers:
+        elif 'Content-Length' not in self.headers:
             if status < 200 or status in (204, 205, 304):
                 pass
             else:
-                if self.protocol == "HTTP/1.1" \
-                        and self.request.method != "HEAD" \
-                        and self.request.server is not None \
-                        and not cLength == 0:
+                if (
+                    self.protocol == 'HTTP/1.1'
+                    and self.request.method != 'HEAD'
+                    and self.request.server is not None
+                    and cLength != 0
+                ):
                     self.chunked = True
-                    self.headers.add_header("Transfer-Encoding", "chunked")
+                    self.headers.add_header('Transfer-Encoding', 'chunked')
                 else:
                     self.close = True
 
-        if (self.request.server is not None and "Connection" not in self.headers):
-            if self.protocol == "HTTP/1.1":
+        if self.request.server is not None and 'Connection' not in self.headers:
+            if self.protocol == 'HTTP/1.1':
                 if self.close:
-                    self.headers.add_header("Connection", "close")
+                    self.headers.add_header('Connection', 'close')
             else:
                 if not self.close:
-                    self.headers.add_header("Connection", "Keep-Alive")
+                    self.headers.add_header('Connection', 'Keep-Alive')
 
-        if self.headers.get("Transfer-Encoding", "") == "chunked":
+        if self.headers.get('Transfer-Encoding', '') == 'chunked':
             self.chunked = True
