@@ -4,14 +4,14 @@ from circuits import BaseComponent, Debugger, handler
 
 
 class MyComponent(BaseComponent):
-
     def __init__(self):
-        super(MyComponent, self).__init__()
+        super().__init__()
 
         Debugger().register(self)
 
-    @handler("started", channel="*")
+    @handler('started', channel='*')
     def system_started(self, component):
-        print "Start event detected"
+        print('Start event detected')
+
 
 MyComponent().run()
