@@ -4,16 +4,14 @@ from circuits import Component, Debugger, Event
 
 
 class Identify(Event):
-
     """Identify Event"""
 
     success = True
 
 
 class Pound(Component):
-
     def __init__(self):
-        super(Pound, self).__init__()
+        super().__init__()
 
         Debugger().register(self)
         Bob().register(self)
@@ -25,24 +23,22 @@ class Pound(Component):
     def Identify_success(self, evt, result):
         if not isinstance(result, list):
             result = [result]
-        print "In pound:"
+        print('In pound:')
         for name in result:
-            print name
+            print(name)
 
 
 class Dog(Component):
-
     def Identify(self):
         return self.__class__.__name__
 
 
 class Bob(Dog):
-
     """Bob"""
 
 
 class Fred(Dog):
-
     """Fred"""
 
+
 Pound().run()
