@@ -4,14 +4,12 @@ from circuits import Component, Event
 
 
 class woof(Event):
-
     """woof Event"""
 
 
 class Pound(Component):
-
     def __init__(self):
-        super(Pound, self).__init__()
+        super().__init__()
 
         self.bob = Bob().register(self)
         self.fred = Fred().register(self)
@@ -21,18 +19,16 @@ class Pound(Component):
 
 
 class Dog(Component):
-
     def woof(self):
         print("Woof! I'm %s!" % self.name)
 
 
 class Bob(Dog):
-
     """Bob"""
 
 
 class Fred(Dog):
-
     """Fred"""
 
+
 Pound().run()
