@@ -4,14 +4,12 @@ from circuits import Component, Event
 
 
 class woof(Event):
-
     """woof Event"""
 
 
 class Pound(Component):
-
     def __init__(self):
-        super(Pound, self).__init__()
+        super().__init__()
 
         self.bob = Bob().register(self)
         self.fred = Fred().register(self)
@@ -21,22 +19,20 @@ class Pound(Component):
 
 
 class Dog(Component):
-
     def woof(self):
         print("Woof! I'm %s!" % self.name)
 
 
 class Bob(Dog):
-
     """Bob"""
 
-    channel = "bob"
+    channel = 'bob'
 
 
 class Fred(Dog):
-
     """Fred"""
 
-    channel = "fred"
+    channel = 'fred'
+
 
 Pound().run()
