@@ -1,9 +1,9 @@
 #!/usr/bin/env python
-"""An implementation of the Python Concurrency Problem of 99 Bottles of Beer
+"""
+An implementation of the Python Concurrency Problem of 99 Bottles of Beer
 
 See: http://wiki.python.org/moin/Concurrency/99Bottles
 """
-from __future__ import print_function
 
 import sys
 
@@ -13,24 +13,24 @@ from circuits.protocols import Line
 
 
 class Tail(Component):
-
-    """A complex component which combines the ``File`` and ``LP``
+    """
+    A complex component which combines the ``File`` and ``LP``
     (Line Protoco) components together to implement similar functionality to
     the UNIX ``tail`` command.
     """
 
     def init(self, filename):
-        """Initialize the Component.
+        """
+        Initialize the Component.
 
         NB: This is automatically called after ``__new__`` and ``__init__``.
         """
-
-        (File(filename, "r") + Line()).register(self)
+        (File(filename, 'r') + Line()).register(self)
 
 
 class Grep(Component):
-
-    """A simple component that simply listens for ``line`` events from the
+    """
+    A simple component that simply listens for ``line`` events from the
     ``Tail`` component and performs a regular expression match against each
     line. If the line matches it is printed to standard output.
     """
@@ -40,8 +40,7 @@ class Grep(Component):
 
     def line(self, line):
         """Line Event Handler"""
-
-        line = line.decode("utf-8")
+        line = line.decode('utf-8')
 
         if self.pattern in line:
             print(line)
