@@ -1,11 +1,13 @@
 #!/usr/bin/env python
-"""Directory Watch Example
+"""
+Directory Watch Example
 
 This example demonstrates the inotify I/O Component ``Notify`` which can
 be used for real-time monitoring of file system events. The example simply
 takes a path to watch as the first Command Line Argument and prints to
 stdour every file system event it sees.
 """
+
 import sys
 
 from circuits import Component
@@ -13,14 +15,13 @@ from circuits.io import Notify
 
 
 class FileWatcher(Component):
-
-    channel = "notify"
+    channel = 'notify'
 
     def opened(self, filename, path, fullpath, isdir):
-        print("File {0:s} opened".format(filename))
+        print(f'File {filename:s} opened')
 
     def closed(self, filename, path, fullpath, isdir):
-        print("File {0:s} closed".format(filename))
+        print(f'File {filename:s} closed')
 
 
 # Configure the system
