@@ -1,18 +1,20 @@
 #!/usr/bin/env python
-"""Simple TCP Echo Server
+"""
+Simple TCP Echo Server
 
 This example shows how you can create a simple TCP Server (an Echo Service)
 utilizing the builtin Socket Components that the circuits library ships with.
 """
+
 from circuits import Debugger, handler
 from circuits.net.sockets import TCPServer
 
 
 class EchoServer(TCPServer):
-
-    @handler("read")
+    @handler('read')
     def on_read(self, sock, data):
-        """Read Event Handler
+        """
+        Read Event Handler
 
         This is fired by the underlying Socket Component when there has been
         new data read from the connected client.
@@ -22,12 +24,11 @@ class EchoServer(TCPServer):
                   returned some data and fires a subsequent Write event with
                   the value returned.
         """
-
         return data
 
 
 # Start and "run" the system.
 # Bind to port 0.0.0.0:8000
-app = EchoServer(("0.0.0.0", 8000), secure=True, certfile="cert.pem")
+app = EchoServer(('0.0.0.0', 8000), secure=True, certfile='cert.pem')
 Debugger().register(app)
 app.run()
