@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 """circuits Hello World"""
 
-from __future__ import print_function
-
 from circuits import Component, Event
 
 
@@ -15,20 +13,18 @@ class terminate(Event):
 
 
 class App(Component):
-
     def hello(self):
         """Hello Event Handler"""
-
-        print("Hello World!")
+        print('Hello World!')
 
     def started(self, *args):
-        """Started Event Handler
+        """
+        Started Event Handler
 
         This is fired internally when your application starts up
         and can be used to trigger events that only occur once
         during startup.
         """
-
         self.fire(hello())  # Fire hello Event
         self.fire(terminate())
 
