@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-"""Bridge Example
+"""
+Bridge Example
 
 This example is quite similar to the Hello example
 but displays a hello form both the parent and child
 processing demonstrating how IPC works using the Bridge.
 """
-from __future__ import print_function
 
 from os import getpid
 
@@ -17,13 +17,11 @@ class hello(Event):
 
 
 class Child(Component):
-
     def hello(self):
-        return "Hello from child with pid {0}".format(getpid())
+        return f'Hello from child with pid {getpid()}'
 
 
 class App(Component):
-
     def init(self):
         Child().start(process=True, link=self)
 
@@ -37,7 +35,7 @@ class App(Component):
         raise SystemExit(0)
 
     def hello(self):
-        return "Hello from parent with pid {0}".format(getpid())
+        return f'Hello from parent with pid {getpid()}'
 
 
 App().run()
