@@ -1,9 +1,9 @@
 #!/usr/bin/env python
-"""Multi Bridge Example
+"""
+Multi Bridge Example
 
 Identical to the Hello Bridge Example but with a 2nd child.
 """
-from __future__ import print_function
 
 from os import getpid
 
@@ -19,13 +19,11 @@ class hello(Event):
 
 
 class Child(Component):
-
     def hello(self):
-        return "Hello from child with pid {0}".format(getpid())
+        return f'Hello from child with pid {getpid()}'
 
 
 class App(Component):
-
     def init(self):
         self.counter = 0
         self.child1 = Child().start(process=True, link=self)
@@ -50,7 +48,7 @@ class App(Component):
         raise SystemExit(0)
 
     def hello(self):
-        return "Hello from parent with pid {0}".format(getpid())
+        return f'Hello from parent with pid {getpid()}'
 
 
 App().run()
