@@ -20,7 +20,6 @@ At the python prompt:
     >>> y
     <Value (u'Hello World! (16035)') result=True; errors=False; for <Remote[*.remote] (<Hello[.hello] ( )>, 'app2' channel=None)>
 """  # noqa
-from __future__ import print_function
 
 import sys
 from os import getpid
@@ -30,22 +29,20 @@ from circuits.node import Node, remote  # noqa
 
 
 class hello(Event):
-
     """hello Event"""
 
 
 class App(Component):
-
     def ready(self, client):
-        print("Ready!")
+        print('Ready!')
 
     def connected(self, host, port):
-        print("Connected to {}:{}".format(host, port))
-        print("Try: x = app.fire(hello())")
+        print(f'Connected to {host}:{port}')
+        print('Try: x = app.fire(hello())')
 
     def hello(self):
-        print("Now try: y = app.fire(remote(hello(), \"test\"))")
-        return "Hello World! ({0:d})".format(getpid())
+        print('Now try: y = app.fire(remote(hello(), "test"))')
+        return f'Hello World! ({getpid():d})'
 
 
 # Setup app1 with a debugger
@@ -57,7 +54,7 @@ port = int(sys.argv[2])
 bind = (host, port)
 
 # Add an address of a node to talk to called "test"
-node.add("test", *bind)
+node.add('test', *bind)
 
 # Start app as a thread
 app.start()
