@@ -4,27 +4,33 @@ from optparse import OptionParser
 from circuits import Component, Debugger
 from circuits.node import Node
 
-__version__ = "0.0.1"
 
-USAGE = "%prog [options]"
-VERSION = "%prog v" + __version__
+__version__ = '0.0.1'
+
+USAGE = '%prog [options]'
+VERSION = '%prog v' + __version__
 
 
 def parse_options():
     parser = OptionParser(usage=USAGE, version=VERSION)
 
     parser.add_option(
-        "-i", "--ip",
-        action="store", type="string",
-        default="127.0.0.1:8000", dest="bind",
-        help="Bind to address:[port]"
+        '-i',
+        '--ip',
+        action='store',
+        type='string',
+        default='127.0.0.1:8000',
+        dest='bind',
+        help='Bind to address:[port]',
     )
 
     parser.add_option(
-        "-d", "--debug",
-        action="store_true",
-        default=False, dest="debug",
-        help="Enable debug mode"
+        '-d',
+        '--debug',
+        action='store_true',
+        default=False,
+        dest='debug',
+        help='Enable debug mode',
     )
 
     opts, args = parser.parse_args()
@@ -33,13 +39,12 @@ def parse_options():
 
 
 class NodeClient(Component):
-
     def init(self, args, opts):
         if opts.debug:
             Debugger().register(self)
 
-        if ":" in opts.bind:
-            address, port = opts.bind.split(":")
+        if ':' in opts.bind:
+            address, port = opts.bind.split(':')
             port = int(port)
         else:
             address, port = opts.bind, 8000
@@ -58,5 +63,5 @@ def main():
     NodeClient(args, opts).run()
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
