@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-"""Bridge Example
+"""
+Bridge Example
 
 A Bridge example that demonstrates bidirectional parent/child
 communications and displays the no. of events per second and latency.
 """
-from __future__ import print_function
 
 import sys
 from signal import SIGINT, SIGTERM
@@ -15,17 +15,17 @@ from circuits import Component, Event, handler, ipc
 
 
 def log(msg, *args, **kwargs):
-    sys.stderr.write("{0:s}{1:s}".format(msg.format(*args), kwargs.get("n", "\n")))
+    sys.stderr.write('{:s}{:s}'.format(msg.format(*args), kwargs.get('n', '\n')))
     sys.stderr.flush()
 
 
 def error(e):
-    log("ERROR: {0:s}", e)
+    log('ERROR: {0:s}', e)
     log(format_exc())
 
 
 def status(msg, *args):
-    log("\r\x1b[K{0:s}", msg.format(*args), n="")
+    log('\r\x1b[K{0:s}', msg.format(*args), n='')
 
 
 class ping(Event):
@@ -37,13 +37,11 @@ class pong(Event):
 
 
 class Child(Component):
-
     def ping(self, ts):
         self.fire(ipc(pong(ts, time())))
 
 
 class App(Component):
-
     def init(self):
         self.events = 0
         self.stime = time()
@@ -56,10 +54,7 @@ class App(Component):
     def pong(self, ts1, ts2):
         latency = (ts2 - ts1) * 1000.0
         status(
-            "{0:d} event/s @ {1:0.2f}ms latency".format(
-                int(self.events / (time() - self.stime)),
-                latency
-            )
+            f'{int(self.events / (time() - self.stime)):d} event/s @ {latency:0.2f}ms latency',
         )
         self.fire(ipc(ping(time())))
 
