@@ -3,22 +3,18 @@ from circuits import Component, Event
 
 
 class hello(Event):
-
     """hello Event"""
 
 
 class foo(Event):
-
     """foo Event"""
 
 
 class bar(Event):
-
     """bar Event"""
 
 
 class App(Component):
-
     def foo(self):
         return 1
 
@@ -32,7 +28,7 @@ class App(Component):
 
     def started(self, component):
         x = yield self.call(hello())
-        print("{0:d}".format(x.value))
+        print(f'{x.value:d}')
         self.stop()
 
 
