@@ -3,32 +3,28 @@ from circuits import Component, Event
 
 
 class hello(Event):
-
     """hello Event"""
 
 
 class foo(Event):
-
     """foo Event"""
 
 
 class bar(Event):
-
     """bar Event"""
 
 
 class App(Component):
-
     def foo(self):
-        print("Foo!")
+        print('Foo!')
 
     def bar(self):
-        print("Bar!")
+        print('Bar!')
 
     def hello(self):
         self.fire(foo())
         self.fire(bar())
-        print("Hello World!")
+        print('Hello World!')
 
     def started(self, component):
         self.fire(hello())
