@@ -3,22 +3,18 @@ from circuits import Component, Event
 
 
 class hello(Event):
-
     """hello Event"""
 
 
 class foo(Event):
-
     """foo Event"""
 
 
 class bar(Event):
-
     """bar Event"""
 
 
 class App(Component):
-
     def foo(self):
         return 1
 
@@ -27,17 +23,17 @@ class App(Component):
 
     def hello(self):
         x = self.fire(foo())
-        yield self.wait("foo")
+        yield self.wait('foo')
 
         y = self.fire(bar())
-        yield self.wait("bar")
+        yield self.wait('bar')
 
         yield x.value + y.value
 
     def started(self, component):
         x = self.fire(hello())
-        yield self.wait("hello")
-        print("{0:d}".format(x.value))
+        yield self.wait('hello')
+        print(f'{x.value:d}')
         self.stop()
 
 
