@@ -3,32 +3,31 @@ from circuits.web import Controller, Logger, Server
 
 
 class Root(Controller):
-
     def GET(self, *args, **kwargs):
-        """GET Request Handler
+        """
+        GET Request Handler
 
         The default Dispatcher in circuits.web also looks for GET, POST,
         PUT, DELETE and HEAD Request handlers on registered Controller(s).
 
         These can be used to implement RESTful resources with CRUD operations.
         """
-
-        return "GET({0:s}, {1:s})".format(repr(args), repr(kwargs))
+        return f'GET({args!r:s}, {kwargs!r:s})'
 
     def POST(self, *args, **kwargs):
-        return "POST({0:s}, {1:s})".format(repr(args), repr(kwargs))
+        return f'POST({args!r:s}, {kwargs!r:s})'
 
     def PUT(self, *args, **kwargs):
-        return "PUT({0:s}, {1:s})".format(repr(args), repr(kwargs))
+        return f'PUT({args!r:s}, {kwargs!r:s})'
 
     def DELETE(self, *args, **kwargs):
-        return "DELETE({0:s}, {1:s})".format(repr(args), repr(kwargs))
+        return f'DELETE({args!r:s}, {kwargs!r:s})'
 
     def HEAD(self, *args, **kwargs):
-        return "HEAD({0:s}, {1:s})".format(repr(args), repr(kwargs))
+        return f'HEAD({args!r:s}, {kwargs!r:s})'
 
 
-app = Server(("0.0.0.0", 8000))
+app = Server(('0.0.0.0', 8000))
 Logger().register(app)
 Root().register(app)
 app.run()
