@@ -1,8 +1,10 @@
 #!/usr/bin/env python
-"""File Upload
+"""
+File Upload
 
 A simple example showing how to access an uploaded file.
 """
+
 from circuits.web import Controller, Server
 
 
@@ -43,9 +45,9 @@ UPLOADED_FILE = """
 
 
 class Root(Controller):
-
-    def index(self, file=None, desc=""):
-        """Request Handler
+    def index(self, file=None, desc=''):
+        """
+        Request Handler
 
         If we haven't received an uploaded file yet, repond with
         the UPLOAD_FORM template. Otherwise respond with the
@@ -54,13 +56,11 @@ class Root(Controller):
         the ``desc`` keyword argument. These also happen to be
         the same fields used on the form.
         """
-
         if file is None:
             return UPLOAD_FORM
-        else:
-            return UPLOADED_FILE % (file.filename, desc, file.value)
+        return UPLOADED_FILE % (file.filename, desc, file.value)
 
 
-app = Server(("0.0.0.0", 8000))
+app = Server(('0.0.0.0', 8000))
 Root().register(app)
 app.run()
