@@ -20,7 +20,6 @@ HTML = """\
 
 
 class Root(Controller):
-
     def index(self):
         return HTML
 
@@ -28,9 +27,9 @@ class Root(Controller):
         raise SystemExit(0)
 
 
-app = Server(("0.0.0.0", 8000))
+app = Server(('0.0.0.0', 8000))
 Root().register(app)
 app.start()
 
-webbrowser.open("http://127.0.0.1:8000/")
+webbrowser.open('http://127.0.0.1:8000/')
 app.join()
