@@ -4,9 +4,8 @@ from circuits.web.wsgi import Application
 
 
 class Root(Controller):
-
     def index(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 application = Application()
