@@ -1,8 +1,5 @@
 """Help Tasks"""
 
-
-from __future__ import print_function
-
 from fabric import state
 from fabric.api import task
 from fabric.task_utils import crawl
@@ -11,7 +8,8 @@ from fabric.tasks import Task
 
 @task(default=True)
 def help(name=None):
-    """Display help for a given task
+    """
+    Display help for a given task
 
     Options:
         name    - The task to display help on.
@@ -24,19 +22,18 @@ def help(name=None):
 
         $ fab help:<name>
     """
-
     if name is None:
-        name = "help"
+        name = 'help'
 
     task = crawl(name, state.commands)
     if isinstance(task, Task):
-        doc = getattr(task, "__doc__", None)
+        doc = getattr(task, '__doc__', None)
         if doc is not None:
-            print("Help on {0:s}:".format(name))
+            print(f'Help on {name:s}:')
             print()
             print(doc)
         else:
-            print("No help available for {0:s}".format(name))
+            print(f'No help available for {name:s}')
     else:
-        print("No such task {0:s}".format(name))
-        print("For a list of tasks type: fab -l")
+        print(f'No such task {name:s}')
+        print('For a list of tasks type: fab -l')
