@@ -5,7 +5,6 @@ from circuits import Component
 
 
 class App(Component):
-
     def started(self, *args):
         try:
             code = int(sys.argv[1])
@@ -19,5 +18,5 @@ def main():
     App().run()
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
