@@ -5,15 +5,16 @@ import sys
 from circuits import Component
 from circuits.app import Daemon
 
+
 try:
     from coverage import coverage
+
     HAS_COVERAGE = True
 except ImportError:
     HAS_COVERAGE = False
 
 
 class App(Component):
-
     def init(self, pidfile, signalfile):
         self.pidfile = pidfile
         self.signalfile = signalfile
@@ -21,7 +22,7 @@ class App(Component):
         Daemon(self.pidfile).register(self)
 
     def signal(self, signal, stack):
-        f = open(self.signalfile, "w")
+        f = open(self.signalfile, 'w')
         f.write(str(signal))
         f.close()
         self.stop()
@@ -41,5 +42,5 @@ def main():
         _coverage.save()
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
