@@ -5,9 +5,10 @@ import pytest
 
 from circuits import Component, Event, ipc
 
+
 pytestmark = pytest.mark.skipif(pytest.PLATFORM == 'win32', reason='Unsupported Platform')
 
-pytest.importorskip("multiprocessing")
+pytest.importorskip('multiprocessing')
 
 
 class hello(Event):
@@ -15,24 +16,23 @@ class hello(Event):
 
 
 class App(Component):
-
     def hello(self):
-        return "Hello from {0:d}".format(getpid())
+        return f'Hello from {getpid():d}'
 
 
 def test(manager, watcher):
     app = App()
-    process, bridge = app.start(process=True, link=manager)
-    assert watcher.wait("ready")
+    _process, bridge = app.start(process=True, link=manager)
+    assert watcher.wait('ready')
 
     x = manager.fire(ipc(hello()))
 
-    assert pytest.wait_for(x, "result")
+    assert pytest.wait_for(x, 'result')
 
-    assert x.value == "Hello from {0:d}".format(app.pid)
+    assert x.value == f'Hello from {app.pid:d}'
 
     app.stop()
     app.join()
 
     bridge.unregister()
-    watcher.wait("unregistered")
+    watcher.wait('unregistered')
