@@ -8,7 +8,6 @@ from circuits.core import Component, Event, Worker, handler, task
 
 
 class hello(Event):
-
     """hello Event"""
 
     success = True
@@ -20,7 +19,6 @@ def process(x=None):
 
 
 class App(Component):
-
     @handler('hello')
     def _on_hello(self):
         e1 = task(process, 1)
@@ -29,15 +27,15 @@ class App(Component):
         yield (yield self.call(e1))
 
 
-@pytest.fixture
+@pytest.fixture()
 def app(request, manager, watcher):
     seed(time())
 
     app = App().register(manager)
-    assert watcher.wait("registered")
+    assert watcher.wait('registered')
 
     worker = Worker().register(manager)
-    assert watcher.wait("registered")
+    assert watcher.wait('registered')
 
     def finalizer():
         app.unregister()
