@@ -5,24 +5,22 @@ from circuits import Component, Event
 
 
 class hello(Event):
-
     """hello Event"""
 
     success = True
 
 
 class App(Component):
-
-    channel = "app"
+    channel = 'app'
 
     def hello(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
-@pytest.fixture
+@pytest.fixture()
 def app(request, manager, watcher):
     app = App().register(manager)
-    assert watcher.wait("registered")
+    assert watcher.wait('registered')
 
     def finalizer():
         app.unregister()
@@ -34,7 +32,7 @@ def app(request, manager, watcher):
 
 def test(manager, watcher, app):
     x = manager.fire(hello(), app)
-    assert watcher.wait("hello_success")
+    assert watcher.wait('hello_success')
 
     value = x.value
-    assert value == "Hello World!"
+    assert value == 'Hello World!'
