@@ -3,14 +3,12 @@ from circuits import Component, Event, Manager
 
 
 class test(Event):
-
     """test Event"""
 
 
 class App(Component):
-
     def test(self):
-        return "Hello World!"
+        return 'Hello World!'
 
     def unregistered(self, *args):
         return
@@ -30,7 +28,7 @@ while len(app):
 def test_fire():
     x = m.fire(test())
     m.flush()
-    assert x.value == "Hello World!"
+    assert x.value == 'Hello World!'
 
 
 def test_contains():
