@@ -5,13 +5,12 @@ from circuits import Event, Manager, handler
 
 
 class foo(Event):
-
     """foo Event"""
 
 
-@handler("foo")
+@handler('foo')
 def on_foo(self):
-    return "Hello World!"
+    return 'Hello World!'
 
 
 def test_addHandler():
@@ -20,12 +19,12 @@ def test_addHandler():
 
     m.addHandler(on_foo)
 
-    waiter = pytest.WaitEvent(m, "foo")
+    waiter = pytest.WaitEvent(m, 'foo')
     x = m.fire(foo())
     waiter.wait()
 
     s = x.value
-    assert s == "Hello World!"
+    assert s == 'Hello World!'
 
     m.stop()
 
@@ -36,22 +35,22 @@ def test_removeHandler():
 
     method = m.addHandler(on_foo)
 
-    waiter = pytest.WaitEvent(m, "foo")
+    waiter = pytest.WaitEvent(m, 'foo')
     x = m.fire(foo())
     waiter.wait()
 
     s = x.value
-    assert s == "Hello World!"
+    assert s == 'Hello World!'
 
     m.removeHandler(method)
 
-    waiter = pytest.WaitEvent(m, "foo")
+    waiter = pytest.WaitEvent(m, 'foo')
     x = m.fire(foo())
     waiter.wait()
 
     assert x.value is None
 
     assert on_foo not in dir(m)
-    assert "foo" not in m._handlers
+    assert 'foo' not in m._handlers
 
     m.stop()
