@@ -5,14 +5,12 @@ from circuits import Component, Event
 
 
 class test(Event):
-
     """test Event"""
 
 
 class App(Component):
-
     def __init__(self):
-        super(App, self).__init__()
+        super().__init__()
 
         self.etype = None
         self.evalue = None
@@ -21,7 +19,7 @@ class App(Component):
         self.fevent = None
 
     def test(self):
-        return x  # NOQA
+        return x  # noqa: F821
 
     def exception(self, etype, evalue, etraceback, handler=None, fevent=None):
         self.etype = etype
@@ -35,10 +33,10 @@ def reraise(e):
     raise e
 
 
-@pytest.fixture
+@pytest.fixture()
 def app(request, manager, watcher):
     app = App().register(manager)
-    watcher.wait("registered")
+    watcher.wait('registered')
 
     def finalizer():
         app.unregister()
@@ -51,9 +49,9 @@ def app(request, manager, watcher):
 def test_main(app, watcher):
     e = test()
     app.fire(e)
-    watcher.wait("exception")
+    watcher.wait('exception')
 
-    assert app.etype == NameError
+    assert app.etype is NameError
     pytest.raises(NameError, lambda e: reraise(e), app.evalue)
     assert isinstance(app.etraceback, list)
     assert app.handler == app.test
