@@ -1,19 +1,17 @@
 """Event Tests"""
 
-import py
+import pytest
 
 from circuits import Component, Event
 
 
 class test(Event):
-
     """test Event"""
 
 
 class App(Component):
-
     def test(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 def test_repr():
@@ -24,12 +22,12 @@ def test_repr():
     e = test()
 
     s = repr(e)
-    assert s == "<test[] ( )>"
+    assert s == '<test[] ( )>'
 
     app.fire(e)
 
     s = repr(e)
-    assert s == "<test[*] ( )>"
+    assert s == '<test[*] ( )>'
 
 
 def test_create():
@@ -37,15 +35,15 @@ def test_create():
     while len(app):
         app.flush()
 
-    e = Event.create("test")
+    e = Event.create('test')
 
     s = repr(e)
-    assert s == "<test[] ( )>"
+    assert s == '<test[] ( )>'
 
     app.fire(e)
 
     s = repr(e)
-    assert s == "<test[*] ( )>"
+    assert s == '<test[*] ( )>'
 
 
 def test_getitem():
@@ -53,15 +51,15 @@ def test_getitem():
     while len(app):
         app.flush()
 
-    e = test(1, 2, 3, foo="bar")
+    e = test(1, 2, 3, foo='bar')
 
     assert e[0] == 1
-    assert e["foo"] == "bar"
+    assert e['foo'] == 'bar'
 
     def f(e, k):
         return e[k]
 
-    py.test.raises(TypeError, f, e, None)
+    pytest.raises(TypeError, f, e, None)
 
 
 def test_setitem():
@@ -69,25 +67,26 @@ def test_setitem():
     while len(app):
         app.flush()
 
-    e = test(1, 2, 3, foo="bar")
+    e = test(1, 2, 3, foo='bar')
 
     assert e[0] == 1
-    assert e["foo"] == "bar"
+    assert e['foo'] == 'bar'
 
     e[0] = 0
-    e["foo"] = "Hello"
+    e['foo'] = 'Hello'
 
     def f(e, k, v):
         e[k] = v
 
-    py.test.raises(TypeError, f, e, None, None)
+    pytest.raises(TypeError, f, e, None, None)
 
     assert e[0] == 0
-    assert e["foo"] == "Hello"
+    assert e['foo'] == 'Hello'
 
 
 def test_subclass_looses_properties():
     class hello(Event):
         success = True
+
     e = hello().child('success')
     assert e.success is False
