@@ -5,7 +5,6 @@ from circuits import Component, Event
 
 
 class App(Component):
-
     def init(self):
         self._ready = False
         self._done = False
@@ -13,16 +12,16 @@ class App(Component):
 
     def registered(self, component, manager):
         if component is self:
-            self.fire(Event.create("ready"))
+            self.fire(Event.create('ready'))
 
     def generate_events(self, event):
         if not self._ready or self._done:
             return
 
         if self._counter < 10:
-            self.fire(Event.create("hello"))
+            self.fire(Event.create('hello'))
         else:
-            self.fire(Event.create("done"))
+            self.fire(Event.create('done'))
         event.reduce_time_left(0)
 
     def done(self):
@@ -35,7 +34,7 @@ class App(Component):
         self._ready = True
 
 
-@pytest.fixture
+@pytest.fixture()
 def app(request, manager, watcher):
     app = App().register(manager)
 
@@ -44,11 +43,11 @@ def app(request, manager, watcher):
 
     request.addfinalizer(finalizer)
 
-    assert watcher.wait("ready")
+    assert watcher.wait('ready')
 
     return app
 
 
 def test(manager, watcher, app):
-    watcher.wait("done")
+    watcher.wait('done')
     assert app._counter == 10
