@@ -3,26 +3,24 @@ from circuits import Component, Event
 
 
 class test(Event):
-
     """test Event"""
 
 
 class hello(Event):
-
     """hello Event"""
 
 
 class App(Component):
-
     def test(self):
         def f():
             while True:
-                yield "Hello"
+                yield 'Hello'
+
         return f()
 
     def hello(self):
-        yield "Hello "
-        yield "World!"
+        yield 'Hello '
+        yield 'World!'
 
 
 def test_return_generator():
@@ -35,7 +33,7 @@ def test_return_generator():
     app.tick()
 
     x = v.value
-    assert x == "Hello"
+    assert x == 'Hello'
 
 
 def test_yield():
@@ -49,4 +47,4 @@ def test_yield():
     app.tick()
 
     x = v.value
-    assert x == ["Hello ", "World!"]
+    assert x == ['Hello ', 'World!']
