@@ -3,21 +3,19 @@ from circuits import Component, Event, Manager, handler
 
 
 class test(Event):
-
     """test Event"""
 
 
 class App(Component):
-
-    @handler("test")
+    @handler('test')
     def test_0(self):
         return 0
 
-    @handler("test", priority=3)
+    @handler('test', priority=3)
     def test_3(self):
         return 3
 
-    @handler("test", priority=2)
+    @handler('test', priority=2)
     def test_2(self):
         return 2
 
