@@ -28,16 +28,16 @@ def wait(pid, timeout=3):
 
 
 def test(tmpdir):
-    if not os.name == "posix":
-        pytest.skip("Cannot run test on a non-POSIX platform.")
+    if os.name != 'posix':
+        pytest.skip('Cannot run test on a non-POSIX platform.')
 
-    tmpdir.ensure(".pid")
-    tmpdir.ensure(".signal")
-    pidfile = str(tmpdir.join(".pid"))
-    signalfile = str(tmpdir.join(".signal"))
+    tmpdir.ensure('.pid')
+    tmpdir.ensure('.signal')
+    pidfile = str(tmpdir.join('.pid'))
+    signalfile = str(tmpdir.join('.signal'))
 
     args = [sys.executable, signalapp.__file__, pidfile, signalfile]
-    cmd = " ".join(args)
+    cmd = ' '.join(args)
     p = Popen(cmd, shell=True, env={'PYTHONPATH': ':'.join(sys.path)})
     status = p.wait()
 
@@ -48,14 +48,14 @@ def test(tmpdir):
     assert os.path.exists(pidfile)
     assert os.path.isfile(pidfile)
 
-    f = open(pidfile, "r")
+    f = open(pidfile)
     pid = int(f.read().strip())
     f.close()
 
     kill(pid, SIGTERM)
     wait(pid)
 
-    with open(signalfile, "r") as fd:
+    with open(signalfile) as fd:
         signal = fd.read().strip()
 
     assert int(signal) == int(SIGTERM)
