@@ -1,6 +1,5 @@
 """Timers Tests"""
 
-
 from datetime import datetime, timedelta
 from itertools import starmap
 from operator import sub
@@ -9,17 +8,16 @@ from time import time
 import pytest
 
 from circuits import Component, Event, Timer, sleep
-from circuits.six.moves import map, zip
 
 
-@pytest.fixture
+@pytest.fixture()
 def app(request, manager, watcher):
     app = App().register(manager)
-    assert watcher.wait("registered")
+    assert watcher.wait('registered')
 
     def finalizer():
         app.unregister()
-        assert watcher.wait("unregistered")
+        assert watcher.wait('unregistered')
 
     request.addfinalizer(finalizer)
 
@@ -27,21 +25,18 @@ def app(request, manager, watcher):
 
 
 class single(Event):
-
     """single Event"""
 
     complete = True
 
 
 class persistent(Event):
-
     """persistent Event"""
 
     complete = True
 
 
 class App(Component):
-
     def init(self):
         self.flag = False
         self.count = 0
@@ -63,15 +58,15 @@ class App(Component):
 
 def test_single(app, watcher):
     Timer(0.1, single()).register(app)
-    assert watcher.wait("single_complete")
+    assert watcher.wait('single_complete')
     assert app.flag
 
 
 def test_persistent(app, watcher):
     exponent = -1
-    interval = 10.0 ** exponent
+    interval = 10.0**exponent
     app.fire(persistent(interval))
-    assert watcher.wait("persistent_complete")
+    assert watcher.wait('persistent_complete')
 
     xs = list(map(abs, starmap(sub, zip(app.timestamps, app.timestamps[1:]))))
     avg = sum(xs) / len(xs)
@@ -83,5 +78,5 @@ def test_datetime(app, watcher):
     now = datetime.now()
     d = now + timedelta(seconds=0.1)
     Timer(d, single()).register(app)
-    assert watcher.wait("single_complete")
+    assert watcher.wait('single_complete')
     assert app.flag
