@@ -7,7 +7,7 @@ import pytest
 from circuits import Worker, task
 
 
-@pytest.fixture
+@pytest.fixture()
 def worker(request, manager):
     worker = Worker().register(manager)
 
@@ -20,7 +20,7 @@ def worker(request, manager):
 
 
 def err():
-    return x * 2  # NOQA
+    return x * 2  # noqa: F821
 
 
 def foo():
@@ -33,7 +33,7 @@ def foo():
 
 
 def pid():
-    return "Hello from {0:d}".format(getpid())
+    return f'Hello from {getpid():d}'
 
 
 def add(a, b):
@@ -46,7 +46,7 @@ def test_failure(manager, watcher, worker):
 
     x = worker.fire(e)
 
-    assert watcher.wait("task_failure")
+    assert watcher.wait('task_failure')
 
     assert isinstance(x.value[1], Exception)
 
@@ -57,7 +57,7 @@ def test_success(manager, watcher, worker):
 
     x = worker.fire(e)
 
-    assert watcher.wait("task_success")
+    assert watcher.wait('task_success')
 
     assert x.value == 1000000
 
@@ -68,6 +68,6 @@ def test_args(manager, watcher, worker):
 
     x = worker.fire(e)
 
-    assert watcher.wait("task_success")
+    assert watcher.wait('task_success')
 
     assert x.value == 3
