@@ -1,21 +1,21 @@
 """Workers Tests"""
 
-
 import pytest
 
 from circuits import Worker, task
 
+
 task.complete = True
 
 
-@pytest.fixture
+@pytest.fixture()
 def worker(request, manager, watcher):
     worker = Worker().register(manager)
-    assert watcher.wait("registered")
+    assert watcher.wait('registered')
 
     def finalizer():
         worker.unregister()
-        assert watcher.wait("unregistered")
+        assert watcher.wait('unregistered')
 
     request.addfinalizer(finalizer)
 
@@ -37,7 +37,7 @@ def add(a, b):
 
 def test(manager, watcher, worker):
     x = manager.fire(task(f))
-    assert watcher.wait("task_complete")
+    assert watcher.wait('task_complete')
 
     assert x.result
     assert x.value == 1000000
@@ -45,7 +45,7 @@ def test(manager, watcher, worker):
 
 def test_args(manager, watcher, worker):
     x = manager.fire(task(add, 1, 2))
-    assert watcher.wait("task_complete")
+    assert watcher.wait('task_complete')
 
     assert x.result
     assert x.value == 3
