@@ -2,13 +2,12 @@ from circuits import Component
 
 
 class Client(Component):
-
-    channel = "client"
+    channel = 'client'
 
     def __init__(self, channel=channel):
-        super(Client, self).__init__(channel=channel)
+        super().__init__(channel=channel)
 
-        self.data = ""
+        self.data = ''
         self.error = None
         self.ready = False
         self.closed = False
@@ -24,7 +23,7 @@ class Client(Component):
     def connected(self, host, port):
         self.connected = True
 
-    def disconnect(self):
+    def disconnect(self, *args):
         return
 
     def disconnected(self):
