@@ -6,7 +6,6 @@ def test_client_bind_int():
     from circuits.net.sockets import Client
 
     class TestClient(Client):
-
         def _create_socket(self):
             return None
 
@@ -21,26 +20,24 @@ def test_client_bind_int_gaierror(monkeypatch):
     def broken_gethostname():
         raise gaierror()
 
-    monkeypatch.setattr(sockets, "gethostname", broken_gethostname)
+    monkeypatch.setattr(sockets, 'gethostname', broken_gethostname)
 
     class TestClient(sockets.Client):
-
         def _create_socket(self):
             return None
 
     client = TestClient(1234)
 
-    assert client._bind == ("0.0.0.0", 1234)
+    assert client._bind == ('0.0.0.0', 1234)
 
 
 def test_client_bind_str():
     from circuits.net.sockets import Client
 
     class TestClient(Client):
-
         def _create_socket(self):
             return None
 
-    client = TestClient("0.0.0.0:1234")
+    client = TestClient('0.0.0.0:1234')
 
-    assert client._bind == ("0.0.0.0", 1234)
+    assert client._bind == ('0.0.0.0', 1234)
