@@ -8,17 +8,18 @@ from circuits.net.sockets import Pipe
 
 from .client import Client
 
+
 pytestmark = pytest.mark.skipif(pytest.PLATFORM == 'win32', reason='Unsupported Platform')
 
 
 def pytest_generate_tests(metafunc):
-    metafunc.parametrize("Poller", [Select])
+    metafunc.parametrize('Poller', [Select])
 
 
 def test_pipe(Poller):
     m = Manager() + Poller()
 
-    a, b = Pipe("a", "b")
+    a, b = Pipe('a', 'b')
     a.register(m)
     b.register(m)
 
@@ -28,19 +29,19 @@ def test_pipe(Poller):
     m.start()
 
     try:
-        assert pytest.wait_for(a, "ready")
-        assert pytest.wait_for(b, "ready")
+        assert pytest.wait_for(a, 'ready')
+        assert pytest.wait_for(b, 'ready')
 
-        a.fire(write(b"foo"))
-        assert pytest.wait_for(b, "data", b"foo")
+        a.fire(write(b'foo'))
+        assert pytest.wait_for(b, 'data', b'foo')
 
-        b.fire(write(b"foo"))
-        assert pytest.wait_for(a, "data", b"foo")
+        b.fire(write(b'foo'))
+        assert pytest.wait_for(a, 'data', b'foo')
 
         a.fire(close())
-        assert pytest.wait_for(a, "disconnected")
+        assert pytest.wait_for(a, 'disconnected')
 
         b.fire(close())
-        assert pytest.wait_for(b, "disconnected")
+        assert pytest.wait_for(b, 'disconnected')
     finally:
         m.stop()
