@@ -1,38 +1,38 @@
 #!/usr/bin/env python
+import contextlib
 import os.path
 import select
-from socket import (
-    AF_INET, AF_INET6, EAI_NODATA, EAI_NONAME, SOCK_STREAM,
-    error as SocketError, has_ipv6, socket,
-)
-from ssl import wrap_socket as sslsocket
+from socket import AF_INET, AF_INET6, EAI_NODATA, EAI_NONAME, SOCK_STREAM, has_ipv6, socket
+from ssl import CERT_NONE, PROTOCOL_TLS_CLIENT, SSLContext
 
 import pytest
-from tests.conftest import WaitEvent
 
 from circuits import Debugger, Manager
 from circuits.core.pollers import EPoll, KQueue, Poll, Select
 from circuits.net.events import close, connect, write
 from circuits.net.sockets import TCP6Client, TCP6Server, TCPClient, TCPServer
+from tests.conftest import WaitEvent
 
 from .client import Client
 from .server import Server
 
-CERT_FILE = os.path.join(os.path.dirname(__file__), "cert.pem")
+
+CERT_FILE = os.path.join(os.path.dirname(__file__), 'cert.pem')
 
 
-class TestClient(object):
-
+class _TestClient:
     def __init__(self, ipv6=False):
         self._sockname = None
 
         self.sock = socket(
-            AF_INET6 if ipv6
-            else AF_INET,
-            SOCK_STREAM
+            AF_INET6 if ipv6 else AF_INET,
+            SOCK_STREAM,
         )
 
-        self.ssock = sslsocket(self.sock)
+        ctx = SSLContext(PROTOCOL_TLS_CLIENT)
+        ctx.check_hostname = False
+        ctx.verify_mode = CERT_NONE
+        self.ssock = ctx.wrap_socket(self.sock)
 
     @property
     def sockname(self):
@@ -49,20 +49,16 @@ class TestClient(object):
         return self.ssock.recv(buflen)
 
     def disconnect(self):
-        try:
+        with contextlib.suppress(OSError):
             self.ssock.shutdown(2)
-        except SocketError:
-            pass
 
-        try:
+        with contextlib.suppress(OSError):
             self.ssock.close()
-        except SocketError:
-            pass
 
 
-@pytest.fixture
+@pytest.fixture()
 def client(request, ipv6):
-    client = TestClient(ipv6=ipv6)
+    client = _TestClient(ipv6=ipv6)
 
     def finalizer():
         client.disconnect()
@@ -74,8 +70,9 @@ def client(request, ipv6):
 
 def wait_host(server):
     def checker(obj, attr):
-        return all((getattr(obj, a) for a in attr))
-    assert pytest.wait_for(server, ("host", "port"), checker)
+        return all(getattr(obj, a) for a in attr)
+
+    assert pytest.wait_for(server, ('host', 'port'), checker)
 
 
 def pytest_generate_tests(metafunc):
@@ -86,13 +83,13 @@ def pytest_generate_tests(metafunc):
     for ipv6 in ipv6:
         poller = [(Select, ipv6)]
 
-        if hasattr(select, "poll"):
+        if hasattr(select, 'poll'):
             poller.append((Poll, ipv6))
 
-        if hasattr(select, "epoll"):
+        if hasattr(select, 'epoll'):
             poller.append((EPoll, ipv6))
 
-        if hasattr(select, "kqueue"):
+        if hasattr(select, 'kqueue'):
             poller.append((KQueue, ipv6))
 
     metafunc.parametrize('Poller,ipv6', poller)
@@ -102,7 +99,7 @@ def test_tcp_basic(Poller, ipv6):
     m = Manager() + Poller()
 
     if ipv6:
-        tcp_server = TCP6Server(("::1", 0))
+        tcp_server = TCP6Server(('::1', 0))
         tcp_client = TCP6Client()
     else:
         tcp_server = TCPServer(0)
@@ -116,25 +113,25 @@ def test_tcp_basic(Poller, ipv6):
     m.start()
 
     try:
-        assert pytest.wait_for(client, "ready")
-        assert pytest.wait_for(server, "ready")
+        assert pytest.wait_for(client, 'ready')
+        assert pytest.wait_for(server, 'ready')
         wait_host(server)
 
         client.fire(connect(server.host, server.port))
-        assert pytest.wait_for(client, "connected")
-        assert pytest.wait_for(server, "connected")
-        assert pytest.wait_for(client, "data", b"Ready")
+        assert pytest.wait_for(client, 'connected')
+        assert pytest.wait_for(server, 'connected')
+        assert pytest.wait_for(client, 'data', b'Ready')
 
-        client.fire(write(b"foo"))
-        assert pytest.wait_for(server, "data", b"foo")
-        assert pytest.wait_for(client, "data", b"foo")
+        client.fire(write(b'foo'))
+        assert pytest.wait_for(server, 'data', b'foo')
+        assert pytest.wait_for(client, 'data', b'foo')
 
         client.fire(close())
-        assert pytest.wait_for(client, "disconnected")
-        assert pytest.wait_for(server, "disconnected")
+        assert pytest.wait_for(client, 'disconnected')
+        assert pytest.wait_for(server, 'disconnected')
 
         server.fire(close())
-        assert pytest.wait_for(server, "closed")
+        assert pytest.wait_for(server, 'closed')
     finally:
         m.stop()
 
@@ -143,7 +140,7 @@ def test_tcps_basic(manager, watcher, client, Poller, ipv6):
     poller = Poller().register(manager)
 
     if ipv6:
-        tcp_server = TCP6Server(("::1", 0), secure=True, certfile=CERT_FILE)
+        tcp_server = TCP6Server(('::1', 0), secure=True, certfile=CERT_FILE)
     else:
         tcp_server = TCPServer(0, secure=True, certfile=CERT_FILE)
 
@@ -152,38 +149,38 @@ def test_tcps_basic(manager, watcher, client, Poller, ipv6):
     server.register(manager)
 
     try:
-        watcher.wait("ready", "server")
+        watcher.wait('ready', 'server')
 
         client.connect(server.host, server.port)
-        assert watcher.wait("connect", "server")
-        assert client.recv() == b"Ready"
+        assert watcher.wait('connect', 'server')
+        assert client.recv() == b'Ready'
 
-        client.send(b"foo")
-        assert watcher.wait("read", "server")
-        assert client.recv() == b"foo"
+        client.send(b'foo')
+        assert watcher.wait('read', 'server')
+        assert client.recv() == b'foo'
 
         client.disconnect()
-        assert watcher.wait("disconnect", "server")
+        assert watcher.wait('disconnect', 'server')
 
         server.fire(close())
-        assert watcher.wait("closed", "server")
+        assert watcher.wait('closed', 'server')
     finally:
         poller.unregister()
         server.unregister()
 
 
 def test_tcp_reconnect(Poller, ipv6):
-    # XXX: Apparently this doesn't work on Windows either?
-    # XXX: UPDATE: Apparently Broken on Windows + Python 3.2
+    # TODO: Apparently this doesn't work on Windows either?
+    # TODO: UPDATE: Apparently Broken on Windows + Python 3.2
     # TODO: Need to look into this. Find out why...
 
-    if pytest.PLATFORM == "win32" and pytest.PYVER[:2] >= (3, 2):
-        pytest.skip("Broken on Windows on Python 3.2")
+    if pytest.PLATFORM == 'win32' and pytest.PYVER[:2] >= (3, 2):
+        pytest.skip('Broken on Windows on Python 3.2')
 
     m = Manager() + Poller()
 
     if ipv6:
-        tcp_server = TCP6Server(("::1", 0))
+        tcp_server = TCP6Server(('::1', 0))
         tcp_client = TCP6Client()
     else:
         tcp_server = TCPServer(0)
@@ -197,51 +194,50 @@ def test_tcp_reconnect(Poller, ipv6):
     m.start()
 
     try:
-        assert pytest.wait_for(client, "ready")
-        assert pytest.wait_for(server, "ready")
+        assert pytest.wait_for(client, 'ready')
+        assert pytest.wait_for(server, 'ready')
         wait_host(server)
 
         # 1st connect
         client.fire(connect(server.host, server.port))
-        assert pytest.wait_for(client, "connected")
-        assert pytest.wait_for(server, "connected")
-        assert pytest.wait_for(client, "data", b"Ready")
+        assert pytest.wait_for(client, 'connected')
+        assert pytest.wait_for(server, 'connected')
+        assert pytest.wait_for(client, 'data', b'Ready')
 
-        client.fire(write(b"foo"))
-        assert pytest.wait_for(server, "data", b"foo")
+        client.fire(write(b'foo'))
+        assert pytest.wait_for(server, 'data', b'foo')
 
         # disconnect
         client.fire(close())
-        assert pytest.wait_for(client, "disconnected")
+        assert pytest.wait_for(client, 'disconnected')
 
         # 2nd reconnect
         client.fire(connect(server.host, server.port))
-        assert pytest.wait_for(client, "connected")
-        assert pytest.wait_for(server, "connected")
-        assert pytest.wait_for(client, "data", b"Ready")
+        assert pytest.wait_for(client, 'connected')
+        assert pytest.wait_for(server, 'connected')
+        assert pytest.wait_for(client, 'data', b'Ready')
 
-        client.fire(write(b"foo"))
-        assert pytest.wait_for(server, "data", b"foo")
+        client.fire(write(b'foo'))
+        assert pytest.wait_for(server, 'data', b'foo')
 
         client.fire(close())
-        assert pytest.wait_for(client, "disconnected")
-        assert pytest.wait_for(server, "disconnected")
+        assert pytest.wait_for(client, 'disconnected')
+        assert pytest.wait_for(server, 'disconnected')
 
         server.fire(close())
-        assert pytest.wait_for(server, "closed")
+        assert pytest.wait_for(server, 'closed')
     finally:
         m.stop()
 
 
 def test_tcp_connect_closed_port(Poller, ipv6):
-
-    if pytest.PLATFORM == "win32":
-        pytest.skip("Broken on Windows")
+    if pytest.PLATFORM == 'win32':
+        pytest.skip('Broken on Windows')
 
     m = Manager() + Poller() + Debugger()
 
     if ipv6:
-        tcp_server = TCP6Server(("::1", 0))
+        tcp_server = TCP6Server(('::1', 0))
         tcp_client = TCP6Client(connect_timeout=1)
     else:
         tcp_server = TCPServer(0)
@@ -255,8 +251,8 @@ def test_tcp_connect_closed_port(Poller, ipv6):
     m.start()
 
     try:
-        assert pytest.wait_for(client, "ready")
-        assert pytest.wait_for(server, "ready")
+        assert pytest.wait_for(client, 'ready')
+        assert pytest.wait_for(server, 'ready')
         wait_host(server)
 
         host, port = server.host, server.port
@@ -264,7 +260,7 @@ def test_tcp_connect_closed_port(Poller, ipv6):
 
         # 1st connect
         client.fire(connect(host, port))
-        waiter = WaitEvent(m, "unreachable", channel='client')
+        waiter = WaitEvent(m, 'unreachable', channel='client')
         assert waiter.wait()
     finally:
         server.unregister()
@@ -277,17 +273,17 @@ def test_tcp_bind(Poller, ipv6):
 
     if ipv6:
         sock = socket(AF_INET6, SOCK_STREAM)
-        sock.bind(("::1", 0))
+        sock.bind(('::1', 0))
         sock.listen(5)
-        _, bind_port, _, _ = sock.getsockname()
+        _, _bind_port, _, _ = sock.getsockname()
         sock.close()
-        server = Server() + TCP6Server(("::1", 0))
+        server = Server() + TCP6Server(('::1', 0))
         client = Client() + TCP6Client()
     else:
         sock = socket(AF_INET, SOCK_STREAM)
-        sock.bind(("", 0))
+        sock.bind(('', 0))
         sock.listen(5)
-        _, bind_port = sock.getsockname()
+        _, _bind_port = sock.getsockname()
         sock.close()
         server = Server() + TCPServer(0)
         client = Client() + TCPClient()
@@ -298,26 +294,26 @@ def test_tcp_bind(Poller, ipv6):
     m.start()
 
     try:
-        assert pytest.wait_for(client, "ready")
-        assert pytest.wait_for(server, "ready")
+        assert pytest.wait_for(client, 'ready')
+        assert pytest.wait_for(server, 'ready')
         wait_host(server)
 
         client.fire(connect(server.host, server.port))
-        assert pytest.wait_for(client, "connected")
-        assert pytest.wait_for(server, "connected")
-        assert pytest.wait_for(client, "data", b"Ready")
+        assert pytest.wait_for(client, 'connected')
+        assert pytest.wait_for(server, 'connected')
+        assert pytest.wait_for(client, 'data', b'Ready')
 
         # assert server.client[1] == bind_port
 
-        client.fire(write(b"foo"))
-        assert pytest.wait_for(server, "data", b"foo")
+        client.fire(write(b'foo'))
+        assert pytest.wait_for(server, 'data', b'foo')
 
         client.fire(close())
-        assert pytest.wait_for(client, "disconnected")
-        assert pytest.wait_for(server, "disconnected")
+        assert pytest.wait_for(client, 'disconnected')
+        assert pytest.wait_for(server, 'disconnected')
 
         server.fire(close())
-        assert pytest.wait_for(server, "closed")
+        assert pytest.wait_for(server, 'closed')
     finally:
         m.stop()
 
@@ -325,24 +321,21 @@ def test_tcp_bind(Poller, ipv6):
 def test_tcp_lookup_failure(manager, watcher, Poller, ipv6):
     poller = Poller().register(manager)
 
-    if ipv6:
-        tcp_client = TCP6Client()
-    else:
-        tcp_client = TCPClient()
+    tcp_client = TCP6Client() if ipv6 else TCPClient()
 
     client = Client() + tcp_client
     client.register(manager)
 
     try:
-        assert watcher.wait("ready", "client")
+        assert watcher.wait('ready', 'client')
 
-        client.fire(connect("foo.bar.baz", 1234))
-        assert watcher.wait("error", "client")
+        client.fire(connect('foo.bar.baz', 1234))
+        assert watcher.wait('error', 'client')
 
-        if pytest.PLATFORM == "win32":
+        if pytest.PLATFORM == 'win32':
             assert client.error.errno == 11004
         else:
-            assert client.error.errno in (EAI_NODATA, EAI_NONAME,)
+            assert client.error.errno in (EAI_NODATA, EAI_NONAME)
     finally:
         poller.unregister()
         client.unregister()
