@@ -1,8 +1,8 @@
-'''test_utils
+"""
+test_utils
 
 ...
-'''
-
+"""
 
 from circuits import Event
 from circuits.core import Value
@@ -10,8 +10,7 @@ from circuits.node.utils import dump_event, dump_value, load_event, load_value
 
 
 class test(Event):
-
-    '''test Event'''
+    """test Event"""
 
 
 def test_events():
