@@ -31,25 +31,11 @@
 # --------------------------------------------------------------------
 import base64
 import json
-import sys
+from http.client import HTTPConnection, HTTPSConnection
+from urllib.parse import splithost, splittype, splituser, unquote
 
-PY3 = sys.version_info[0] == 3
 
-try:
-    from http.client import HTTPConnection
-    from http.client import HTTPSConnection
-except ImportError:
-    from httplib import HTTP as HTTPConnection  # NOQA
-    from httplib import HTTPS as HTTPSConnection  # NOQA
-
-try:
-    from urllib.parse import unquote
-    from urllib.parse import splithost, splittype, splituser
-except ImportError:
-    from urllib import unquote  # NOQA
-    from urllib import splithost, splittype, splituser  # NOQA
-
-__version__ = "0.0.1"
+__version__ = '0.0.1'
 
 ID = 1
 
@@ -66,13 +52,14 @@ def _gen_id():
 ##
 # Base class for all kinds of client-side errors.
 
-class Error(Exception):
 
+class Error(Exception):
     """Base class for client errors."""
 
     def __str__(self):
         return repr(self)
 
+
 ##
 # Indicates an HTTP-level protocol error.  This is raised by the HTTP
 # transport layer, if the server returns an error code other than 200
@@ -85,7 +72,6 @@ class Error(Exception):
 
 
 class ProtocolError(Error):
-
     """Indicates an HTTP protocol error."""
 
     def __init__(self, url, errcode, errmsg, headers, response):
@@ -97,10 +83,7 @@ class ProtocolError(Error):
         self.response = response
 
     def __repr__(self):
-        return (
-            "<ProtocolError for %s: %s %s>" %
-            (self.url, self.errcode, self.errmsg)
-        )
+        return '<ProtocolError for %s: %s %s>' % (self.url, self.errcode, self.errmsg)
 
 
 def getparser(encoding):
@@ -109,18 +92,17 @@ def getparser(encoding):
     return par, un
 
 
-def dumps(params, methodname=None, methodresponse=None, encoding=None,
-          allow_none=0):
+def dumps(params, methodname=None, methodresponse=None, encoding=None, allow_none=0):
     if methodname:
         request = {}
-        request["method"] = methodname
-        request["params"] = params
-        request["id"] = _gen_id()
+        request['method'] = methodname
+        request['params'] = params
+        request['id'] = _gen_id()
         return json.dumps(request)
+    return None
 
 
-class Unmarshaller(object):
-
+class Unmarshaller:
     def __init__(self, encoding):
         self.data = None
         self.encoding = encoding
@@ -136,8 +118,7 @@ class Unmarshaller(object):
         return json.loads(self.data.decode(self.encoding))
 
 
-class Parser(object):
-
+class Parser:
     def __init__(self, unmarshaller):
         self._target = unmarshaller
         self.data = None
@@ -152,7 +133,7 @@ class Parser(object):
         self._target.feed(self.data)
 
 
-class _Method(object):
+class _Method:
     # some magic to bind an JSON-RPC method to an RPC server.
     # supports "nested" methods (e.g. examples.getStateName)
 
@@ -161,11 +142,12 @@ class _Method(object):
         self.__name = name
 
     def __getattr__(self, name):
-        return _Method(self.__send, "%s.%s" % (self.__name, name))
+        return _Method(self.__send, f'{self.__name}.{name}')
 
     def __call__(self, *args):
         return self.__send(self.__name, args)
 
+
 ##
 # Standard transport class for JSON-RPC over HTTP.
 # <p>
@@ -174,11 +156,10 @@ class _Method(object):
 
 
 class Transport:
-
     """Handles an HTTP transaction to an JSON-RPC server."""
 
     # client identifier (may be overridden)
-    user_agent = "jsonlib.py/%s (by matt harrison)" % __version__
+    user_agent = 'jsonlib.py/%s (by matt harrison)' % __version__
 
     ##
     # Send a complete request, and parse the response.
@@ -197,8 +178,6 @@ class Transport:
             h.set_debuglevel(1)
 
         self.send_request(h, handler, request_body)
-        if not PY3:
-            self.send_host(h, host)
         self.send_user_agent(h)
         self.send_content(h, request_body)
 
@@ -215,9 +194,10 @@ class Transport:
             response = r.read()
             raise ProtocolError(
                 host + handler,
-                errcode, errmsg,
+                errcode,
+                errmsg,
                 headers,
-                response
+                response,
             )
 
         self.verbose = verbose
@@ -249,7 +229,6 @@ class Transport:
     #     x509 info).  The header and x509 fields may be None.
 
     def get_host_info(self, host):
-
         x509 = {}
         if isinstance(host, tuple):
             host, x509 = host
@@ -258,9 +237,9 @@ class Transport:
 
         if auth:
             auth = base64.encodestring(unquote(auth))
-            auth = "".join(auth.split())  # get rid of whitespace
+            auth = ''.join(auth.split())  # get rid of whitespace
             extra_headers = [
-                ("Authorization", "Basic " + auth)
+                ('Authorization', 'Basic ' + auth),
             ]
         else:
             extra_headers = None
@@ -275,7 +254,7 @@ class Transport:
 
     def make_connection(self, host):
         # create a HTTP connection object from a host descriptor
-        host, extra_headers, x509 = self.get_host_info(host)
+        host, _extra_headers, _x509 = self.get_host_info(host)
         return HTTPConnection(host)
 
     ##
@@ -286,7 +265,7 @@ class Transport:
     # @param request_body JSON-RPC body.
 
     def send_request(self, connection, handler, request_body):
-        connection.putrequest("POST", handler)
+        connection.putrequest('POST', handler)
 
     ##
     # Send host name.
@@ -295,8 +274,8 @@ class Transport:
     # @param host Host name.
 
     def send_host(self, connection, host):
-        host, extra_headers, x509 = self.get_host_info(host)
-        connection.putheader("Host", host)
+        host, extra_headers, _x509 = self.get_host_info(host)
+        connection.putheader('Host', host)
         if extra_headers:
             if isinstance(extra_headers, dict):
                 extra_headers = list(extra_headers.items())
@@ -309,7 +288,7 @@ class Transport:
     # @param connection Connection handle.
 
     def send_user_agent(self, connection):
-        connection.putheader("User-Agent", self.user_agent)
+        connection.putheader('User-Agent', self.user_agent)
 
     ##
     # Send request body.
@@ -318,8 +297,8 @@ class Transport:
     # @param request_body JSON-RPC request body.
 
     def send_content(self, connection, request_body):
-        connection.putheader("Content-Type", "text/xml")
-        connection.putheader("Content-Length", str(len(request_body)))
+        connection.putheader('Content-Type', 'text/xml')
+        connection.putheader('Content-Length', str(len(request_body)))
         connection.endheaders()
         if request_body:
             connection.send(request_body)
@@ -350,14 +329,11 @@ class Transport:
         p, u = self.getparser(encoding)
 
         while 1:
-            if sock:
-                response = sock.recv(1024)
-            else:
-                response = file.read(1024)
+            response = sock.recv(1024) if sock else file.read(1024)
             if not response:
                 break
             if self.verbose:
-                print("body:", repr(response))
+                print('body:', repr(response))
             p.feed(response)
 
         file.close()
@@ -365,12 +341,12 @@ class Transport:
 
         return u.close()
 
+
 ##
 # Standard transport class for JSON-RPC over HTTPS.
 
 
 class SafeTransport(Transport):
-
     """Handles an HTTPS transaction to an JSON-RPC server."""
 
     # FIXME: mostly untested
@@ -378,33 +354,28 @@ class SafeTransport(Transport):
     def make_connection(self, host):
         # create a HTTPS connection object from a host descriptor
         # host may be a string, or a (host, x509-dict) tuple
-        host, extra_headers, x509 = self.get_host_info(host)
+        host, _extra_headers, x509 = self.get_host_info(host)
         try:
             HTTPS = HTTPSConnection
         except AttributeError:
             raise NotImplementedError(
-                "your version of httplib doesn't support HTTPS"
+                "your version of httplib doesn't support HTTPS",
             )
         else:
             return HTTPS(host, None, **(x509 or {}))
 
 
-class ServerProxy(object):
-
-    def __init__(self, uri, transport=None, encoding=None,
-                 verbose=None, allow_none=0):
+class ServerProxy:
+    def __init__(self, uri, transport=None, encoding=None, verbose=None, allow_none=0):
         utype, uri = splittype(uri)
-        if utype not in ("http", "https"):
-            raise IOError("Unsupported JSONRPC protocol")
+        if utype not in ('http', 'https'):
+            raise OSError('Unsupported JSONRPC protocol')
         self.__host, self.__handler = splithost(uri)
         if not self.__handler:
-            self.__handler = "/RPC2"
+            self.__handler = '/RPC2'
 
         if transport is None:
-            if utype == "https":
-                transport = SafeTransport()
-            else:
-                transport = Transport()
+            transport = SafeTransport() if utype == 'https' else Transport()
         self.__transport = transport
 
         self.__encoding = encoding
@@ -412,18 +383,15 @@ class ServerProxy(object):
         self.__allow_none = allow_none
 
     def __request(self, methodname, params):
-        """call a method on the remote server
-        """
-
-        request = dumps(params, methodname, encoding=self.__encoding,
-                        allow_none=self.__allow_none)
+        """Call a method on the remote server"""
+        request = dumps(params, methodname, encoding=self.__encoding, allow_none=self.__allow_none)
 
         response = self.__transport.request(
             self.__host,
             self.__handler,
             request.encode(self.__encoding),
             self.__encoding,
-            verbose=self.__verbose
+            verbose=self.__verbose,
         )
 
         if len(response) == 1:
@@ -432,9 +400,7 @@ class ServerProxy(object):
         return response
 
     def __repr__(self):
-        return ("<JSONProxy for %s%s>" %
-                (self.__host, self.__handler)
-                )
+        return '<JSONProxy for %s%s>' % (self.__host, self.__handler)
 
     __str__ = __repr__
 
@@ -446,13 +412,13 @@ class ServerProxy(object):
     # result getattr(server, "strange-python-name")(args)
 
 
-if __name__ == "__main__":
-    s = ServerProxy("http://localhost:8080/foo/", verbose=1)
-    c = s.echo("foo bar")
+if __name__ == '__main__':
+    s = ServerProxy('http://localhost:8080/foo/', verbose=1)
+    c = s.echo('foo bar')
     print(c)
-    d = s.bad("other")
+    d = s.bad('other')
     print(d)
-    e = s.echo("foo bar", "baz")
+    e = s.echo('foo bar', 'baz')
     print(e)
     f = s.echo(5)
     print(f)
