@@ -6,22 +6,19 @@ from .helpers import urlopen
 
 
 class foo(Event):
-
     """foo Event"""
 
 
 class App(Component):
-
-    channel = "app"
+    channel = 'app'
 
     def foo(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 class Root(Controller):
-
     def index(self):
-        value = (yield self.call(foo(), "app"))
+        value = yield self.call(foo(), 'app')
         yield value.value
 
 
@@ -30,6 +27,6 @@ def test(webapp):
     try:
         f = urlopen(webapp.server.http.base)
         s = f.read()
-        assert s == b"Hello World!"
+        assert s == b'Hello World!'
     finally:
         app.unregister()
