@@ -4,16 +4,15 @@ from circuits.web.client import Client, request
 
 
 class Root(Controller):
-
     def index(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 def test(webapp):
     client = Client()
     client.start()
 
-    client.fire(request("GET", webapp.server.http.base))
+    client.fire(request('GET', webapp.server.http.base))
     while client.response is None:
         pass
 
@@ -21,7 +20,7 @@ def test(webapp):
 
     response = client.response
     assert response.status == 200
-    assert response.reason == "OK"
+    assert response.reason == 'OK'
 
     s = response.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
