@@ -1,16 +1,12 @@
 #!/usr/bin/env python
-try:
-    from httplib import HTTPConnection
-except ImportError:
-    from http.client import HTTPConnection  # NOQA
+from http.client import HTTPConnection
 
 from circuits.web import Controller
 
 
 class Root(Controller):
-
     def index(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 def test(webapp):
@@ -18,12 +14,12 @@ def test(webapp):
     connection.auto_open = False
     connection.connect()
 
-    for i in range(2):
-        connection.request("GET", "/")
+    for _i in range(2):
+        connection.request('GET', '/')
         response = connection.getresponse()
         assert response.status == 200
-        assert response.reason == "OK"
+        assert response.reason == 'OK'
         s = response.read()
-        assert s == b"Hello World!"
+        assert s == b'Hello World!'
 
     connection.close()
