@@ -5,14 +5,12 @@ from .helpers import CookieJar, HTTPCookieProcessor, build_opener
 
 
 class Root(Controller):
-
     def index(self):
-        visited = self.cookie.get("visited")
+        visited = self.cookie.get('visited')
         if visited and visited.value:
-            return "Hello again!"
-        else:
-            self.cookie["visited"] = True
-            return "Hello World!"
+            return 'Hello again!'
+        self.cookie['visited'] = True
+        return 'Hello World!'
 
 
 def test(webapp):
@@ -21,8 +19,8 @@ def test(webapp):
 
     f = opener.open(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
 
     f = opener.open(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello again!"
+    assert s == b'Hello again!'
