@@ -1,33 +1,31 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 from circuits.web import Controller, expose
 
 from .helpers import urlopen
 
 
 class Root(Controller):
-
     def __init__(self, *args, **kwargs):
-        super(Root, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self += Hello()
         self += World()
 
     def index(self):
-        return "index"
+        return 'index'
 
     def hello1(self):
-        return "hello1"
+        return 'hello1'
 
-    @expose("hello2")
+    @expose('hello2')
     def hello2(self):
-        return "hello2"
+        return 'hello2'
 
     def query(req, test):
         return 'query %s' % test
 
 
 class Hello(Controller):
-    channel = "/hello"
+    channel = '/hello'
 
     def index(self):
         return 'hello index'
@@ -40,7 +38,7 @@ class Hello(Controller):
 
 
 class World(Controller):
-    channel = "/world"
+    channel = '/world'
 
     def index(self):
         return 'world index'
@@ -50,56 +48,56 @@ class World(Controller):
 
 
 def test_simple(webapp):
-    url = "%s/hello1" % webapp.server.http.base
+    url = '%s/hello1' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"hello1"
+    assert s == b'hello1'
 
 
 def test_expose(webapp):
-    url = "%s/hello2" % webapp.server.http.base
+    url = '%s/hello2' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"hello2"
+    assert s == b'hello2'
 
 
 def test_index(webapp):
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"index"
+    assert s == b'index'
 
 
 def test_controller_index(webapp):
-    url = "%s/hello/" % webapp.server.http.base
+    url = '%s/hello/' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"hello index"
+    assert s == b'hello index'
 
-    url = "%s/world/" % webapp.server.http.base
+    url = '%s/world/' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"world index"
+    assert s == b'world index'
 
 
 def test_controller_expose(webapp):
-    url = "%s/hello/test" % webapp.server.http.base
+    url = '%s/hello/test' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"hello test"
+    assert s == b'hello test'
 
-    url = "%s/world/test" % webapp.server.http.base
+    url = '%s/world/test' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"world test"
+    assert s == b'world test'
 
 
 def test_query(webapp):
-    url = "%s/query?test=1" % webapp.server.http.base
+    url = '%s/query?test=1' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"query 1"
+    assert s == b'query 1'
 
-    url = "%s/hello/query?test=2" % webapp.server.http.base
+    url = '%s/hello/query?test=2' % webapp.server.http.base
     f = urlopen(url)
     s = f.read()
-    assert s == b"hello query 2"
+    assert s == b'hello query 2'
