@@ -13,21 +13,19 @@ from .helpers import Request, build_opener
 
 
 class Gzip(Component):
+    channel = 'web'
 
-    channel = "web"
-
-    @handler("response", priority=1.0)
+    @handler('response', priority=1.0)
     def _on_response(self, event, *args, **kwargs):
         event[0] = gzip(event[0])
 
 
 class Root(Controller):
-
     def index(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
-@fixture
+@fixture()
 def gziptool(request, webapp):
     gziptool = Gzip().register(webapp)
 
@@ -53,19 +51,19 @@ def decompress(body):
 
 def test1(webapp, gziptool):
     request = Request(webapp.server.http.base)
-    request.add_header("Accept-Encoding", "gzip")
+    request.add_header('Accept-Encoding', 'gzip')
     opener = build_opener()
 
     f = opener.open(request)
     s = decompress(f.read())
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
 
 
 def test2(webapp, gziptool):
-    request = Request("%s/static/largefile.txt" % webapp.server.http.base)
-    request.add_header("Accept-Encoding", "gzip")
+    request = Request('%s/static/largefile.txt' % webapp.server.http.base)
+    request.add_header('Accept-Encoding', 'gzip')
     opener = build_opener()
 
     f = opener.open(request)
     s = decompress(f.read())
-    assert s == open(path.join(DOCROOT, "largefile.txt"), "rb").read()
+    assert s == open(path.join(DOCROOT, 'largefile.txt'), 'rb').read()
