@@ -4,7 +4,6 @@ from .helpers import HTTPError, urlopen
 
 
 class Root(Controller):
-
     def index(self):
         pass
 
@@ -14,6 +13,6 @@ def test(webapp):
         urlopen(webapp.server.http.base)
     except HTTPError as e:
         assert e.code == 404
-        assert e.msg == "Not Found"
+        assert e.msg == 'Not Found'
     else:
         assert False
