@@ -8,12 +8,11 @@ from .helpers import urlopen
 
 
 class Root(Controller):
-
     def __init__(self, *args, **kwargs):
-        super(Root, self).__init__(self, *args, **kwargs)
+        super().__init__(self, *args, **kwargs)
 
         fd, self.filename = mkstemp()
-        os.write(fd, b"Hello World!")
+        os.write(fd, b'Hello World!')
         os.close(fd)
 
     def __del__(self):
@@ -26,4 +25,4 @@ class Root(Controller):
 def test(webapp):
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
