@@ -1,13 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
+from http.client import HTTPConnection
 
 import pytest
 
-try:
-    from httplib import HTTPConnection
-except ImportError:
-    from http.client import HTTPConnection  # noqa
-
 from circuits.web import Controller
 from circuits.web.client import Client, request
 
@@ -15,22 +11,21 @@ from .helpers import urlopen
 
 
 class Root(Controller):
-
     def index(self):
-        return "Hello World!"
+        return 'Hello World!'
 
     def request_body(self):
         return self.request.body.read()
 
     def response_body(self):
-        return "ä"
+        return 'ä'
 
     def request_headers(self):
-        return self.request.headers["A"]
+        return self.request.headers['A']
 
     def response_headers(self):
-        self.response.headers["A"] = "ä"
-        return "ä"
+        self.response.headers['A'] = 'ä'
+        return 'ä'
 
     def argument(self, arg):
         return arg
@@ -39,21 +34,24 @@ class Root(Controller):
 def test_index(webapp):
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
 
 
-@pytest.mark.parametrize('body', [
-    u"ä".encode('utf-8'),
-    u"ä".encode('iso8859-1')
-])
+@pytest.mark.parametrize(
+    'body',
+    [
+        'ä'.encode(),
+        'ä'.encode('iso8859-1'),
+    ],
+)
 def test_request_body(webapp, body):
     connection = HTTPConnection(webapp.server.host, webapp.server.port)
     connection.connect()
 
-    connection.request("GET", "/request_body", body)
+    connection.request('POST', '/request_body', body)
     response = connection.getresponse()
     assert response.status == 200
-    assert response.reason == "OK"
+    assert response.reason == 'OK'
     s = response.read()
     assert s == body
 
@@ -64,12 +62,12 @@ def test_response_body(webapp):
     connection = HTTPConnection(webapp.server.host, webapp.server.port)
     connection.connect()
 
-    connection.request("GET", "/response_body")
+    connection.request('GET', '/response_body')
     response = connection.getresponse()
     assert response.status == 200
-    assert response.reason == "OK"
+    assert response.reason == 'OK'
     s = response.read()
-    assert s == u"ä".encode('utf-8')
+    assert s == 'ä'.encode()
 
     connection.close()
 
@@ -78,14 +76,14 @@ def test_request_headers(webapp):
     connection = HTTPConnection(webapp.server.host, webapp.server.port)
     connection.connect()
 
-    body = b""
-    headers = {"A": "ä"}
-    connection.request("GET", "/request_headers", body, headers)
+    body = b''
+    headers = {'A': 'ä'}
+    connection.request('GET', '/request_headers', body, headers)
     response = connection.getresponse()
     assert response.status == 200
-    assert response.reason == "OK"
+    assert response.reason == 'OK'
     s = response.read()
-    assert s == u"ä".encode('utf-8')
+    assert s == 'ä'.encode()
 
     connection.close()
 
@@ -95,11 +93,13 @@ def test_response_headers(webapp):
     client.start()
     client.fire(
         request(
-            "GET",
-            "http://%s:%s/response_headers" % (
-                webapp.server.host, webapp.server.port
-            )
-        )
+            'GET',
+            'http://%s:%s/response_headers'
+            % (
+                webapp.server.host,
+                webapp.server.port,
+            ),
+        ),
     )
 
     while client.response is None:
@@ -108,8 +108,8 @@ def test_response_headers(webapp):
     assert client.response.reason == 'OK'
     s = client.response.read()
     a = client.response.headers.get('A')
-    assert a == "ä"
-    assert s == u"ä".encode('utf-8')
+    assert a == 'ä'
+    assert s == 'ä'.encode()
 
 
 def test_argument(webapp):
@@ -117,11 +117,11 @@ def test_argument(webapp):
     connection.connect()
 
     data = 'arg=%E2%86%92'
-    connection.request("POST", "/argument", data, {"Content-type": "application/x-www-form-urlencoded"})
+    connection.request('POST', '/argument', data, {'Content-type': 'application/x-www-form-urlencoded'})
     response = connection.getresponse()
     assert response.status == 200
-    assert response.reason == "OK"
+    assert response.reason == 'OK'
     s = response.read()
-    assert s.decode('utf-8') == u'\u2192'
+    assert s.decode('utf-8') == '\u2192'
 
     connection.close()
