@@ -6,18 +6,15 @@ from .helpers import urlopen
 
 
 class hello(Event):
-
     """hello Event"""
 
 
 class App(Component):
-
     def hello(self):
-        return "Hello World!"
+        return 'Hello World!'
 
 
 class Root(Controller):
-
     def index(self):
         return self.fire(hello())
 
@@ -27,4 +24,4 @@ def test(webapp):
 
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
