@@ -6,11 +6,11 @@ from .helpers import urlopen
 
 
 class Root(Controller):
-
     def index(self):
         def response():
-            yield "Hello "
-            yield "World!"
+            yield 'Hello '
+            yield 'World!'
+
         return response()
 
 
@@ -20,4 +20,5 @@ application = Application() + Root()
 def test(webapp):
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
+    assert f.headers.get('Transfer-Encoding') != 'chunked'
