@@ -6,10 +6,9 @@ from .helpers import urlopen
 
 
 class Root(Controller):
-
     def index(self):
-        yield "Hello "
-        yield "World!"
+        yield 'Hello '
+        yield 'World!'
 
 
 application = Application() + Root()
@@ -18,4 +17,5 @@ application = Application() + Root()
 def test(webapp):
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
+    assert f.headers.get('Transfer-Encoding') != 'chunked'
