@@ -3,13 +3,13 @@ from .helpers import urlopen
 
 
 def application(environ, start_response):
-    status = "200 OK"
-    response_headers = [("Content-type", "text/plain")]
+    status = '200 OK'
+    response_headers = [('Content-type', 'text/plain')]
     start_response(status, response_headers)
 
     def response():
-        yield "Hello "
-        yield "World!"
+        yield 'Hello '
+        yield 'World!'
 
     return response()
 
@@ -17,4 +17,5 @@ def application(environ, start_response):
 def test(webapp):
     f = urlopen(webapp.server.http.base)
     s = f.read()
-    assert s == b"Hello World!"
+    assert s == b'Hello World!'
+    assert f.headers.get('Transfer-Encoding') == 'chunked'
